# coding: utf8
from __future__ import unicode_literals


# Source: https://github.com/stopwords-iso/stopwords-af

STOP_WORDS = set(
    """
'n
aan
af
al
as
baie
by
daar
dag
dat
die
dit
een
ek
en
gaan
gesê
haar
het
hom
hulle
hy
in
is
jou
jy
kan
kom
ma
maar
met
my
na
nie
om
ons
op
saam
sal
se
sien
so
sy
te
toe
uit
van
vir
was
wat
ŉ
""".split()
)
