# coding: utf8
from __future__ import unicode_literals

"""
Example sentences to test spaCy and its language models.

>>> from spacy.lang.ko.examples import sentences
>>> docs = nlp.pipe(sentences)
"""

sentences = [
    "애플이 영국의 스타트업을 10억 달러에 인수하는 것을 알아보고 있다.",
    "자율주행 자동차의 손해 배상 책임이 제조 업체로 옮겨 가다",
    "샌프란시스코 시가 자동 배달 로봇의 보도 주행 금지를 검토 중이라고 합니다.",
    "런던은 영국의 수도이자 가장 큰 도시입니다.",
]
