# encoding: utf8
from __future__ import unicode_literals

# Source: Handpicked by Jens Dahl Møllerhøj.

STOP_WORDS = set(
    """
af aldrig alene alle allerede alligevel alt altid anden andet andre at

bag begge blandt blev blive bliver burde bør

da de dem den denne dens der derefter deres derfor derfra deri dermed derpå derved det dette dig din dine disse dog du

efter egen eller ellers en end endnu ene eneste enhver ens enten er et

flere flest fleste for foran fordi forrige fra få før først

gennem gjorde gjort god gør gøre gørende

ham han hans har havde have hel heller hen hende hendes henover her herefter heri hermed herpå hun hvad hvem hver hvilke hvilken hvilkes hvis hvor hvordan hvorefter hvorfor hvorfra hvorhen hvori hvorimod hvornår hvorved

i igen igennem ikke imellem imens imod ind indtil ingen intet

jeg jer jeres jo

kan kom kommer kun kunne

lad langs lav lave lavet lidt lige ligesom lille længere

man mange med meget mellem men mens mere mest mig min mindre mindst mine mit må måske

ned nemlig nogen nogensinde noget nogle nok nu ny nyt nær næste næsten

og også om omkring op os over overalt

på

samme sammen selv selvom senere ses siden sig sige skal skulle som stadig synes syntes så sådan således

temmelig tidligere til tilbage tit

ud uden udover under undtagen

var ved vi via vil ville vore vores vær være været

øvrigt
""".split()
)
