#  tests for spacy-2.3.5-py37h59b6b97_0 (this is a generated file);
print('===== testing package: spacy-2.3.5-py37h59b6b97_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import sys
import pytest
import spacy
import multiprocessing

if __name__ == "__main__":
    multiprocessing.freeze_support()

    PACKAGE_DIR = os.path.abspath(os.path.dirname((spacy.__file__)))
    sys.exit(pytest.main([PACKAGE_DIR]))#  --- run_test.py (end) ---

print('===== spacy-2.3.5-py37h59b6b97_0 OK =====');
print("import: 'spacy'")
import spacy

