# coding: utf8
from __future__ import unicode_literals


STOP_WORDS = set(
    """
а
авај
ако
ал
али
арх
ау
ах
аха
ај
бар
би
била
били
било
бисмо
бисте
бих
бијасмо
бијасте
бијах
бијаху
бијаше
биће
близу
број
брр
буде
будимо
будите
буду
будући
бум
бућ
вам
вама
вас
ваша
ваше
вашим
вашима
ваљда
веома
вероватно
већ
већина
ви
видео
више
врло
врх
га
где
гиц
год
горе
гђекоје
да
дакле
дана
данас
дај
два
де
дедер
делимице
делимично
дем
до
добар
добити
довечер
докле
доле
донекле
досад
доскоро
дотад
дотле
дошао
доћи
другамо
другде
други
е
ево
ено
ето
ех
ехе
еј
желела
желеле
желели
желело
желех
желећи
жели
за
заиста
зар
затим
зато
захвалити
зашто
збиља
зимус
знати
зум
и
иде
из
изван
изволи
између
изнад
икада
икакав
икаква
икакве
икакви
икаквим
икаквима
икаквих
икакво
икаквог
икаквога
икаквом
икаквоме
икаквој
или
им
има
имам
имао
испод
их
ију
ићи
кад
када
кога
којекакав
којима
коју
кришом
лани
ли
мали
мањи
ме
мене
мени
ми
мимо
мисли
много
могу
мора
морао
мој
моја
моје
моји
моју
моћи
му
на
над
након
нам
нама
нас
наша
наше
нашег
наши
наћи
не
негде
нека
некад
неке
неког
неку
нема
немам
неко
неће
нећемо
нећете
нећеш
нећу
ни
никада
никога
никоје
никоји
никоју
нисам
ниси
нисте
нису
ништа
ниједан
но
о
ова
овако
овамо
овај
овде
ове
овим
овима
ово
овој
од
одмах
око
около
он
онај
оне
оним
онима
оном
оној
ону
осим
остали
отишао
па
пак
питати
по
поводом
под
подаље
пожељан
пожељна
поиздаље
поименце
понекад
попреко
поред
после
потаман
потрбушке
поуздано
почетак
поједини
правити
први
преко
према
прије
пут
пљус
радије
с
са
сав
сада
сам
само
сасвим
сва
сваки
сви
свим
свог
свом
свој
своја
своје
своју
сву
свугде
се
себе
себи
си
смети
смо
ствар
стварно
сте
су
сутра
та
таèно
тако
такође
тамо
твој
твоја
твоје
твоји
твоју
те
тебе
теби
ти
тима
то
томе
тој
ту
у
увек
увијек
уз
уза
узалуд
уздуж
узети
умало
унутра
употребити
упркос
учинио
учинити
хало
хвала
хеј
хм
хоп
хоће
хоћемо
хоћете
хоћеш
хоћу
хтедосте
хтедох
хтедоше
хтела
хтеле
хтели
хтео
хтејасмо
хтејасте
хтејаху
хура
често
чијем
чији
чијим
чијима
шиц
штагод
што
штогод
ја
је
један
једини
једна
једне
једни
једно
једном
јер
јесам
јеси
јесмо
јесу
јим
јој
ју
јуче
његова
његово
њезин
њезина
њезино
њему
њен
њим
њима
њихова
њихово
њој
њу
ће
ћемо
ћете
ћеш
ћу
""".split()
)
