# coding: utf8
from __future__ import unicode_literals

STOP_WORDS = set(
    """
من
نحو
لعل
بما
بين
وبين
ايضا
وبينما
تحت
مثلا
لدي
عنه
مع
هي
وهذا
واذا
هذان
انه
بينما
أمسى
وسوف
ولم
لذلك
إلى
منه
منها
كما
ظل
هنا
به
كذلك
اما
هما
بعد
بينهم
التي
أبو
اذا
بدلا
لها
أمام
يلي
حين
ضد
الذي
قد
صار
إذا
مابرح
قبل
كل
وليست
الذين
لهذا
وثي
انهم
باللتي
مافتئ
ولا
بهذه
بحيث
كيف
وله
علي
بات
لاسيما
حتى
وقد
و
أما
فيها
بهذا
لذا
حيث
لقد
إن
فإن
اول
ليت
فاللتي
ولقد
لسوف
هذه
ولماذا
معه
الحالي
بإن
حول
في
عليه
مايزال
ولعل
أنه
أضحى
اي
ستكون
لن
أن
ضمن
وعلى
امسى
الي
ذات
ولايزال
ذلك
فقد
هم
أي
عند
ابن
أو
فهو
فانه
سوف
ما
آل
كلا
عنها
وكذلك
ليست
لم
وأن
ماذا
لو
وهل
اللتي
ولذا
يمكن
فيه
الا
عليها
وبينهم
يوم
وبما
لما
فكان
اضحى
اصبح
لهم
بها
او
الذى
الى
إلي
قال
والتي
لازال
أصبح
ولهذا
مثل
وكانت
لكنه
بذلك
هذا
لماذا
قالت
فقط
لكن
مما
وكل
وان
وأبو
ومن
كان
مازال
هل
بينهن
هو
وما
على
وهو
لأن
واللتي
والذي
دون
عن
وايضا
هناك
بلا
جدا
ثم
منذ
اللذين
لايزال
بعض
مساء
تكون
فلا
بيننا
لا
ولكن
إذ
وأثناء
ليس
ومع
فيهم
ولسوف
بل
تلك
أحد
وهي
وكان
ومنها
وفي
ماانفك
اليوم
وماذا
هؤلاء
وليس
له
أثناء
بد
اليه
كأن
اليها
بتلك
يكون
ولما
هن
والى
كانت
وقبل
ان
لدى
إذما
إذن
أف
أقل
أكثر
ألا
إلا
اللاتي
اللائي
اللتان
اللتيا
اللتين
اللذان
اللواتي
إليك
إليكم
إليكما
إليكن
أم
أما
إما
إنا
أنا
أنت
أنتم
أنتما
أنتن
إنما
إنه
أنى
أنى
آه
آها
أولاء
أولئك
أوه
آي
أيها
إي
أين
أين
أينما
إيه
بخ
بس
بك
بكم
بكم
بكما
بكن
بلى
بماذا
بمن
بنا
بهم
بهما
بهن
بي
بيد
تلكم
تلكما
ته
تي
تين
تينك
ثمة
حاشا
حبذا
حيثما
خلا
ذا
ذاك
ذان
ذانك
ذلكم
ذلكما
ذلكن
ذه
ذو
ذوا
ذواتا
ذواتي
ذي
ذين
ذينك
ريث
سوى
شتان
عدا
عسى
عل
عليك
عما
غير
فإذا
فمن
فيم
فيما
كأنما
كأي
كأين
كذا
كلاهما
كلتا
كلما
كليكما
كليهما
كم
كم
كي
كيت
كيفما
لست
لستم
لستما
لستن
لسن
لسنا
لك
لكم
لكما
لكنما
لكي
لكيلا
لنا
لهما
لهن
لولا
لوما
لي
لئن
ليسا
ليستا
ليسوا
متى
مذ
ممن
مه
مهما
نحن
نعم
ها
هاتان
هاته
هاتي
هاتين
هاك
هاهنا
هذي
هذين
هكذا
هلا
هنالك
هيا
هيت
هيهات
والذين
وإذ
وإذا
وإن
ولو
يا
""".split()
)
