# encoding: utf8
from __future__ import unicode_literals


STOP_WORDS = set(
    """
a abans ací ah així això al aleshores algun alguna algunes alguns alhora allà allí allò
als altra altre altres amb ambdues ambdós anar ans apa aquell aquella aquelles aquells
aquest aquesta aquestes aquests aquí

baix bastant bé

cada cadascuna cadascunes cadascuns cadascú com consegueixo conseguim conseguir
consigueix consigueixen consigueixes contra

d'un d'una d'unes d'uns dalt de del dels des des de després dins dintre donat doncs durant

e eh el elles ells els em en encara ens entre era erem eren eres es esta estan estat
estava estaven estem esteu estic està estàvem estàveu et etc ets érem éreu és éssent

fa faig fan fas fem fer feu fi fins fora

gairebé

ha han has haver havia he hem heu hi ho

i igual iguals inclòs

ja jo

l'hi la les li li'n llarg llavors

m'he ma mal malgrat mateix mateixa mateixes mateixos me mentre meu meus meva
meves mode molt molta moltes molts mon mons més

n'he n'hi ne ni no nogensmenys només nosaltres nostra nostre nostres

o oh oi on

pas pel pels per per que perquè però poc poca pocs podem poden poder
podeu poques potser primer propi puc

qual quals quan quant que quelcom qui quin quina quines quins què

s'ha s'han sa sabem saben saber sabeu sap saps semblant semblants sense ser ses
seu seus seva seves si sobre sobretot soc solament sols som son sons sota sou sóc són

t'ha t'han t'he ta tal també tampoc tan tant tanta tantes te tene tenim tenir teniu
teu teus teva teves tinc ton tons tot tota totes tots

un una unes uns us últim ús

va vaig vam van vas veu vosaltres vostra vostre vostres

""".split()
)
