# coding: utf8
from __future__ import unicode_literals


"""
Example sentences to test spaCy and its language models.

>>> from spacy.lang.sa.examples import sentences
>>> docs = nlp.pipe(sentences)
"""


sentences = [
    "अभ्यावहति कल्याणं विविधं वाक् सुभाषिता ।",
    "मनसि व्याकुले चक्षुः पश्यन्नपि न पश्यति ।",
    "यस्य बुद्धिर्बलं तस्य निर्बुद्धेस्तु कुतो बलम्?",
    "परो अपि हितवान् बन्धुः बन्धुः अपि अहितः परः ।",
    "अहितः देहजः व्याधिः हितम् आरण्यं औषधम् ॥",
]
