/* Generated by Cython 0.29.21 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef __cplusplus
  #error "Cython files generated with the C++ option must be compiled with a C++ compiler."
#endif
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #else
    #define CYTHON_INLINE inline
  #endif
#endif
template<typename T>
void __Pyx_call_destructor(T& x) {
    x.~T();
}
template<typename T>
class __Pyx_FakeReference {
  public:
    __Pyx_FakeReference() : ptr(NULL) { }
    __Pyx_FakeReference(const T& ref) : ptr(const_cast<T*>(&ref)) { }
    T *operator->() { return ptr; }
    T *operator&() { return ptr; }
    operator T&() { return *ptr; }
    template<typename U> bool operator ==(U other) { return *ptr == other; }
    template<typename U> bool operator !=(U other) { return *ptr != other; }
  private:
    T *ptr;
};

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__spacy__symbols
#define __PYX_HAVE_API__spacy__symbols
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "symbols.pyx",
};

/*--- Type declarations ---*/

/* "spacy/symbols.pxd":1
 * cdef enum symbol_t:             # <<<<<<<<<<<<<<
 *     NIL
 *     IS_ALPHA
 */
enum __pyx_t_5spacy_7symbols_symbol_t {
  __pyx_e_5spacy_7symbols_NIL,
  __pyx_e_5spacy_7symbols_IS_ALPHA,
  __pyx_e_5spacy_7symbols_IS_ASCII,
  __pyx_e_5spacy_7symbols_IS_DIGIT,
  __pyx_e_5spacy_7symbols_IS_LOWER,
  __pyx_e_5spacy_7symbols_IS_PUNCT,
  __pyx_e_5spacy_7symbols_IS_SPACE,
  __pyx_e_5spacy_7symbols_IS_TITLE,
  __pyx_e_5spacy_7symbols_IS_UPPER,
  __pyx_e_5spacy_7symbols_LIKE_URL,
  __pyx_e_5spacy_7symbols_LIKE_NUM,
  __pyx_e_5spacy_7symbols_LIKE_EMAIL,
  __pyx_e_5spacy_7symbols_IS_STOP,
  __pyx_e_5spacy_7symbols_IS_OOV_DEPRECATED,
  __pyx_e_5spacy_7symbols_IS_BRACKET,
  __pyx_e_5spacy_7symbols_IS_QUOTE,
  __pyx_e_5spacy_7symbols_IS_LEFT_PUNCT,
  __pyx_e_5spacy_7symbols_IS_RIGHT_PUNCT,
  __pyx_e_5spacy_7symbols_IS_CURRENCY,
  __pyx_e_5spacy_7symbols_FLAG19 = 19,
  __pyx_e_5spacy_7symbols_FLAG20,
  __pyx_e_5spacy_7symbols_FLAG21,
  __pyx_e_5spacy_7symbols_FLAG22,
  __pyx_e_5spacy_7symbols_FLAG23,
  __pyx_e_5spacy_7symbols_FLAG24,
  __pyx_e_5spacy_7symbols_FLAG25,
  __pyx_e_5spacy_7symbols_FLAG26,
  __pyx_e_5spacy_7symbols_FLAG27,
  __pyx_e_5spacy_7symbols_FLAG28,
  __pyx_e_5spacy_7symbols_FLAG29,
  __pyx_e_5spacy_7symbols_FLAG30,
  __pyx_e_5spacy_7symbols_FLAG31,
  __pyx_e_5spacy_7symbols_FLAG32,
  __pyx_e_5spacy_7symbols_FLAG33,
  __pyx_e_5spacy_7symbols_FLAG34,
  __pyx_e_5spacy_7symbols_FLAG35,
  __pyx_e_5spacy_7symbols_FLAG36,
  __pyx_e_5spacy_7symbols_FLAG37,
  __pyx_e_5spacy_7symbols_FLAG38,
  __pyx_e_5spacy_7symbols_FLAG39,
  __pyx_e_5spacy_7symbols_FLAG40,
  __pyx_e_5spacy_7symbols_FLAG41,
  __pyx_e_5spacy_7symbols_FLAG42,
  __pyx_e_5spacy_7symbols_FLAG43,
  __pyx_e_5spacy_7symbols_FLAG44,
  __pyx_e_5spacy_7symbols_FLAG45,
  __pyx_e_5spacy_7symbols_FLAG46,
  __pyx_e_5spacy_7symbols_FLAG47,
  __pyx_e_5spacy_7symbols_FLAG48,
  __pyx_e_5spacy_7symbols_FLAG49,
  __pyx_e_5spacy_7symbols_FLAG50,
  __pyx_e_5spacy_7symbols_FLAG51,
  __pyx_e_5spacy_7symbols_FLAG52,
  __pyx_e_5spacy_7symbols_FLAG53,
  __pyx_e_5spacy_7symbols_FLAG54,
  __pyx_e_5spacy_7symbols_FLAG55,
  __pyx_e_5spacy_7symbols_FLAG56,
  __pyx_e_5spacy_7symbols_FLAG57,
  __pyx_e_5spacy_7symbols_FLAG58,
  __pyx_e_5spacy_7symbols_FLAG59,
  __pyx_e_5spacy_7symbols_FLAG60,
  __pyx_e_5spacy_7symbols_FLAG61,
  __pyx_e_5spacy_7symbols_FLAG62,
  __pyx_e_5spacy_7symbols_FLAG63,
  __pyx_e_5spacy_7symbols_ID,
  __pyx_e_5spacy_7symbols_ORTH,
  __pyx_e_5spacy_7symbols_LOWER,
  __pyx_e_5spacy_7symbols_NORM,
  __pyx_e_5spacy_7symbols_SHAPE,
  __pyx_e_5spacy_7symbols_PREFIX,
  __pyx_e_5spacy_7symbols_SUFFIX,
  __pyx_e_5spacy_7symbols_LENGTH,
  __pyx_e_5spacy_7symbols_CLUSTER,
  __pyx_e_5spacy_7symbols_LEMMA,
  __pyx_e_5spacy_7symbols_POS,
  __pyx_e_5spacy_7symbols_TAG,
  __pyx_e_5spacy_7symbols_DEP,
  __pyx_e_5spacy_7symbols_ENT_IOB,
  __pyx_e_5spacy_7symbols_ENT_TYPE,
  __pyx_e_5spacy_7symbols_HEAD,
  __pyx_e_5spacy_7symbols_SENT_START,
  __pyx_e_5spacy_7symbols_SPACY,
  __pyx_e_5spacy_7symbols_PROB,
  __pyx_e_5spacy_7symbols_LANG,
  __pyx_e_5spacy_7symbols_ADJ,
  __pyx_e_5spacy_7symbols_ADP,
  __pyx_e_5spacy_7symbols_ADV,
  __pyx_e_5spacy_7symbols_AUX,
  __pyx_e_5spacy_7symbols_CONJ,
  __pyx_e_5spacy_7symbols_CCONJ,
  __pyx_e_5spacy_7symbols_DET,
  __pyx_e_5spacy_7symbols_INTJ,
  __pyx_e_5spacy_7symbols_NOUN,
  __pyx_e_5spacy_7symbols_NUM,
  __pyx_e_5spacy_7symbols_PART,
  __pyx_e_5spacy_7symbols_PRON,
  __pyx_e_5spacy_7symbols_PROPN,
  __pyx_e_5spacy_7symbols_PUNCT,
  __pyx_e_5spacy_7symbols_SCONJ,
  __pyx_e_5spacy_7symbols_SYM,
  __pyx_e_5spacy_7symbols_VERB,
  __pyx_e_5spacy_7symbols_X,
  __pyx_e_5spacy_7symbols_EOL,
  __pyx_e_5spacy_7symbols_SPACE,
  __pyx_e_5spacy_7symbols_Animacy_anim,
  __pyx_e_5spacy_7symbols_Animacy_inan,
  __pyx_e_5spacy_7symbols_Animacy_hum,
  __pyx_e_5spacy_7symbols_Animacy_nhum,
  __pyx_e_5spacy_7symbols_Aspect_freq,
  __pyx_e_5spacy_7symbols_Aspect_imp,
  __pyx_e_5spacy_7symbols_Aspect_mod,
  __pyx_e_5spacy_7symbols_Aspect_none,
  __pyx_e_5spacy_7symbols_Aspect_perf,
  __pyx_e_5spacy_7symbols_Aspect_iter,
  __pyx_e_5spacy_7symbols_Aspect_hab,
  __pyx_e_5spacy_7symbols_Case_abe,
  __pyx_e_5spacy_7symbols_Case_abl,
  __pyx_e_5spacy_7symbols_Case_abs,
  __pyx_e_5spacy_7symbols_Case_acc,
  __pyx_e_5spacy_7symbols_Case_ade,
  __pyx_e_5spacy_7symbols_Case_all,
  __pyx_e_5spacy_7symbols_Case_cau,
  __pyx_e_5spacy_7symbols_Case_com,
  __pyx_e_5spacy_7symbols_Case_cmp,
  __pyx_e_5spacy_7symbols_Case_dat,
  __pyx_e_5spacy_7symbols_Case_del,
  __pyx_e_5spacy_7symbols_Case_dis,
  __pyx_e_5spacy_7symbols_Case_ela,
  __pyx_e_5spacy_7symbols_Case_equ,
  __pyx_e_5spacy_7symbols_Case_ess,
  __pyx_e_5spacy_7symbols_Case_gen,
  __pyx_e_5spacy_7symbols_Case_ill,
  __pyx_e_5spacy_7symbols_Case_ine,
  __pyx_e_5spacy_7symbols_Case_ins,
  __pyx_e_5spacy_7symbols_Case_loc,
  __pyx_e_5spacy_7symbols_Case_lat,
  __pyx_e_5spacy_7symbols_Case_nom,
  __pyx_e_5spacy_7symbols_Case_par,
  __pyx_e_5spacy_7symbols_Case_sub,
  __pyx_e_5spacy_7symbols_Case_sup,
  __pyx_e_5spacy_7symbols_Case_tem,
  __pyx_e_5spacy_7symbols_Case_ter,
  __pyx_e_5spacy_7symbols_Case_tra,
  __pyx_e_5spacy_7symbols_Case_voc,
  __pyx_e_5spacy_7symbols_Definite_two,
  __pyx_e_5spacy_7symbols_Definite_def,
  __pyx_e_5spacy_7symbols_Definite_red,
  __pyx_e_5spacy_7symbols_Definite_cons,
  __pyx_e_5spacy_7symbols_Definite_ind,
  __pyx_e_5spacy_7symbols_Definite_spec,
  __pyx_e_5spacy_7symbols_Degree_cmp,
  __pyx_e_5spacy_7symbols_Degree_comp,
  __pyx_e_5spacy_7symbols_Degree_none,
  __pyx_e_5spacy_7symbols_Degree_pos,
  __pyx_e_5spacy_7symbols_Degree_sup,
  __pyx_e_5spacy_7symbols_Degree_abs,
  __pyx_e_5spacy_7symbols_Degree_com,
  __pyx_e_5spacy_7symbols_Degree_dim,
  __pyx_e_5spacy_7symbols_Degree_equ,
  __pyx_e_5spacy_7symbols_Evident_nfh,
  __pyx_e_5spacy_7symbols_Gender_com,
  __pyx_e_5spacy_7symbols_Gender_fem,
  __pyx_e_5spacy_7symbols_Gender_masc,
  __pyx_e_5spacy_7symbols_Gender_neut,
  __pyx_e_5spacy_7symbols_Mood_cnd,
  __pyx_e_5spacy_7symbols_Mood_imp,
  __pyx_e_5spacy_7symbols_Mood_ind,
  __pyx_e_5spacy_7symbols_Mood_n,
  __pyx_e_5spacy_7symbols_Mood_pot,
  __pyx_e_5spacy_7symbols_Mood_sub,
  __pyx_e_5spacy_7symbols_Mood_opt,
  __pyx_e_5spacy_7symbols_Mood_prp,
  __pyx_e_5spacy_7symbols_Mood_adm,
  __pyx_e_5spacy_7symbols_Negative_neg,
  __pyx_e_5spacy_7symbols_Negative_pos,
  __pyx_e_5spacy_7symbols_Negative_yes,
  __pyx_e_5spacy_7symbols_Polarity_neg,
  __pyx_e_5spacy_7symbols_Polarity_pos,
  __pyx_e_5spacy_7symbols_Number_com,
  __pyx_e_5spacy_7symbols_Number_dual,
  __pyx_e_5spacy_7symbols_Number_none,
  __pyx_e_5spacy_7symbols_Number_plur,
  __pyx_e_5spacy_7symbols_Number_sing,
  __pyx_e_5spacy_7symbols_Number_ptan,
  __pyx_e_5spacy_7symbols_Number_count,
  __pyx_e_5spacy_7symbols_Number_tri,
  __pyx_e_5spacy_7symbols_NumType_card,
  __pyx_e_5spacy_7symbols_NumType_dist,
  __pyx_e_5spacy_7symbols_NumType_frac,
  __pyx_e_5spacy_7symbols_NumType_gen,
  __pyx_e_5spacy_7symbols_NumType_mult,
  __pyx_e_5spacy_7symbols_NumType_none,
  __pyx_e_5spacy_7symbols_NumType_ord,
  __pyx_e_5spacy_7symbols_NumType_sets,
  __pyx_e_5spacy_7symbols_Person_one,
  __pyx_e_5spacy_7symbols_Person_two,
  __pyx_e_5spacy_7symbols_Person_three,
  __pyx_e_5spacy_7symbols_Person_none,
  __pyx_e_5spacy_7symbols_Poss_yes,
  __pyx_e_5spacy_7symbols_PronType_advPart,
  __pyx_e_5spacy_7symbols_PronType_art,
  __pyx_e_5spacy_7symbols_PronType_default,
  __pyx_e_5spacy_7symbols_PronType_dem,
  __pyx_e_5spacy_7symbols_PronType_ind,
  __pyx_e_5spacy_7symbols_PronType_int,
  __pyx_e_5spacy_7symbols_PronType_neg,
  __pyx_e_5spacy_7symbols_PronType_prs,
  __pyx_e_5spacy_7symbols_PronType_rcp,
  __pyx_e_5spacy_7symbols_PronType_rel,
  __pyx_e_5spacy_7symbols_PronType_tot,
  __pyx_e_5spacy_7symbols_PronType_clit,
  __pyx_e_5spacy_7symbols_PronType_exc,
  __pyx_e_5spacy_7symbols_PronType_emp,
  __pyx_e_5spacy_7symbols_Reflex_yes,
  __pyx_e_5spacy_7symbols_Tense_fut,
  __pyx_e_5spacy_7symbols_Tense_imp,
  __pyx_e_5spacy_7symbols_Tense_past,
  __pyx_e_5spacy_7symbols_Tense_pres,
  __pyx_e_5spacy_7symbols_VerbForm_fin,
  __pyx_e_5spacy_7symbols_VerbForm_ger,
  __pyx_e_5spacy_7symbols_VerbForm_inf,
  __pyx_e_5spacy_7symbols_VerbForm_none,
  __pyx_e_5spacy_7symbols_VerbForm_part,
  __pyx_e_5spacy_7symbols_VerbForm_partFut,
  __pyx_e_5spacy_7symbols_VerbForm_partPast,
  __pyx_e_5spacy_7symbols_VerbForm_partPres,
  __pyx_e_5spacy_7symbols_VerbForm_sup,
  __pyx_e_5spacy_7symbols_VerbForm_trans,
  __pyx_e_5spacy_7symbols_VerbForm_conv,
  __pyx_e_5spacy_7symbols_VerbForm_gdv,
  __pyx_e_5spacy_7symbols_VerbForm_vnoun,
  __pyx_e_5spacy_7symbols_Voice_act,
  __pyx_e_5spacy_7symbols_Voice_cau,
  __pyx_e_5spacy_7symbols_Voice_pass,
  __pyx_e_5spacy_7symbols_Voice_mid,
  __pyx_e_5spacy_7symbols_Voice_int,
  __pyx_e_5spacy_7symbols_Voice_antip,
  __pyx_e_5spacy_7symbols_Voice_dir,
  __pyx_e_5spacy_7symbols_Voice_inv,
  __pyx_e_5spacy_7symbols_Abbr_yes,
  __pyx_e_5spacy_7symbols_AdpType_prep,
  __pyx_e_5spacy_7symbols_AdpType_post,
  __pyx_e_5spacy_7symbols_AdpType_voc,
  __pyx_e_5spacy_7symbols_AdpType_comprep,
  __pyx_e_5spacy_7symbols_AdpType_circ,
  __pyx_e_5spacy_7symbols_AdvType_man,
  __pyx_e_5spacy_7symbols_AdvType_loc,
  __pyx_e_5spacy_7symbols_AdvType_tim,
  __pyx_e_5spacy_7symbols_AdvType_deg,
  __pyx_e_5spacy_7symbols_AdvType_cau,
  __pyx_e_5spacy_7symbols_AdvType_mod,
  __pyx_e_5spacy_7symbols_AdvType_sta,
  __pyx_e_5spacy_7symbols_AdvType_ex,
  __pyx_e_5spacy_7symbols_AdvType_adadj,
  __pyx_e_5spacy_7symbols_ConjType_oper,
  __pyx_e_5spacy_7symbols_ConjType_comp,
  __pyx_e_5spacy_7symbols_Connegative_yes,
  __pyx_e_5spacy_7symbols_Derivation_minen,
  __pyx_e_5spacy_7symbols_Derivation_sti,
  __pyx_e_5spacy_7symbols_Derivation_inen,
  __pyx_e_5spacy_7symbols_Derivation_lainen,
  __pyx_e_5spacy_7symbols_Derivation_ja,
  __pyx_e_5spacy_7symbols_Derivation_ton,
  __pyx_e_5spacy_7symbols_Derivation_vs,
  __pyx_e_5spacy_7symbols_Derivation_ttain,
  __pyx_e_5spacy_7symbols_Derivation_ttaa,
  __pyx_e_5spacy_7symbols_Echo_rdp,
  __pyx_e_5spacy_7symbols_Echo_ech,
  __pyx_e_5spacy_7symbols_Foreign_foreign,
  __pyx_e_5spacy_7symbols_Foreign_fscript,
  __pyx_e_5spacy_7symbols_Foreign_tscript,
  __pyx_e_5spacy_7symbols_Foreign_yes,
  __pyx_e_5spacy_7symbols_Gender_dat_masc,
  __pyx_e_5spacy_7symbols_Gender_dat_fem,
  __pyx_e_5spacy_7symbols_Gender_erg_masc,
  __pyx_e_5spacy_7symbols_Gender_erg_fem,
  __pyx_e_5spacy_7symbols_Gender_psor_masc,
  __pyx_e_5spacy_7symbols_Gender_psor_fem,
  __pyx_e_5spacy_7symbols_Gender_psor_neut,
  __pyx_e_5spacy_7symbols_Hyph_yes,
  __pyx_e_5spacy_7symbols_InfForm_one,
  __pyx_e_5spacy_7symbols_InfForm_two,
  __pyx_e_5spacy_7symbols_InfForm_three,
  __pyx_e_5spacy_7symbols_NameType_geo,
  __pyx_e_5spacy_7symbols_NameType_prs,
  __pyx_e_5spacy_7symbols_NameType_giv,
  __pyx_e_5spacy_7symbols_NameType_sur,
  __pyx_e_5spacy_7symbols_NameType_nat,
  __pyx_e_5spacy_7symbols_NameType_com,
  __pyx_e_5spacy_7symbols_NameType_pro,
  __pyx_e_5spacy_7symbols_NameType_oth,
  __pyx_e_5spacy_7symbols_NounType_com,
  __pyx_e_5spacy_7symbols_NounType_prop,
  __pyx_e_5spacy_7symbols_NounType_class,
  __pyx_e_5spacy_7symbols_Number_abs_sing,
  __pyx_e_5spacy_7symbols_Number_abs_plur,
  __pyx_e_5spacy_7symbols_Number_dat_sing,
  __pyx_e_5spacy_7symbols_Number_dat_plur,
  __pyx_e_5spacy_7symbols_Number_erg_sing,
  __pyx_e_5spacy_7symbols_Number_erg_plur,
  __pyx_e_5spacy_7symbols_Number_psee_sing,
  __pyx_e_5spacy_7symbols_Number_psee_plur,
  __pyx_e_5spacy_7symbols_Number_psor_sing,
  __pyx_e_5spacy_7symbols_Number_psor_plur,
  __pyx_e_5spacy_7symbols_Number_pauc,
  __pyx_e_5spacy_7symbols_Number_grpa,
  __pyx_e_5spacy_7symbols_Number_grpl,
  __pyx_e_5spacy_7symbols_Number_inv,
  __pyx_e_5spacy_7symbols_NumForm_digit,
  __pyx_e_5spacy_7symbols_NumForm_roman,
  __pyx_e_5spacy_7symbols_NumForm_word,
  __pyx_e_5spacy_7symbols_NumValue_one,
  __pyx_e_5spacy_7symbols_NumValue_two,
  __pyx_e_5spacy_7symbols_NumValue_three,
  __pyx_e_5spacy_7symbols_PartForm_pres,
  __pyx_e_5spacy_7symbols_PartForm_past,
  __pyx_e_5spacy_7symbols_PartForm_agt,
  __pyx_e_5spacy_7symbols_PartForm_neg,
  __pyx_e_5spacy_7symbols_PartType_mod,
  __pyx_e_5spacy_7symbols_PartType_emp,
  __pyx_e_5spacy_7symbols_PartType_res,
  __pyx_e_5spacy_7symbols_PartType_inf,
  __pyx_e_5spacy_7symbols_PartType_vbp,
  __pyx_e_5spacy_7symbols_Person_abs_one,
  __pyx_e_5spacy_7symbols_Person_abs_two,
  __pyx_e_5spacy_7symbols_Person_abs_three,
  __pyx_e_5spacy_7symbols_Person_dat_one,
  __pyx_e_5spacy_7symbols_Person_dat_two,
  __pyx_e_5spacy_7symbols_Person_dat_three,
  __pyx_e_5spacy_7symbols_Person_erg_one,
  __pyx_e_5spacy_7symbols_Person_erg_two,
  __pyx_e_5spacy_7symbols_Person_erg_three,
  __pyx_e_5spacy_7symbols_Person_psor_one,
  __pyx_e_5spacy_7symbols_Person_psor_two,
  __pyx_e_5spacy_7symbols_Person_psor_three,
  __pyx_e_5spacy_7symbols_Person_zero,
  __pyx_e_5spacy_7symbols_Person_four,
  __pyx_e_5spacy_7symbols_Polite_inf,
  __pyx_e_5spacy_7symbols_Polite_pol,
  __pyx_e_5spacy_7symbols_Polite_abs_inf,
  __pyx_e_5spacy_7symbols_Polite_abs_pol,
  __pyx_e_5spacy_7symbols_Polite_erg_inf,
  __pyx_e_5spacy_7symbols_Polite_erg_pol,
  __pyx_e_5spacy_7symbols_Polite_dat_inf,
  __pyx_e_5spacy_7symbols_Polite_dat_pol,
  __pyx_e_5spacy_7symbols_Polite_infm,
  __pyx_e_5spacy_7symbols_Polite_form,
  __pyx_e_5spacy_7symbols_Polite_form_elev,
  __pyx_e_5spacy_7symbols_Polite_form_humb,
  __pyx_e_5spacy_7symbols_Prefix_yes,
  __pyx_e_5spacy_7symbols_PrepCase_npr,
  __pyx_e_5spacy_7symbols_PrepCase_pre,
  __pyx_e_5spacy_7symbols_PunctSide_ini,
  __pyx_e_5spacy_7symbols_PunctSide_fin,
  __pyx_e_5spacy_7symbols_PunctType_peri,
  __pyx_e_5spacy_7symbols_PunctType_qest,
  __pyx_e_5spacy_7symbols_PunctType_excl,
  __pyx_e_5spacy_7symbols_PunctType_quot,
  __pyx_e_5spacy_7symbols_PunctType_brck,
  __pyx_e_5spacy_7symbols_PunctType_comm,
  __pyx_e_5spacy_7symbols_PunctType_colo,
  __pyx_e_5spacy_7symbols_PunctType_semi,
  __pyx_e_5spacy_7symbols_PunctType_dash,
  __pyx_e_5spacy_7symbols_Style_arch,
  __pyx_e_5spacy_7symbols_Style_rare,
  __pyx_e_5spacy_7symbols_Style_poet,
  __pyx_e_5spacy_7symbols_Style_norm,
  __pyx_e_5spacy_7symbols_Style_coll,
  __pyx_e_5spacy_7symbols_Style_vrnc,
  __pyx_e_5spacy_7symbols_Style_sing,
  __pyx_e_5spacy_7symbols_Style_expr,
  __pyx_e_5spacy_7symbols_Style_derg,
  __pyx_e_5spacy_7symbols_Style_vulg,
  __pyx_e_5spacy_7symbols_Style_yes,
  __pyx_e_5spacy_7symbols_StyleVariant_styleShort,
  __pyx_e_5spacy_7symbols_StyleVariant_styleBound,
  __pyx_e_5spacy_7symbols_VerbType_aux,
  __pyx_e_5spacy_7symbols_VerbType_cop,
  __pyx_e_5spacy_7symbols_VerbType_mod,
  __pyx_e_5spacy_7symbols_VerbType_light,
  __pyx_e_5spacy_7symbols_PERSON,
  __pyx_e_5spacy_7symbols_NORP,
  __pyx_e_5spacy_7symbols_FACILITY,
  __pyx_e_5spacy_7symbols_ORG,
  __pyx_e_5spacy_7symbols_GPE,
  __pyx_e_5spacy_7symbols_LOC,
  __pyx_e_5spacy_7symbols_PRODUCT,
  __pyx_e_5spacy_7symbols_EVENT,
  __pyx_e_5spacy_7symbols_WORK_OF_ART,
  __pyx_e_5spacy_7symbols_LANGUAGE,
  __pyx_e_5spacy_7symbols_LAW,
  __pyx_e_5spacy_7symbols_DATE,
  __pyx_e_5spacy_7symbols_TIME,
  __pyx_e_5spacy_7symbols_PERCENT,
  __pyx_e_5spacy_7symbols_MONEY,
  __pyx_e_5spacy_7symbols_QUANTITY,
  __pyx_e_5spacy_7symbols_ORDINAL,
  __pyx_e_5spacy_7symbols_CARDINAL,
  __pyx_e_5spacy_7symbols_acomp,
  __pyx_e_5spacy_7symbols_advcl,
  __pyx_e_5spacy_7symbols_advmod,
  __pyx_e_5spacy_7symbols_agent,
  __pyx_e_5spacy_7symbols_amod,
  __pyx_e_5spacy_7symbols_appos,
  __pyx_e_5spacy_7symbols_attr,
  __pyx_e_5spacy_7symbols_aux,
  __pyx_e_5spacy_7symbols_auxpass,
  __pyx_e_5spacy_7symbols_cc,
  __pyx_e_5spacy_7symbols_ccomp,
  __pyx_e_5spacy_7symbols_complm,
  __pyx_e_5spacy_7symbols_conj,
  __pyx_e_5spacy_7symbols_cop,
  __pyx_e_5spacy_7symbols_csubj,
  __pyx_e_5spacy_7symbols_csubjpass,
  __pyx_e_5spacy_7symbols_dep,
  __pyx_e_5spacy_7symbols_det,
  __pyx_e_5spacy_7symbols_dobj,
  __pyx_e_5spacy_7symbols_expl,
  __pyx_e_5spacy_7symbols_hmod,
  __pyx_e_5spacy_7symbols_hyph,
  __pyx_e_5spacy_7symbols_infmod,
  __pyx_e_5spacy_7symbols_intj,
  __pyx_e_5spacy_7symbols_iobj,
  __pyx_e_5spacy_7symbols_mark,
  __pyx_e_5spacy_7symbols_meta,
  __pyx_e_5spacy_7symbols_neg,
  __pyx_e_5spacy_7symbols_nmod,
  __pyx_e_5spacy_7symbols_nn,
  __pyx_e_5spacy_7symbols_npadvmod,
  __pyx_e_5spacy_7symbols_nsubj,
  __pyx_e_5spacy_7symbols_nsubjpass,
  __pyx_e_5spacy_7symbols_num,
  __pyx_e_5spacy_7symbols_number,
  __pyx_e_5spacy_7symbols_oprd,
  __pyx_e_5spacy_7symbols_obj,
  __pyx_e_5spacy_7symbols_obl,
  __pyx_e_5spacy_7symbols_parataxis,
  __pyx_e_5spacy_7symbols_partmod,
  __pyx_e_5spacy_7symbols_pcomp,
  __pyx_e_5spacy_7symbols_pobj,
  __pyx_e_5spacy_7symbols_poss,
  __pyx_e_5spacy_7symbols_possessive,
  __pyx_e_5spacy_7symbols_preconj,
  __pyx_e_5spacy_7symbols_prep,
  __pyx_e_5spacy_7symbols_prt,
  __pyx_e_5spacy_7symbols_punct,
  __pyx_e_5spacy_7symbols_quantmod,
  __pyx_e_5spacy_7symbols_relcl,
  __pyx_e_5spacy_7symbols_rcmod,
  __pyx_e_5spacy_7symbols_root,
  __pyx_e_5spacy_7symbols_xcomp,
  __pyx_e_5spacy_7symbols_acl,
  __pyx_e_5spacy_7symbols_ENT_KB_ID,
  __pyx_e_5spacy_7symbols_ENT_ID,
  __pyx_e_5spacy_7symbols_IDX
};

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(enum __pyx_t_5spacy_7symbols_symbol_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* Globals.proto */
static PyObject* __Pyx_Globals(void);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'spacy.symbols' */
#define __Pyx_MODULE_NAME "spacy.symbols"
extern int __pyx_module_is_main_spacy__symbols;
int __pyx_module_is_main_spacy__symbols = 0;

/* Implementation of 'spacy.symbols' */
static PyObject *__pyx_builtin_sorted;
static const char __pyx_k_[] = "";
static const char __pyx_k_X[] = "X";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_ID[] = "ID";
static const char __pyx_k_cc[] = "cc";
static const char __pyx_k_it[] = "it";
static const char __pyx_k_nn[] = "nn";
static const char __pyx_k_ADJ[] = "ADJ";
static const char __pyx_k_ADP[] = "ADP";
static const char __pyx_k_ADV[] = "ADV";
static const char __pyx_k_AUX[] = "AUX";
static const char __pyx_k_DEP[] = "DEP";
static const char __pyx_k_DET[] = "DET";
static const char __pyx_k_EOL[] = "EOL";
static const char __pyx_k_GPE[] = "GPE";
static const char __pyx_k_IDS[] = "IDS";
static const char __pyx_k_IDX[] = "IDX";
static const char __pyx_k_LAW[] = "LAW";
static const char __pyx_k_LOC[] = "LOC";
static const char __pyx_k_NUM[] = "NUM";
static const char __pyx_k_ORG[] = "ORG";
static const char __pyx_k_POS[] = "POS";
static const char __pyx_k_SYM[] = "SYM";
static const char __pyx_k_TAG[] = "TAG";
static const char __pyx_k_acl[] = "acl";
static const char __pyx_k_aux[] = "aux";
static const char __pyx_k_cop[] = "cop";
static const char __pyx_k_dep[] = "dep";
static const char __pyx_k_det[] = "det";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_neg[] = "neg";
static const char __pyx_k_num[] = "num";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_obl[] = "obl";
static const char __pyx_k_prt[] = "prt";
static const char __pyx_k_CONJ[] = "CONJ";
static const char __pyx_k_DATE[] = "DATE";
static const char __pyx_k_HEAD[] = "HEAD";
static const char __pyx_k_INTJ[] = "INTJ";
static const char __pyx_k_LANG[] = "LANG";
static const char __pyx_k_NORM[] = "NORM";
static const char __pyx_k_NORP[] = "NORP";
static const char __pyx_k_NOUN[] = "NOUN";
static const char __pyx_k_ORTH[] = "ORTH";
static const char __pyx_k_PART[] = "PART";
static const char __pyx_k_PROB[] = "PROB";
static const char __pyx_k_PRON[] = "PRON";
static const char __pyx_k_TIME[] = "TIME";
static const char __pyx_k_VERB[] = "VERB";
static const char __pyx_k_amod[] = "amod";
static const char __pyx_k_attr[] = "attr";
static const char __pyx_k_conj[] = "conj";
static const char __pyx_k_dobj[] = "dobj";
static const char __pyx_k_expl[] = "expl";
static const char __pyx_k_hmod[] = "hmod";
static const char __pyx_k_hyph[] = "hyph";
static const char __pyx_k_intj[] = "intj";
static const char __pyx_k_iobj[] = "iobj";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mark[] = "mark";
static const char __pyx_k_meta[] = "meta";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_nmod[] = "nmod";
static const char __pyx_k_oprd[] = "oprd";
static const char __pyx_k_pobj[] = "pobj";
static const char __pyx_k_poss[] = "poss";
static const char __pyx_k_prep[] = "prep";
static const char __pyx_k_root[] = "root";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_CCONJ[] = "CCONJ";
static const char __pyx_k_EVENT[] = "EVENT";
static const char __pyx_k_LEMMA[] = "LEMMA";
static const char __pyx_k_LOWER[] = "LOWER";
static const char __pyx_k_MONEY[] = "MONEY";
static const char __pyx_k_NAMES[] = "NAMES";
static const char __pyx_k_PROPN[] = "PROPN";
static const char __pyx_k_PUNCT[] = "PUNCT";
static const char __pyx_k_SCONJ[] = "SCONJ";
static const char __pyx_k_SHAPE[] = "SHAPE";
static const char __pyx_k_SPACE[] = "SPACE";
static const char __pyx_k_SPACY[] = "SPACY";
static const char __pyx_k_acomp[] = "acomp";
static const char __pyx_k_advcl[] = "advcl";
static const char __pyx_k_agent[] = "agent";
static const char __pyx_k_appos[] = "appos";
static const char __pyx_k_ccomp[] = "ccomp";
static const char __pyx_k_csubj[] = "csubj";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_nsubj[] = "nsubj";
static const char __pyx_k_pcomp[] = "pcomp";
static const char __pyx_k_punct[] = "punct";
static const char __pyx_k_rcmod[] = "rcmod";
static const char __pyx_k_relcl[] = "relcl";
static const char __pyx_k_xcomp[] = "xcomp";
static const char __pyx_k_ENT_ID[] = "ENT_ID";
static const char __pyx_k_FLAG19[] = "FLAG19";
static const char __pyx_k_FLAG20[] = "FLAG20";
static const char __pyx_k_FLAG21[] = "FLAG21";
static const char __pyx_k_FLAG22[] = "FLAG22";
static const char __pyx_k_FLAG23[] = "FLAG23";
static const char __pyx_k_FLAG24[] = "FLAG24";
static const char __pyx_k_FLAG25[] = "FLAG25";
static const char __pyx_k_FLAG26[] = "FLAG26";
static const char __pyx_k_FLAG27[] = "FLAG27";
static const char __pyx_k_FLAG28[] = "FLAG28";
static const char __pyx_k_FLAG29[] = "FLAG29";
static const char __pyx_k_FLAG30[] = "FLAG30";
static const char __pyx_k_FLAG31[] = "FLAG31";
static const char __pyx_k_FLAG32[] = "FLAG32";
static const char __pyx_k_FLAG33[] = "FLAG33";
static const char __pyx_k_FLAG34[] = "FLAG34";
static const char __pyx_k_FLAG35[] = "FLAG35";
static const char __pyx_k_FLAG36[] = "FLAG36";
static const char __pyx_k_FLAG37[] = "FLAG37";
static const char __pyx_k_FLAG38[] = "FLAG38";
static const char __pyx_k_FLAG39[] = "FLAG39";
static const char __pyx_k_FLAG40[] = "FLAG40";
static const char __pyx_k_FLAG41[] = "FLAG41";
static const char __pyx_k_FLAG42[] = "FLAG42";
static const char __pyx_k_FLAG43[] = "FLAG43";
static const char __pyx_k_FLAG44[] = "FLAG44";
static const char __pyx_k_FLAG45[] = "FLAG45";
static const char __pyx_k_FLAG46[] = "FLAG46";
static const char __pyx_k_FLAG47[] = "FLAG47";
static const char __pyx_k_FLAG48[] = "FLAG48";
static const char __pyx_k_FLAG49[] = "FLAG49";
static const char __pyx_k_FLAG50[] = "FLAG50";
static const char __pyx_k_FLAG51[] = "FLAG51";
static const char __pyx_k_FLAG52[] = "FLAG52";
static const char __pyx_k_FLAG53[] = "FLAG53";
static const char __pyx_k_FLAG54[] = "FLAG54";
static const char __pyx_k_FLAG55[] = "FLAG55";
static const char __pyx_k_FLAG56[] = "FLAG56";
static const char __pyx_k_FLAG57[] = "FLAG57";
static const char __pyx_k_FLAG58[] = "FLAG58";
static const char __pyx_k_FLAG59[] = "FLAG59";
static const char __pyx_k_FLAG60[] = "FLAG60";
static const char __pyx_k_FLAG61[] = "FLAG61";
static const char __pyx_k_FLAG62[] = "FLAG62";
static const char __pyx_k_FLAG63[] = "FLAG63";
static const char __pyx_k_LENGTH[] = "LENGTH";
static const char __pyx_k_Mood_n[] = "Mood_n";
static const char __pyx_k_PERSON[] = "PERSON";
static const char __pyx_k_PREFIX[] = "PREFIX";
static const char __pyx_k_PRON_2[] = "-PRON-";
static const char __pyx_k_SUFFIX[] = "SUFFIX";
static const char __pyx_k_advmod[] = "advmod";
static const char __pyx_k_complm[] = "complm";
static const char __pyx_k_infmod[] = "infmod";
static const char __pyx_k_number[] = "number";
static const char __pyx_k_sorted[] = "sorted";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_CLUSTER[] = "CLUSTER";
static const char __pyx_k_ENT_IOB[] = "ENT_IOB";
static const char __pyx_k_IS_STOP[] = "IS_STOP";
static const char __pyx_k_ORDINAL[] = "ORDINAL";
static const char __pyx_k_PERCENT[] = "PERCENT";
static const char __pyx_k_PRODUCT[] = "PRODUCT";
static const char __pyx_k_auxpass[] = "auxpass";
static const char __pyx_k_partmod[] = "partmod";
static const char __pyx_k_preconj[] = "preconj";
static const char __pyx_k_Abbr_yes[] = "Abbr_yes";
static const char __pyx_k_CARDINAL[] = "CARDINAL";
static const char __pyx_k_Case_abe[] = "Case_abe";
static const char __pyx_k_Case_abl[] = "Case_abl";
static const char __pyx_k_Case_abs[] = "Case_abs";
static const char __pyx_k_Case_acc[] = "Case_acc";
static const char __pyx_k_Case_ade[] = "Case_ade";
static const char __pyx_k_Case_all[] = "Case_all";
static const char __pyx_k_Case_cau[] = "Case_cau";
static const char __pyx_k_Case_cmp[] = "Case_cmp";
static const char __pyx_k_Case_com[] = "Case_com";
static const char __pyx_k_Case_dat[] = "Case_dat";
static const char __pyx_k_Case_del[] = "Case_del";
static const char __pyx_k_Case_dis[] = "Case_dis";
static const char __pyx_k_Case_ela[] = "Case_ela";
static const char __pyx_k_Case_equ[] = "Case_equ";
static const char __pyx_k_Case_ess[] = "Case_ess";
static const char __pyx_k_Case_gen[] = "Case_gen";
static const char __pyx_k_Case_ill[] = "Case_ill";
static const char __pyx_k_Case_ine[] = "Case_ine";
static const char __pyx_k_Case_ins[] = "Case_ins";
static const char __pyx_k_Case_lat[] = "Case_lat";
static const char __pyx_k_Case_loc[] = "Case_loc";
static const char __pyx_k_Case_nom[] = "Case_nom";
static const char __pyx_k_Case_par[] = "Case_par";
static const char __pyx_k_Case_sub[] = "Case_sub";
static const char __pyx_k_Case_sup[] = "Case_sup";
static const char __pyx_k_Case_tem[] = "Case_tem";
static const char __pyx_k_Case_ter[] = "Case_ter";
static const char __pyx_k_Case_tra[] = "Case_tra";
static const char __pyx_k_Case_voc[] = "Case_voc";
static const char __pyx_k_ENT_TYPE[] = "ENT_TYPE";
static const char __pyx_k_Echo_ech[] = "Echo_ech";
static const char __pyx_k_Echo_rdp[] = "Echo_rdp";
static const char __pyx_k_FACILITY[] = "FACILITY";
static const char __pyx_k_Hyph_yes[] = "Hyph_yes";
static const char __pyx_k_IS_ALPHA[] = "IS_ALPHA";
static const char __pyx_k_IS_ASCII[] = "IS_ASCII";
static const char __pyx_k_IS_DIGIT[] = "IS_DIGIT";
static const char __pyx_k_IS_LOWER[] = "IS_LOWER";
static const char __pyx_k_IS_PUNCT[] = "IS_PUNCT";
static const char __pyx_k_IS_QUOTE[] = "IS_QUOTE";
static const char __pyx_k_IS_SPACE[] = "IS_SPACE";
static const char __pyx_k_IS_TITLE[] = "IS_TITLE";
static const char __pyx_k_IS_UPPER[] = "IS_UPPER";
static const char __pyx_k_LANGUAGE[] = "LANGUAGE";
static const char __pyx_k_LIKE_NUM[] = "LIKE_NUM";
static const char __pyx_k_LIKE_URL[] = "LIKE_URL";
static const char __pyx_k_Mood_adm[] = "Mood_adm";
static const char __pyx_k_Mood_cnd[] = "Mood_cnd";
static const char __pyx_k_Mood_imp[] = "Mood_imp";
static const char __pyx_k_Mood_ind[] = "Mood_ind";
static const char __pyx_k_Mood_opt[] = "Mood_opt";
static const char __pyx_k_Mood_pot[] = "Mood_pot";
static const char __pyx_k_Mood_prp[] = "Mood_prp";
static const char __pyx_k_Mood_sub[] = "Mood_sub";
static const char __pyx_k_Poss_yes[] = "Poss_yes";
static const char __pyx_k_QUANTITY[] = "QUANTITY";
static const char __pyx_k_npadvmod[] = "npadvmod";
static const char __pyx_k_quantmod[] = "quantmod";
static const char __pyx_k_ENT_KB_ID[] = "ENT_KB_ID";
static const char __pyx_k_Style_yes[] = "Style_yes";
static const char __pyx_k_Tense_fut[] = "Tense_fut";
static const char __pyx_k_Tense_imp[] = "Tense_imp";
static const char __pyx_k_Voice_act[] = "Voice_act";
static const char __pyx_k_Voice_cau[] = "Voice_cau";
static const char __pyx_k_Voice_dir[] = "Voice_dir";
static const char __pyx_k_Voice_int[] = "Voice_int";
static const char __pyx_k_Voice_inv[] = "Voice_inv";
static const char __pyx_k_Voice_mid[] = "Voice_mid";
static const char __pyx_k_csubjpass[] = "csubjpass";
static const char __pyx_k_nsubjpass[] = "nsubjpass";
static const char __pyx_k_parataxis[] = "parataxis";
static const char __pyx_k_sort_nums[] = "sort_nums";
static const char __pyx_k_AdvType_ex[] = "AdvType_ex";
static const char __pyx_k_Aspect_hab[] = "Aspect_hab";
static const char __pyx_k_Aspect_imp[] = "Aspect_imp";
static const char __pyx_k_Aspect_mod[] = "Aspect_mod";
static const char __pyx_k_Degree_abs[] = "Degree_abs";
static const char __pyx_k_Degree_cmp[] = "Degree_cmp";
static const char __pyx_k_Degree_com[] = "Degree_com";
static const char __pyx_k_Degree_dim[] = "Degree_dim";
static const char __pyx_k_Degree_equ[] = "Degree_equ";
static const char __pyx_k_Degree_pos[] = "Degree_pos";
static const char __pyx_k_Degree_sup[] = "Degree_sup";
static const char __pyx_k_Gender_com[] = "Gender_com";
static const char __pyx_k_Gender_fem[] = "Gender_fem";
static const char __pyx_k_IS_BRACKET[] = "IS_BRACKET";
static const char __pyx_k_LIKE_EMAIL[] = "LIKE_EMAIL";
static const char __pyx_k_Number_com[] = "Number_com";
static const char __pyx_k_Number_inv[] = "Number_inv";
static const char __pyx_k_Number_tri[] = "Number_tri";
static const char __pyx_k_PRON_LEMMA[] = "PRON_LEMMA";
static const char __pyx_k_Person_one[] = "Person_one";
static const char __pyx_k_Person_two[] = "Person_two";
static const char __pyx_k_Polite_inf[] = "Polite_inf";
static const char __pyx_k_Polite_pol[] = "Polite_pol";
static const char __pyx_k_Prefix_yes[] = "Prefix_yes";
static const char __pyx_k_Reflex_yes[] = "Reflex_yes";
static const char __pyx_k_SENT_START[] = "SENT_START";
static const char __pyx_k_Style_arch[] = "Style_arch";
static const char __pyx_k_Style_coll[] = "Style_coll";
static const char __pyx_k_Style_derg[] = "Style_derg";
static const char __pyx_k_Style_expr[] = "Style_expr";
static const char __pyx_k_Style_norm[] = "Style_norm";
static const char __pyx_k_Style_poet[] = "Style_poet";
static const char __pyx_k_Style_rare[] = "Style_rare";
static const char __pyx_k_Style_sing[] = "Style_sing";
static const char __pyx_k_Style_vrnc[] = "Style_vrnc";
static const char __pyx_k_Style_vulg[] = "Style_vulg";
static const char __pyx_k_Tense_past[] = "Tense_past";
static const char __pyx_k_Tense_pres[] = "Tense_pres";
static const char __pyx_k_Voice_pass[] = "Voice_pass";
static const char __pyx_k_possessive[] = "possessive";
static const char __pyx_k_AdpType_voc[] = "AdpType_voc";
static const char __pyx_k_AdvType_cau[] = "AdvType_cau";
static const char __pyx_k_AdvType_deg[] = "AdvType_deg";
static const char __pyx_k_AdvType_loc[] = "AdvType_loc";
static const char __pyx_k_AdvType_man[] = "AdvType_man";
static const char __pyx_k_AdvType_mod[] = "AdvType_mod";
static const char __pyx_k_AdvType_sta[] = "AdvType_sta";
static const char __pyx_k_AdvType_tim[] = "AdvType_tim";
static const char __pyx_k_Animacy_hum[] = "Animacy_hum";
static const char __pyx_k_Aspect_freq[] = "Aspect_freq";
static const char __pyx_k_Aspect_iter[] = "Aspect_iter";
static const char __pyx_k_Aspect_none[] = "Aspect_none";
static const char __pyx_k_Aspect_perf[] = "Aspect_perf";
static const char __pyx_k_Degree_comp[] = "Degree_comp";
static const char __pyx_k_Degree_none[] = "Degree_none";
static const char __pyx_k_Evident_nfh[] = "Evident_nfh";
static const char __pyx_k_Foreign_yes[] = "Foreign_yes";
static const char __pyx_k_Gender_masc[] = "Gender_masc";
static const char __pyx_k_Gender_neut[] = "Gender_neut";
static const char __pyx_k_IS_CURRENCY[] = "IS_CURRENCY";
static const char __pyx_k_InfForm_one[] = "InfForm_one";
static const char __pyx_k_InfForm_two[] = "InfForm_two";
static const char __pyx_k_NumType_gen[] = "NumType_gen";
static const char __pyx_k_NumType_ord[] = "NumType_ord";
static const char __pyx_k_Number_dual[] = "Number_dual";
static const char __pyx_k_Number_grpa[] = "Number_grpa";
static const char __pyx_k_Number_grpl[] = "Number_grpl";
static const char __pyx_k_Number_none[] = "Number_none";
static const char __pyx_k_Number_pauc[] = "Number_pauc";
static const char __pyx_k_Number_plur[] = "Number_plur";
static const char __pyx_k_Number_ptan[] = "Number_ptan";
static const char __pyx_k_Number_sing[] = "Number_sing";
static const char __pyx_k_Person_four[] = "Person_four";
static const char __pyx_k_Person_none[] = "Person_none";
static const char __pyx_k_Person_zero[] = "Person_zero";
static const char __pyx_k_Polite_form[] = "Polite_form";
static const char __pyx_k_Polite_infm[] = "Polite_infm";
static const char __pyx_k_Voice_antip[] = "Voice_antip";
static const char __pyx_k_WORK_OF_ART[] = "WORK_OF_ART";
static const char __pyx_k_symbols_pyx[] = "symbols.pyx";
static const char __pyx_k_AdpType_circ[] = "AdpType_circ";
static const char __pyx_k_AdpType_post[] = "AdpType_post";
static const char __pyx_k_AdpType_prep[] = "AdpType_prep";
static const char __pyx_k_Animacy_anim[] = "Animacy_anim";
static const char __pyx_k_Animacy_inam[] = "Animacy_inam";
static const char __pyx_k_Animacy_nhum[] = "Animacy_nhum";
static const char __pyx_k_Definite_def[] = "Definite_def";
static const char __pyx_k_Definite_ind[] = "Definite_ind";
static const char __pyx_k_Definite_red[] = "Definite_red";
static const char __pyx_k_Definite_two[] = "Definite_two";
static const char __pyx_k_NameType_com[] = "NameType_com";
static const char __pyx_k_NameType_geo[] = "NameType_geo";
static const char __pyx_k_NameType_giv[] = "NameType_giv";
static const char __pyx_k_NameType_nat[] = "NameType_nat";
static const char __pyx_k_NameType_oth[] = "NameType_oth";
static const char __pyx_k_NameType_pro[] = "NameType_pro";
static const char __pyx_k_NameType_prs[] = "NameType_prs";
static const char __pyx_k_NameType_sur[] = "NameType_sur";
static const char __pyx_k_Negative_neg[] = "Negative_neg";
static const char __pyx_k_Negative_pos[] = "Negative_pos";
static const char __pyx_k_Negative_yes[] = "Negative_yes";
static const char __pyx_k_NounType_com[] = "NounType_com";
static const char __pyx_k_NumForm_word[] = "NumForm_word";
static const char __pyx_k_NumType_card[] = "NumType_card";
static const char __pyx_k_NumType_dist[] = "NumType_dist";
static const char __pyx_k_NumType_frac[] = "NumType_frac";
static const char __pyx_k_NumType_mult[] = "NumType_mult";
static const char __pyx_k_NumType_none[] = "NumType_none";
static const char __pyx_k_NumType_sets[] = "NumType_sets";
static const char __pyx_k_NumValue_one[] = "NumValue_one";
static const char __pyx_k_NumValue_two[] = "NumValue_two";
static const char __pyx_k_Number_count[] = "Number_count";
static const char __pyx_k_PartForm_agt[] = "PartForm_agt";
static const char __pyx_k_PartForm_neg[] = "PartForm_neg";
static const char __pyx_k_PartType_emp[] = "PartType_emp";
static const char __pyx_k_PartType_inf[] = "PartType_inf";
static const char __pyx_k_PartType_mod[] = "PartType_mod";
static const char __pyx_k_PartType_res[] = "PartType_res";
static const char __pyx_k_PartType_vbp[] = "PartType_vbp";
static const char __pyx_k_Person_three[] = "Person_three";
static const char __pyx_k_Polarity_neg[] = "Polarity_neg";
static const char __pyx_k_Polarity_pos[] = "Polarity_pos";
static const char __pyx_k_PrepCase_npr[] = "PrepCase_npr";
static const char __pyx_k_PrepCase_pre[] = "PrepCase_pre";
static const char __pyx_k_PronType_art[] = "PronType_art";
static const char __pyx_k_PronType_dem[] = "PronType_dem";
static const char __pyx_k_PronType_emp[] = "PronType_emp";
static const char __pyx_k_PronType_exc[] = "PronType_exc";
static const char __pyx_k_PronType_ind[] = "PronType_ind";
static const char __pyx_k_PronType_int[] = "PronType_int";
static const char __pyx_k_PronType_neg[] = "PronType_neg";
static const char __pyx_k_PronType_prs[] = "PronType_prs";
static const char __pyx_k_PronType_rcp[] = "PronType_rcp";
static const char __pyx_k_PronType_rel[] = "PronType_rel";
static const char __pyx_k_PronType_tot[] = "PronType_tot";
static const char __pyx_k_VerbForm_fin[] = "VerbForm_fin";
static const char __pyx_k_VerbForm_gdv[] = "VerbForm_gdv";
static const char __pyx_k_VerbForm_ger[] = "VerbForm_ger";
static const char __pyx_k_VerbForm_inf[] = "VerbForm_inf";
static const char __pyx_k_VerbForm_sup[] = "VerbForm_sup";
static const char __pyx_k_VerbType_aux[] = "VerbType_aux";
static const char __pyx_k_VerbType_cop[] = "VerbType_cop";
static const char __pyx_k_VerbType_mod[] = "VerbType_mod";
static const char __pyx_k_AdvType_adadj[] = "AdvType_adadj";
static const char __pyx_k_ConjType_comp[] = "ConjType_comp";
static const char __pyx_k_ConjType_oper[] = "ConjType_oper";
static const char __pyx_k_Definite_cons[] = "Definite_cons";
static const char __pyx_k_Definite_spec[] = "Definite_spec";
static const char __pyx_k_Derivation_ja[] = "Derivation_ja";
static const char __pyx_k_Derivation_vs[] = "Derivation_vs";
static const char __pyx_k_IS_LEFT_PUNCT[] = "IS_LEFT_PUNCT";
static const char __pyx_k_InfForm_three[] = "InfForm_three";
static const char __pyx_k_NounType_prop[] = "NounType_prop";
static const char __pyx_k_NumForm_digit[] = "NumForm_digit";
static const char __pyx_k_NumForm_roman[] = "NumForm_roman";
static const char __pyx_k_PartForm_past[] = "PartForm_past";
static const char __pyx_k_PartForm_pres[] = "PartForm_pres";
static const char __pyx_k_PronType_clit[] = "PronType_clit";
static const char __pyx_k_PunctSide_fin[] = "PunctSide_fin";
static const char __pyx_k_PunctSide_ini[] = "PunctSide_ini";
static const char __pyx_k_VerbForm_conv[] = "VerbForm_conv";
static const char __pyx_k_VerbForm_none[] = "VerbForm_none";
static const char __pyx_k_VerbForm_part[] = "VerbForm_part";
static const char __pyx_k_spacy_symbols[] = "spacy.symbols";
static const char __pyx_k_Derivation_sti[] = "Derivation_sti";
static const char __pyx_k_Derivation_ton[] = "Derivation_ton";
static const char __pyx_k_Gender_dat_fem[] = "Gender_dat_fem";
static const char __pyx_k_Gender_erg_fem[] = "Gender_erg_fem";
static const char __pyx_k_IS_RIGHT_PUNCT[] = "IS_RIGHT_PUNCT";
static const char __pyx_k_NounType_class[] = "NounType_class";
static const char __pyx_k_NumValue_three[] = "NumValue_three";
static const char __pyx_k_Person_abs_one[] = "Person_abs_one";
static const char __pyx_k_Person_abs_two[] = "Person_abs_two";
static const char __pyx_k_Person_dat_one[] = "Person_dat_one";
static const char __pyx_k_Person_dat_two[] = "Person_dat_two";
static const char __pyx_k_Person_erg_one[] = "Person_erg_one";
static const char __pyx_k_Person_erg_two[] = "Person_erg_two";
static const char __pyx_k_Polite_abs_inf[] = "Polite_abs_inf";
static const char __pyx_k_Polite_abs_pol[] = "Polite_abs_pol";
static const char __pyx_k_Polite_dat_inf[] = "Polite_dat_inf";
static const char __pyx_k_Polite_dat_pol[] = "Polite_dat_pol";
static const char __pyx_k_Polite_erg_inf[] = "Polite_erg_inf";
static const char __pyx_k_Polite_erg_pol[] = "Polite_erg_pol";
static const char __pyx_k_PunctType_brck[] = "PunctType_brck";
static const char __pyx_k_PunctType_colo[] = "PunctType_colo";
static const char __pyx_k_PunctType_comm[] = "PunctType_comm";
static const char __pyx_k_PunctType_dash[] = "PunctType_dash";
static const char __pyx_k_PunctType_excl[] = "PunctType_excl";
static const char __pyx_k_PunctType_peri[] = "PunctType_peri";
static const char __pyx_k_PunctType_qest[] = "PunctType_qest";
static const char __pyx_k_PunctType_quot[] = "PunctType_quot";
static const char __pyx_k_PunctType_semi[] = "PunctType_semi";
static const char __pyx_k_VerbForm_trans[] = "VerbForm_trans";
static const char __pyx_k_VerbForm_vnoun[] = "VerbForm_vnoun";
static const char __pyx_k_VerbType_light[] = "VerbType_light";
static const char __pyx_k_AdpType_comprep[] = "AdpType_comprep";
static const char __pyx_k_Connegative_yes[] = "Connegative_yes";
static const char __pyx_k_Derivation_inen[] = "Derivation_inen";
static const char __pyx_k_Derivation_ttaa[] = "Derivation_ttaa";
static const char __pyx_k_Foreign_foreign[] = "Foreign_foreign";
static const char __pyx_k_Foreign_fscript[] = "Foreign_fscript";
static const char __pyx_k_Foreign_tscript[] = "Foreign_tscript";
static const char __pyx_k_Gender_dat_masc[] = "Gender_dat_masc";
static const char __pyx_k_Gender_erg_masc[] = "Gender_erg_masc";
static const char __pyx_k_Gender_psor_fem[] = "Gender_psor_fem";
static const char __pyx_k_Number_abs_plur[] = "Number_abs_plur";
static const char __pyx_k_Number_abs_sing[] = "Number_abs_sing";
static const char __pyx_k_Number_dat_plur[] = "Number_dat_plur";
static const char __pyx_k_Number_dat_sing[] = "Number_dat_sing";
static const char __pyx_k_Number_erg_plur[] = "Number_erg_plur";
static const char __pyx_k_Number_erg_sing[] = "Number_erg_sing";
static const char __pyx_k_Person_psor_one[] = "Person_psor_one";
static const char __pyx_k_Person_psor_two[] = "Person_psor_two";
static const char __pyx_k_Derivation_minen[] = "Derivation_minen";
static const char __pyx_k_Derivation_ttain[] = "Derivation_ttain";
static const char __pyx_k_Gender_psor_masc[] = "Gender_psor_masc";
static const char __pyx_k_Gender_psor_neut[] = "Gender_psor_neut";
static const char __pyx_k_Number_psee_plur[] = "Number_psee_plur";
static const char __pyx_k_Number_psee_sing[] = "Number_psee_sing";
static const char __pyx_k_Number_psor_plur[] = "Number_psor_plur";
static const char __pyx_k_Number_psor_sing[] = "Number_psor_sing";
static const char __pyx_k_Person_abs_three[] = "Person_abs_three";
static const char __pyx_k_Person_dat_three[] = "Person_dat_three";
static const char __pyx_k_Person_erg_three[] = "Person_erg_three";
static const char __pyx_k_Polite_form_elev[] = "Polite_form_elev";
static const char __pyx_k_Polite_form_humb[] = "Polite_form_humb";
static const char __pyx_k_PronType_advPart[] = "PronType_advPart";
static const char __pyx_k_PronType_default[] = "PronType_default";
static const char __pyx_k_VerbForm_partFut[] = "VerbForm_partFut";
static const char __pyx_k_Derivation_lainen[] = "Derivation_lainen";
static const char __pyx_k_IS_OOV_DEPRECATED[] = "IS_OOV_DEPRECATED";
static const char __pyx_k_Person_psor_three[] = "Person_psor_three";
static const char __pyx_k_VerbForm_partPast[] = "VerbForm_partPast";
static const char __pyx_k_VerbForm_partPres[] = "VerbForm_partPres";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_StyleVariant_styleBound[] = "StyleVariant_styleBound";
static const char __pyx_k_StyleVariant_styleShort[] = "StyleVariant_styleShort";
static PyObject *__pyx_kp_u_;
static PyObject *__pyx_n_u_ADJ;
static PyObject *__pyx_n_u_ADP;
static PyObject *__pyx_n_u_ADV;
static PyObject *__pyx_n_u_AUX;
static PyObject *__pyx_n_u_Abbr_yes;
static PyObject *__pyx_n_u_AdpType_circ;
static PyObject *__pyx_n_u_AdpType_comprep;
static PyObject *__pyx_n_u_AdpType_post;
static PyObject *__pyx_n_u_AdpType_prep;
static PyObject *__pyx_n_u_AdpType_voc;
static PyObject *__pyx_n_u_AdvType_adadj;
static PyObject *__pyx_n_u_AdvType_cau;
static PyObject *__pyx_n_u_AdvType_deg;
static PyObject *__pyx_n_u_AdvType_ex;
static PyObject *__pyx_n_u_AdvType_loc;
static PyObject *__pyx_n_u_AdvType_man;
static PyObject *__pyx_n_u_AdvType_mod;
static PyObject *__pyx_n_u_AdvType_sta;
static PyObject *__pyx_n_u_AdvType_tim;
static PyObject *__pyx_n_u_Animacy_anim;
static PyObject *__pyx_n_u_Animacy_hum;
static PyObject *__pyx_n_u_Animacy_inam;
static PyObject *__pyx_n_u_Animacy_nhum;
static PyObject *__pyx_n_u_Aspect_freq;
static PyObject *__pyx_n_u_Aspect_hab;
static PyObject *__pyx_n_u_Aspect_imp;
static PyObject *__pyx_n_u_Aspect_iter;
static PyObject *__pyx_n_u_Aspect_mod;
static PyObject *__pyx_n_u_Aspect_none;
static PyObject *__pyx_n_u_Aspect_perf;
static PyObject *__pyx_n_u_CARDINAL;
static PyObject *__pyx_n_u_CCONJ;
static PyObject *__pyx_n_u_CLUSTER;
static PyObject *__pyx_n_u_CONJ;
static PyObject *__pyx_n_u_Case_abe;
static PyObject *__pyx_n_u_Case_abl;
static PyObject *__pyx_n_u_Case_abs;
static PyObject *__pyx_n_u_Case_acc;
static PyObject *__pyx_n_u_Case_ade;
static PyObject *__pyx_n_u_Case_all;
static PyObject *__pyx_n_u_Case_cau;
static PyObject *__pyx_n_u_Case_cmp;
static PyObject *__pyx_n_u_Case_com;
static PyObject *__pyx_n_u_Case_dat;
static PyObject *__pyx_n_u_Case_del;
static PyObject *__pyx_n_u_Case_dis;
static PyObject *__pyx_n_u_Case_ela;
static PyObject *__pyx_n_u_Case_equ;
static PyObject *__pyx_n_u_Case_ess;
static PyObject *__pyx_n_u_Case_gen;
static PyObject *__pyx_n_u_Case_ill;
static PyObject *__pyx_n_u_Case_ine;
static PyObject *__pyx_n_u_Case_ins;
static PyObject *__pyx_n_u_Case_lat;
static PyObject *__pyx_n_u_Case_loc;
static PyObject *__pyx_n_u_Case_nom;
static PyObject *__pyx_n_u_Case_par;
static PyObject *__pyx_n_u_Case_sub;
static PyObject *__pyx_n_u_Case_sup;
static PyObject *__pyx_n_u_Case_tem;
static PyObject *__pyx_n_u_Case_ter;
static PyObject *__pyx_n_u_Case_tra;
static PyObject *__pyx_n_u_Case_voc;
static PyObject *__pyx_n_u_ConjType_comp;
static PyObject *__pyx_n_u_ConjType_oper;
static PyObject *__pyx_n_u_Connegative_yes;
static PyObject *__pyx_n_u_DATE;
static PyObject *__pyx_n_u_DEP;
static PyObject *__pyx_n_u_DET;
static PyObject *__pyx_n_u_Definite_cons;
static PyObject *__pyx_n_u_Definite_def;
static PyObject *__pyx_n_u_Definite_ind;
static PyObject *__pyx_n_u_Definite_red;
static PyObject *__pyx_n_u_Definite_spec;
static PyObject *__pyx_n_u_Definite_two;
static PyObject *__pyx_n_u_Degree_abs;
static PyObject *__pyx_n_u_Degree_cmp;
static PyObject *__pyx_n_u_Degree_com;
static PyObject *__pyx_n_u_Degree_comp;
static PyObject *__pyx_n_u_Degree_dim;
static PyObject *__pyx_n_u_Degree_equ;
static PyObject *__pyx_n_u_Degree_none;
static PyObject *__pyx_n_u_Degree_pos;
static PyObject *__pyx_n_u_Degree_sup;
static PyObject *__pyx_n_u_Derivation_inen;
static PyObject *__pyx_n_u_Derivation_ja;
static PyObject *__pyx_n_u_Derivation_lainen;
static PyObject *__pyx_n_u_Derivation_minen;
static PyObject *__pyx_n_u_Derivation_sti;
static PyObject *__pyx_n_u_Derivation_ton;
static PyObject *__pyx_n_u_Derivation_ttaa;
static PyObject *__pyx_n_u_Derivation_ttain;
static PyObject *__pyx_n_u_Derivation_vs;
static PyObject *__pyx_n_u_ENT_ID;
static PyObject *__pyx_n_u_ENT_IOB;
static PyObject *__pyx_n_u_ENT_KB_ID;
static PyObject *__pyx_n_u_ENT_TYPE;
static PyObject *__pyx_n_u_EOL;
static PyObject *__pyx_n_u_EVENT;
static PyObject *__pyx_n_u_Echo_ech;
static PyObject *__pyx_n_u_Echo_rdp;
static PyObject *__pyx_n_u_Evident_nfh;
static PyObject *__pyx_n_u_FACILITY;
static PyObject *__pyx_n_u_FLAG19;
static PyObject *__pyx_n_u_FLAG20;
static PyObject *__pyx_n_u_FLAG21;
static PyObject *__pyx_n_u_FLAG22;
static PyObject *__pyx_n_u_FLAG23;
static PyObject *__pyx_n_u_FLAG24;
static PyObject *__pyx_n_u_FLAG25;
static PyObject *__pyx_n_u_FLAG26;
static PyObject *__pyx_n_u_FLAG27;
static PyObject *__pyx_n_u_FLAG28;
static PyObject *__pyx_n_u_FLAG29;
static PyObject *__pyx_n_u_FLAG30;
static PyObject *__pyx_n_u_FLAG31;
static PyObject *__pyx_n_u_FLAG32;
static PyObject *__pyx_n_u_FLAG33;
static PyObject *__pyx_n_u_FLAG34;
static PyObject *__pyx_n_u_FLAG35;
static PyObject *__pyx_n_u_FLAG36;
static PyObject *__pyx_n_u_FLAG37;
static PyObject *__pyx_n_u_FLAG38;
static PyObject *__pyx_n_u_FLAG39;
static PyObject *__pyx_n_u_FLAG40;
static PyObject *__pyx_n_u_FLAG41;
static PyObject *__pyx_n_u_FLAG42;
static PyObject *__pyx_n_u_FLAG43;
static PyObject *__pyx_n_u_FLAG44;
static PyObject *__pyx_n_u_FLAG45;
static PyObject *__pyx_n_u_FLAG46;
static PyObject *__pyx_n_u_FLAG47;
static PyObject *__pyx_n_u_FLAG48;
static PyObject *__pyx_n_u_FLAG49;
static PyObject *__pyx_n_u_FLAG50;
static PyObject *__pyx_n_u_FLAG51;
static PyObject *__pyx_n_u_FLAG52;
static PyObject *__pyx_n_u_FLAG53;
static PyObject *__pyx_n_u_FLAG54;
static PyObject *__pyx_n_u_FLAG55;
static PyObject *__pyx_n_u_FLAG56;
static PyObject *__pyx_n_u_FLAG57;
static PyObject *__pyx_n_u_FLAG58;
static PyObject *__pyx_n_u_FLAG59;
static PyObject *__pyx_n_u_FLAG60;
static PyObject *__pyx_n_u_FLAG61;
static PyObject *__pyx_n_u_FLAG62;
static PyObject *__pyx_n_u_FLAG63;
static PyObject *__pyx_n_u_Foreign_foreign;
static PyObject *__pyx_n_u_Foreign_fscript;
static PyObject *__pyx_n_u_Foreign_tscript;
static PyObject *__pyx_n_u_Foreign_yes;
static PyObject *__pyx_n_u_GPE;
static PyObject *__pyx_n_u_Gender_com;
static PyObject *__pyx_n_u_Gender_dat_fem;
static PyObject *__pyx_n_u_Gender_dat_masc;
static PyObject *__pyx_n_u_Gender_erg_fem;
static PyObject *__pyx_n_u_Gender_erg_masc;
static PyObject *__pyx_n_u_Gender_fem;
static PyObject *__pyx_n_u_Gender_masc;
static PyObject *__pyx_n_u_Gender_neut;
static PyObject *__pyx_n_u_Gender_psor_fem;
static PyObject *__pyx_n_u_Gender_psor_masc;
static PyObject *__pyx_n_u_Gender_psor_neut;
static PyObject *__pyx_n_u_HEAD;
static PyObject *__pyx_n_u_Hyph_yes;
static PyObject *__pyx_n_u_ID;
static PyObject *__pyx_n_s_IDS;
static PyObject *__pyx_n_u_IDX;
static PyObject *__pyx_n_u_INTJ;
static PyObject *__pyx_n_u_IS_ALPHA;
static PyObject *__pyx_n_u_IS_ASCII;
static PyObject *__pyx_n_u_IS_BRACKET;
static PyObject *__pyx_n_u_IS_CURRENCY;
static PyObject *__pyx_n_u_IS_DIGIT;
static PyObject *__pyx_n_u_IS_LEFT_PUNCT;
static PyObject *__pyx_n_u_IS_LOWER;
static PyObject *__pyx_n_u_IS_OOV_DEPRECATED;
static PyObject *__pyx_n_u_IS_PUNCT;
static PyObject *__pyx_n_u_IS_QUOTE;
static PyObject *__pyx_n_u_IS_RIGHT_PUNCT;
static PyObject *__pyx_n_u_IS_SPACE;
static PyObject *__pyx_n_u_IS_STOP;
static PyObject *__pyx_n_u_IS_TITLE;
static PyObject *__pyx_n_u_IS_UPPER;
static PyObject *__pyx_n_u_InfForm_one;
static PyObject *__pyx_n_u_InfForm_three;
static PyObject *__pyx_n_u_InfForm_two;
static PyObject *__pyx_n_u_LANG;
static PyObject *__pyx_n_u_LANGUAGE;
static PyObject *__pyx_n_u_LAW;
static PyObject *__pyx_n_u_LEMMA;
static PyObject *__pyx_n_u_LENGTH;
static PyObject *__pyx_n_u_LIKE_EMAIL;
static PyObject *__pyx_n_u_LIKE_NUM;
static PyObject *__pyx_n_u_LIKE_URL;
static PyObject *__pyx_n_u_LOC;
static PyObject *__pyx_n_u_LOWER;
static PyObject *__pyx_n_u_MONEY;
static PyObject *__pyx_n_u_Mood_adm;
static PyObject *__pyx_n_u_Mood_cnd;
static PyObject *__pyx_n_u_Mood_imp;
static PyObject *__pyx_n_u_Mood_ind;
static PyObject *__pyx_n_u_Mood_n;
static PyObject *__pyx_n_u_Mood_opt;
static PyObject *__pyx_n_u_Mood_pot;
static PyObject *__pyx_n_u_Mood_prp;
static PyObject *__pyx_n_u_Mood_sub;
static PyObject *__pyx_n_s_NAMES;
static PyObject *__pyx_n_u_NORM;
static PyObject *__pyx_n_u_NORP;
static PyObject *__pyx_n_u_NOUN;
static PyObject *__pyx_n_u_NUM;
static PyObject *__pyx_n_u_NameType_com;
static PyObject *__pyx_n_u_NameType_geo;
static PyObject *__pyx_n_u_NameType_giv;
static PyObject *__pyx_n_u_NameType_nat;
static PyObject *__pyx_n_u_NameType_oth;
static PyObject *__pyx_n_u_NameType_pro;
static PyObject *__pyx_n_u_NameType_prs;
static PyObject *__pyx_n_u_NameType_sur;
static PyObject *__pyx_n_u_Negative_neg;
static PyObject *__pyx_n_u_Negative_pos;
static PyObject *__pyx_n_u_Negative_yes;
static PyObject *__pyx_n_u_NounType_class;
static PyObject *__pyx_n_u_NounType_com;
static PyObject *__pyx_n_u_NounType_prop;
static PyObject *__pyx_n_u_NumForm_digit;
static PyObject *__pyx_n_u_NumForm_roman;
static PyObject *__pyx_n_u_NumForm_word;
static PyObject *__pyx_n_u_NumType_card;
static PyObject *__pyx_n_u_NumType_dist;
static PyObject *__pyx_n_u_NumType_frac;
static PyObject *__pyx_n_u_NumType_gen;
static PyObject *__pyx_n_u_NumType_mult;
static PyObject *__pyx_n_u_NumType_none;
static PyObject *__pyx_n_u_NumType_ord;
static PyObject *__pyx_n_u_NumType_sets;
static PyObject *__pyx_n_u_NumValue_one;
static PyObject *__pyx_n_u_NumValue_three;
static PyObject *__pyx_n_u_NumValue_two;
static PyObject *__pyx_n_u_Number_abs_plur;
static PyObject *__pyx_n_u_Number_abs_sing;
static PyObject *__pyx_n_u_Number_com;
static PyObject *__pyx_n_u_Number_count;
static PyObject *__pyx_n_u_Number_dat_plur;
static PyObject *__pyx_n_u_Number_dat_sing;
static PyObject *__pyx_n_u_Number_dual;
static PyObject *__pyx_n_u_Number_erg_plur;
static PyObject *__pyx_n_u_Number_erg_sing;
static PyObject *__pyx_n_u_Number_grpa;
static PyObject *__pyx_n_u_Number_grpl;
static PyObject *__pyx_n_u_Number_inv;
static PyObject *__pyx_n_u_Number_none;
static PyObject *__pyx_n_u_Number_pauc;
static PyObject *__pyx_n_u_Number_plur;
static PyObject *__pyx_n_u_Number_psee_plur;
static PyObject *__pyx_n_u_Number_psee_sing;
static PyObject *__pyx_n_u_Number_psor_plur;
static PyObject *__pyx_n_u_Number_psor_sing;
static PyObject *__pyx_n_u_Number_ptan;
static PyObject *__pyx_n_u_Number_sing;
static PyObject *__pyx_n_u_Number_tri;
static PyObject *__pyx_n_u_ORDINAL;
static PyObject *__pyx_n_u_ORG;
static PyObject *__pyx_n_u_ORTH;
static PyObject *__pyx_n_u_PART;
static PyObject *__pyx_n_u_PERCENT;
static PyObject *__pyx_n_u_PERSON;
static PyObject *__pyx_n_u_POS;
static PyObject *__pyx_n_u_PREFIX;
static PyObject *__pyx_n_u_PROB;
static PyObject *__pyx_n_u_PRODUCT;
static PyObject *__pyx_n_u_PRON;
static PyObject *__pyx_kp_u_PRON_2;
static PyObject *__pyx_n_s_PRON_LEMMA;
static PyObject *__pyx_n_u_PROPN;
static PyObject *__pyx_n_u_PUNCT;
static PyObject *__pyx_n_u_PartForm_agt;
static PyObject *__pyx_n_u_PartForm_neg;
static PyObject *__pyx_n_u_PartForm_past;
static PyObject *__pyx_n_u_PartForm_pres;
static PyObject *__pyx_n_u_PartType_emp;
static PyObject *__pyx_n_u_PartType_inf;
static PyObject *__pyx_n_u_PartType_mod;
static PyObject *__pyx_n_u_PartType_res;
static PyObject *__pyx_n_u_PartType_vbp;
static PyObject *__pyx_n_u_Person_abs_one;
static PyObject *__pyx_n_u_Person_abs_three;
static PyObject *__pyx_n_u_Person_abs_two;
static PyObject *__pyx_n_u_Person_dat_one;
static PyObject *__pyx_n_u_Person_dat_three;
static PyObject *__pyx_n_u_Person_dat_two;
static PyObject *__pyx_n_u_Person_erg_one;
static PyObject *__pyx_n_u_Person_erg_three;
static PyObject *__pyx_n_u_Person_erg_two;
static PyObject *__pyx_n_u_Person_four;
static PyObject *__pyx_n_u_Person_none;
static PyObject *__pyx_n_u_Person_one;
static PyObject *__pyx_n_u_Person_psor_one;
static PyObject *__pyx_n_u_Person_psor_three;
static PyObject *__pyx_n_u_Person_psor_two;
static PyObject *__pyx_n_u_Person_three;
static PyObject *__pyx_n_u_Person_two;
static PyObject *__pyx_n_u_Person_zero;
static PyObject *__pyx_n_u_Polarity_neg;
static PyObject *__pyx_n_u_Polarity_pos;
static PyObject *__pyx_n_u_Polite_abs_inf;
static PyObject *__pyx_n_u_Polite_abs_pol;
static PyObject *__pyx_n_u_Polite_dat_inf;
static PyObject *__pyx_n_u_Polite_dat_pol;
static PyObject *__pyx_n_u_Polite_erg_inf;
static PyObject *__pyx_n_u_Polite_erg_pol;
static PyObject *__pyx_n_u_Polite_form;
static PyObject *__pyx_n_u_Polite_form_elev;
static PyObject *__pyx_n_u_Polite_form_humb;
static PyObject *__pyx_n_u_Polite_inf;
static PyObject *__pyx_n_u_Polite_infm;
static PyObject *__pyx_n_u_Polite_pol;
static PyObject *__pyx_n_u_Poss_yes;
static PyObject *__pyx_n_u_Prefix_yes;
static PyObject *__pyx_n_u_PrepCase_npr;
static PyObject *__pyx_n_u_PrepCase_pre;
static PyObject *__pyx_n_u_PronType_advPart;
static PyObject *__pyx_n_u_PronType_art;
static PyObject *__pyx_n_u_PronType_clit;
static PyObject *__pyx_n_u_PronType_default;
static PyObject *__pyx_n_u_PronType_dem;
static PyObject *__pyx_n_u_PronType_emp;
static PyObject *__pyx_n_u_PronType_exc;
static PyObject *__pyx_n_u_PronType_ind;
static PyObject *__pyx_n_u_PronType_int;
static PyObject *__pyx_n_u_PronType_neg;
static PyObject *__pyx_n_u_PronType_prs;
static PyObject *__pyx_n_u_PronType_rcp;
static PyObject *__pyx_n_u_PronType_rel;
static PyObject *__pyx_n_u_PronType_tot;
static PyObject *__pyx_n_u_PunctSide_fin;
static PyObject *__pyx_n_u_PunctSide_ini;
static PyObject *__pyx_n_u_PunctType_brck;
static PyObject *__pyx_n_u_PunctType_colo;
static PyObject *__pyx_n_u_PunctType_comm;
static PyObject *__pyx_n_u_PunctType_dash;
static PyObject *__pyx_n_u_PunctType_excl;
static PyObject *__pyx_n_u_PunctType_peri;
static PyObject *__pyx_n_u_PunctType_qest;
static PyObject *__pyx_n_u_PunctType_quot;
static PyObject *__pyx_n_u_PunctType_semi;
static PyObject *__pyx_n_u_QUANTITY;
static PyObject *__pyx_n_u_Reflex_yes;
static PyObject *__pyx_n_u_SCONJ;
static PyObject *__pyx_n_u_SENT_START;
static PyObject *__pyx_n_u_SHAPE;
static PyObject *__pyx_n_u_SPACE;
static PyObject *__pyx_n_u_SPACY;
static PyObject *__pyx_n_u_SUFFIX;
static PyObject *__pyx_n_u_SYM;
static PyObject *__pyx_n_u_StyleVariant_styleBound;
static PyObject *__pyx_n_u_StyleVariant_styleShort;
static PyObject *__pyx_n_u_Style_arch;
static PyObject *__pyx_n_u_Style_coll;
static PyObject *__pyx_n_u_Style_derg;
static PyObject *__pyx_n_u_Style_expr;
static PyObject *__pyx_n_u_Style_norm;
static PyObject *__pyx_n_u_Style_poet;
static PyObject *__pyx_n_u_Style_rare;
static PyObject *__pyx_n_u_Style_sing;
static PyObject *__pyx_n_u_Style_vrnc;
static PyObject *__pyx_n_u_Style_vulg;
static PyObject *__pyx_n_u_Style_yes;
static PyObject *__pyx_n_u_TAG;
static PyObject *__pyx_n_u_TIME;
static PyObject *__pyx_n_u_Tense_fut;
static PyObject *__pyx_n_u_Tense_imp;
static PyObject *__pyx_n_u_Tense_past;
static PyObject *__pyx_n_u_Tense_pres;
static PyObject *__pyx_n_u_VERB;
static PyObject *__pyx_n_u_VerbForm_conv;
static PyObject *__pyx_n_u_VerbForm_fin;
static PyObject *__pyx_n_u_VerbForm_gdv;
static PyObject *__pyx_n_u_VerbForm_ger;
static PyObject *__pyx_n_u_VerbForm_inf;
static PyObject *__pyx_n_u_VerbForm_none;
static PyObject *__pyx_n_u_VerbForm_part;
static PyObject *__pyx_n_u_VerbForm_partFut;
static PyObject *__pyx_n_u_VerbForm_partPast;
static PyObject *__pyx_n_u_VerbForm_partPres;
static PyObject *__pyx_n_u_VerbForm_sup;
static PyObject *__pyx_n_u_VerbForm_trans;
static PyObject *__pyx_n_u_VerbForm_vnoun;
static PyObject *__pyx_n_u_VerbType_aux;
static PyObject *__pyx_n_u_VerbType_cop;
static PyObject *__pyx_n_u_VerbType_light;
static PyObject *__pyx_n_u_VerbType_mod;
static PyObject *__pyx_n_u_Voice_act;
static PyObject *__pyx_n_u_Voice_antip;
static PyObject *__pyx_n_u_Voice_cau;
static PyObject *__pyx_n_u_Voice_dir;
static PyObject *__pyx_n_u_Voice_int;
static PyObject *__pyx_n_u_Voice_inv;
static PyObject *__pyx_n_u_Voice_mid;
static PyObject *__pyx_n_u_Voice_pass;
static PyObject *__pyx_n_u_WORK_OF_ART;
static PyObject *__pyx_n_u_X;
static PyObject *__pyx_n_u_acl;
static PyObject *__pyx_n_u_acomp;
static PyObject *__pyx_n_u_advcl;
static PyObject *__pyx_n_u_advmod;
static PyObject *__pyx_n_u_agent;
static PyObject *__pyx_n_u_amod;
static PyObject *__pyx_n_u_appos;
static PyObject *__pyx_n_u_attr;
static PyObject *__pyx_n_u_aux;
static PyObject *__pyx_n_u_auxpass;
static PyObject *__pyx_n_u_cc;
static PyObject *__pyx_n_u_ccomp;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_u_complm;
static PyObject *__pyx_n_u_conj;
static PyObject *__pyx_n_u_cop;
static PyObject *__pyx_n_u_csubj;
static PyObject *__pyx_n_u_csubjpass;
static PyObject *__pyx_n_u_dep;
static PyObject *__pyx_n_u_det;
static PyObject *__pyx_n_u_dobj;
static PyObject *__pyx_n_u_expl;
static PyObject *__pyx_n_u_hmod;
static PyObject *__pyx_n_u_hyph;
static PyObject *__pyx_n_u_infmod;
static PyObject *__pyx_n_u_intj;
static PyObject *__pyx_n_u_iobj;
static PyObject *__pyx_n_s_it;
static PyObject *__pyx_n_s_items;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_u_mark;
static PyObject *__pyx_n_u_meta;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_u_neg;
static PyObject *__pyx_n_u_nmod;
static PyObject *__pyx_n_u_nn;
static PyObject *__pyx_n_u_npadvmod;
static PyObject *__pyx_n_u_nsubj;
static PyObject *__pyx_n_u_nsubjpass;
static PyObject *__pyx_n_u_num;
static PyObject *__pyx_n_u_number;
static PyObject *__pyx_n_u_obj;
static PyObject *__pyx_n_u_obl;
static PyObject *__pyx_n_u_oprd;
static PyObject *__pyx_n_u_parataxis;
static PyObject *__pyx_n_u_partmod;
static PyObject *__pyx_n_u_pcomp;
static PyObject *__pyx_n_u_pobj;
static PyObject *__pyx_n_u_poss;
static PyObject *__pyx_n_u_possessive;
static PyObject *__pyx_n_u_preconj;
static PyObject *__pyx_n_u_prep;
static PyObject *__pyx_n_u_prt;
static PyObject *__pyx_n_u_punct;
static PyObject *__pyx_n_u_quantmod;
static PyObject *__pyx_n_u_rcmod;
static PyObject *__pyx_n_u_relcl;
static PyObject *__pyx_n_u_root;
static PyObject *__pyx_n_s_sort_nums;
static PyObject *__pyx_n_s_sorted;
static PyObject *__pyx_n_s_spacy_symbols;
static PyObject *__pyx_kp_s_symbols_pyx;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_n_u_xcomp;
static PyObject *__pyx_pf_5spacy_7symbols_sort_nums(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x); /* proto */
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_codeobj__3;
/* Late includes */

/* "spacy/symbols.pyx":474
 * 
 * 
 * def sort_nums(x):             # <<<<<<<<<<<<<<
 *     return x[1]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5spacy_7symbols_1sort_nums(PyObject *__pyx_self, PyObject *__pyx_v_x); /*proto*/
static PyMethodDef __pyx_mdef_5spacy_7symbols_1sort_nums = {"sort_nums", (PyCFunction)__pyx_pw_5spacy_7symbols_1sort_nums, METH_O, 0};
static PyObject *__pyx_pw_5spacy_7symbols_1sort_nums(PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sort_nums (wrapper)", 0);
  __pyx_r = __pyx_pf_5spacy_7symbols_sort_nums(__pyx_self, ((PyObject *)__pyx_v_x));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5spacy_7symbols_sort_nums(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sort_nums", 0);

  /* "spacy/symbols.pyx":475
 * 
 * def sort_nums(x):
 *     return x[1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_x, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "spacy/symbols.pyx":474
 * 
 * 
 * def sort_nums(x):             # <<<<<<<<<<<<<<
 *     return x[1]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("spacy.symbols.sort_nums", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_symbols(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_symbols},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "symbols",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
  {&__pyx_n_u_ADJ, __pyx_k_ADJ, sizeof(__pyx_k_ADJ), 0, 1, 0, 1},
  {&__pyx_n_u_ADP, __pyx_k_ADP, sizeof(__pyx_k_ADP), 0, 1, 0, 1},
  {&__pyx_n_u_ADV, __pyx_k_ADV, sizeof(__pyx_k_ADV), 0, 1, 0, 1},
  {&__pyx_n_u_AUX, __pyx_k_AUX, sizeof(__pyx_k_AUX), 0, 1, 0, 1},
  {&__pyx_n_u_Abbr_yes, __pyx_k_Abbr_yes, sizeof(__pyx_k_Abbr_yes), 0, 1, 0, 1},
  {&__pyx_n_u_AdpType_circ, __pyx_k_AdpType_circ, sizeof(__pyx_k_AdpType_circ), 0, 1, 0, 1},
  {&__pyx_n_u_AdpType_comprep, __pyx_k_AdpType_comprep, sizeof(__pyx_k_AdpType_comprep), 0, 1, 0, 1},
  {&__pyx_n_u_AdpType_post, __pyx_k_AdpType_post, sizeof(__pyx_k_AdpType_post), 0, 1, 0, 1},
  {&__pyx_n_u_AdpType_prep, __pyx_k_AdpType_prep, sizeof(__pyx_k_AdpType_prep), 0, 1, 0, 1},
  {&__pyx_n_u_AdpType_voc, __pyx_k_AdpType_voc, sizeof(__pyx_k_AdpType_voc), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_adadj, __pyx_k_AdvType_adadj, sizeof(__pyx_k_AdvType_adadj), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_cau, __pyx_k_AdvType_cau, sizeof(__pyx_k_AdvType_cau), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_deg, __pyx_k_AdvType_deg, sizeof(__pyx_k_AdvType_deg), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_ex, __pyx_k_AdvType_ex, sizeof(__pyx_k_AdvType_ex), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_loc, __pyx_k_AdvType_loc, sizeof(__pyx_k_AdvType_loc), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_man, __pyx_k_AdvType_man, sizeof(__pyx_k_AdvType_man), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_mod, __pyx_k_AdvType_mod, sizeof(__pyx_k_AdvType_mod), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_sta, __pyx_k_AdvType_sta, sizeof(__pyx_k_AdvType_sta), 0, 1, 0, 1},
  {&__pyx_n_u_AdvType_tim, __pyx_k_AdvType_tim, sizeof(__pyx_k_AdvType_tim), 0, 1, 0, 1},
  {&__pyx_n_u_Animacy_anim, __pyx_k_Animacy_anim, sizeof(__pyx_k_Animacy_anim), 0, 1, 0, 1},
  {&__pyx_n_u_Animacy_hum, __pyx_k_Animacy_hum, sizeof(__pyx_k_Animacy_hum), 0, 1, 0, 1},
  {&__pyx_n_u_Animacy_inam, __pyx_k_Animacy_inam, sizeof(__pyx_k_Animacy_inam), 0, 1, 0, 1},
  {&__pyx_n_u_Animacy_nhum, __pyx_k_Animacy_nhum, sizeof(__pyx_k_Animacy_nhum), 0, 1, 0, 1},
  {&__pyx_n_u_Aspect_freq, __pyx_k_Aspect_freq, sizeof(__pyx_k_Aspect_freq), 0, 1, 0, 1},
  {&__pyx_n_u_Aspect_hab, __pyx_k_Aspect_hab, sizeof(__pyx_k_Aspect_hab), 0, 1, 0, 1},
  {&__pyx_n_u_Aspect_imp, __pyx_k_Aspect_imp, sizeof(__pyx_k_Aspect_imp), 0, 1, 0, 1},
  {&__pyx_n_u_Aspect_iter, __pyx_k_Aspect_iter, sizeof(__pyx_k_Aspect_iter), 0, 1, 0, 1},
  {&__pyx_n_u_Aspect_mod, __pyx_k_Aspect_mod, sizeof(__pyx_k_Aspect_mod), 0, 1, 0, 1},
  {&__pyx_n_u_Aspect_none, __pyx_k_Aspect_none, sizeof(__pyx_k_Aspect_none), 0, 1, 0, 1},
  {&__pyx_n_u_Aspect_perf, __pyx_k_Aspect_perf, sizeof(__pyx_k_Aspect_perf), 0, 1, 0, 1},
  {&__pyx_n_u_CARDINAL, __pyx_k_CARDINAL, sizeof(__pyx_k_CARDINAL), 0, 1, 0, 1},
  {&__pyx_n_u_CCONJ, __pyx_k_CCONJ, sizeof(__pyx_k_CCONJ), 0, 1, 0, 1},
  {&__pyx_n_u_CLUSTER, __pyx_k_CLUSTER, sizeof(__pyx_k_CLUSTER), 0, 1, 0, 1},
  {&__pyx_n_u_CONJ, __pyx_k_CONJ, sizeof(__pyx_k_CONJ), 0, 1, 0, 1},
  {&__pyx_n_u_Case_abe, __pyx_k_Case_abe, sizeof(__pyx_k_Case_abe), 0, 1, 0, 1},
  {&__pyx_n_u_Case_abl, __pyx_k_Case_abl, sizeof(__pyx_k_Case_abl), 0, 1, 0, 1},
  {&__pyx_n_u_Case_abs, __pyx_k_Case_abs, sizeof(__pyx_k_Case_abs), 0, 1, 0, 1},
  {&__pyx_n_u_Case_acc, __pyx_k_Case_acc, sizeof(__pyx_k_Case_acc), 0, 1, 0, 1},
  {&__pyx_n_u_Case_ade, __pyx_k_Case_ade, sizeof(__pyx_k_Case_ade), 0, 1, 0, 1},
  {&__pyx_n_u_Case_all, __pyx_k_Case_all, sizeof(__pyx_k_Case_all), 0, 1, 0, 1},
  {&__pyx_n_u_Case_cau, __pyx_k_Case_cau, sizeof(__pyx_k_Case_cau), 0, 1, 0, 1},
  {&__pyx_n_u_Case_cmp, __pyx_k_Case_cmp, sizeof(__pyx_k_Case_cmp), 0, 1, 0, 1},
  {&__pyx_n_u_Case_com, __pyx_k_Case_com, sizeof(__pyx_k_Case_com), 0, 1, 0, 1},
  {&__pyx_n_u_Case_dat, __pyx_k_Case_dat, sizeof(__pyx_k_Case_dat), 0, 1, 0, 1},
  {&__pyx_n_u_Case_del, __pyx_k_Case_del, sizeof(__pyx_k_Case_del), 0, 1, 0, 1},
  {&__pyx_n_u_Case_dis, __pyx_k_Case_dis, sizeof(__pyx_k_Case_dis), 0, 1, 0, 1},
  {&__pyx_n_u_Case_ela, __pyx_k_Case_ela, sizeof(__pyx_k_Case_ela), 0, 1, 0, 1},
  {&__pyx_n_u_Case_equ, __pyx_k_Case_equ, sizeof(__pyx_k_Case_equ), 0, 1, 0, 1},
  {&__pyx_n_u_Case_ess, __pyx_k_Case_ess, sizeof(__pyx_k_Case_ess), 0, 1, 0, 1},
  {&__pyx_n_u_Case_gen, __pyx_k_Case_gen, sizeof(__pyx_k_Case_gen), 0, 1, 0, 1},
  {&__pyx_n_u_Case_ill, __pyx_k_Case_ill, sizeof(__pyx_k_Case_ill), 0, 1, 0, 1},
  {&__pyx_n_u_Case_ine, __pyx_k_Case_ine, sizeof(__pyx_k_Case_ine), 0, 1, 0, 1},
  {&__pyx_n_u_Case_ins, __pyx_k_Case_ins, sizeof(__pyx_k_Case_ins), 0, 1, 0, 1},
  {&__pyx_n_u_Case_lat, __pyx_k_Case_lat, sizeof(__pyx_k_Case_lat), 0, 1, 0, 1},
  {&__pyx_n_u_Case_loc, __pyx_k_Case_loc, sizeof(__pyx_k_Case_loc), 0, 1, 0, 1},
  {&__pyx_n_u_Case_nom, __pyx_k_Case_nom, sizeof(__pyx_k_Case_nom), 0, 1, 0, 1},
  {&__pyx_n_u_Case_par, __pyx_k_Case_par, sizeof(__pyx_k_Case_par), 0, 1, 0, 1},
  {&__pyx_n_u_Case_sub, __pyx_k_Case_sub, sizeof(__pyx_k_Case_sub), 0, 1, 0, 1},
  {&__pyx_n_u_Case_sup, __pyx_k_Case_sup, sizeof(__pyx_k_Case_sup), 0, 1, 0, 1},
  {&__pyx_n_u_Case_tem, __pyx_k_Case_tem, sizeof(__pyx_k_Case_tem), 0, 1, 0, 1},
  {&__pyx_n_u_Case_ter, __pyx_k_Case_ter, sizeof(__pyx_k_Case_ter), 0, 1, 0, 1},
  {&__pyx_n_u_Case_tra, __pyx_k_Case_tra, sizeof(__pyx_k_Case_tra), 0, 1, 0, 1},
  {&__pyx_n_u_Case_voc, __pyx_k_Case_voc, sizeof(__pyx_k_Case_voc), 0, 1, 0, 1},
  {&__pyx_n_u_ConjType_comp, __pyx_k_ConjType_comp, sizeof(__pyx_k_ConjType_comp), 0, 1, 0, 1},
  {&__pyx_n_u_ConjType_oper, __pyx_k_ConjType_oper, sizeof(__pyx_k_ConjType_oper), 0, 1, 0, 1},
  {&__pyx_n_u_Connegative_yes, __pyx_k_Connegative_yes, sizeof(__pyx_k_Connegative_yes), 0, 1, 0, 1},
  {&__pyx_n_u_DATE, __pyx_k_DATE, sizeof(__pyx_k_DATE), 0, 1, 0, 1},
  {&__pyx_n_u_DEP, __pyx_k_DEP, sizeof(__pyx_k_DEP), 0, 1, 0, 1},
  {&__pyx_n_u_DET, __pyx_k_DET, sizeof(__pyx_k_DET), 0, 1, 0, 1},
  {&__pyx_n_u_Definite_cons, __pyx_k_Definite_cons, sizeof(__pyx_k_Definite_cons), 0, 1, 0, 1},
  {&__pyx_n_u_Definite_def, __pyx_k_Definite_def, sizeof(__pyx_k_Definite_def), 0, 1, 0, 1},
  {&__pyx_n_u_Definite_ind, __pyx_k_Definite_ind, sizeof(__pyx_k_Definite_ind), 0, 1, 0, 1},
  {&__pyx_n_u_Definite_red, __pyx_k_Definite_red, sizeof(__pyx_k_Definite_red), 0, 1, 0, 1},
  {&__pyx_n_u_Definite_spec, __pyx_k_Definite_spec, sizeof(__pyx_k_Definite_spec), 0, 1, 0, 1},
  {&__pyx_n_u_Definite_two, __pyx_k_Definite_two, sizeof(__pyx_k_Definite_two), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_abs, __pyx_k_Degree_abs, sizeof(__pyx_k_Degree_abs), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_cmp, __pyx_k_Degree_cmp, sizeof(__pyx_k_Degree_cmp), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_com, __pyx_k_Degree_com, sizeof(__pyx_k_Degree_com), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_comp, __pyx_k_Degree_comp, sizeof(__pyx_k_Degree_comp), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_dim, __pyx_k_Degree_dim, sizeof(__pyx_k_Degree_dim), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_equ, __pyx_k_Degree_equ, sizeof(__pyx_k_Degree_equ), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_none, __pyx_k_Degree_none, sizeof(__pyx_k_Degree_none), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_pos, __pyx_k_Degree_pos, sizeof(__pyx_k_Degree_pos), 0, 1, 0, 1},
  {&__pyx_n_u_Degree_sup, __pyx_k_Degree_sup, sizeof(__pyx_k_Degree_sup), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_inen, __pyx_k_Derivation_inen, sizeof(__pyx_k_Derivation_inen), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_ja, __pyx_k_Derivation_ja, sizeof(__pyx_k_Derivation_ja), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_lainen, __pyx_k_Derivation_lainen, sizeof(__pyx_k_Derivation_lainen), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_minen, __pyx_k_Derivation_minen, sizeof(__pyx_k_Derivation_minen), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_sti, __pyx_k_Derivation_sti, sizeof(__pyx_k_Derivation_sti), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_ton, __pyx_k_Derivation_ton, sizeof(__pyx_k_Derivation_ton), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_ttaa, __pyx_k_Derivation_ttaa, sizeof(__pyx_k_Derivation_ttaa), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_ttain, __pyx_k_Derivation_ttain, sizeof(__pyx_k_Derivation_ttain), 0, 1, 0, 1},
  {&__pyx_n_u_Derivation_vs, __pyx_k_Derivation_vs, sizeof(__pyx_k_Derivation_vs), 0, 1, 0, 1},
  {&__pyx_n_u_ENT_ID, __pyx_k_ENT_ID, sizeof(__pyx_k_ENT_ID), 0, 1, 0, 1},
  {&__pyx_n_u_ENT_IOB, __pyx_k_ENT_IOB, sizeof(__pyx_k_ENT_IOB), 0, 1, 0, 1},
  {&__pyx_n_u_ENT_KB_ID, __pyx_k_ENT_KB_ID, sizeof(__pyx_k_ENT_KB_ID), 0, 1, 0, 1},
  {&__pyx_n_u_ENT_TYPE, __pyx_k_ENT_TYPE, sizeof(__pyx_k_ENT_TYPE), 0, 1, 0, 1},
  {&__pyx_n_u_EOL, __pyx_k_EOL, sizeof(__pyx_k_EOL), 0, 1, 0, 1},
  {&__pyx_n_u_EVENT, __pyx_k_EVENT, sizeof(__pyx_k_EVENT), 0, 1, 0, 1},
  {&__pyx_n_u_Echo_ech, __pyx_k_Echo_ech, sizeof(__pyx_k_Echo_ech), 0, 1, 0, 1},
  {&__pyx_n_u_Echo_rdp, __pyx_k_Echo_rdp, sizeof(__pyx_k_Echo_rdp), 0, 1, 0, 1},
  {&__pyx_n_u_Evident_nfh, __pyx_k_Evident_nfh, sizeof(__pyx_k_Evident_nfh), 0, 1, 0, 1},
  {&__pyx_n_u_FACILITY, __pyx_k_FACILITY, sizeof(__pyx_k_FACILITY), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG19, __pyx_k_FLAG19, sizeof(__pyx_k_FLAG19), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG20, __pyx_k_FLAG20, sizeof(__pyx_k_FLAG20), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG21, __pyx_k_FLAG21, sizeof(__pyx_k_FLAG21), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG22, __pyx_k_FLAG22, sizeof(__pyx_k_FLAG22), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG23, __pyx_k_FLAG23, sizeof(__pyx_k_FLAG23), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG24, __pyx_k_FLAG24, sizeof(__pyx_k_FLAG24), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG25, __pyx_k_FLAG25, sizeof(__pyx_k_FLAG25), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG26, __pyx_k_FLAG26, sizeof(__pyx_k_FLAG26), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG27, __pyx_k_FLAG27, sizeof(__pyx_k_FLAG27), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG28, __pyx_k_FLAG28, sizeof(__pyx_k_FLAG28), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG29, __pyx_k_FLAG29, sizeof(__pyx_k_FLAG29), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG30, __pyx_k_FLAG30, sizeof(__pyx_k_FLAG30), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG31, __pyx_k_FLAG31, sizeof(__pyx_k_FLAG31), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG32, __pyx_k_FLAG32, sizeof(__pyx_k_FLAG32), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG33, __pyx_k_FLAG33, sizeof(__pyx_k_FLAG33), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG34, __pyx_k_FLAG34, sizeof(__pyx_k_FLAG34), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG35, __pyx_k_FLAG35, sizeof(__pyx_k_FLAG35), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG36, __pyx_k_FLAG36, sizeof(__pyx_k_FLAG36), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG37, __pyx_k_FLAG37, sizeof(__pyx_k_FLAG37), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG38, __pyx_k_FLAG38, sizeof(__pyx_k_FLAG38), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG39, __pyx_k_FLAG39, sizeof(__pyx_k_FLAG39), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG40, __pyx_k_FLAG40, sizeof(__pyx_k_FLAG40), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG41, __pyx_k_FLAG41, sizeof(__pyx_k_FLAG41), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG42, __pyx_k_FLAG42, sizeof(__pyx_k_FLAG42), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG43, __pyx_k_FLAG43, sizeof(__pyx_k_FLAG43), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG44, __pyx_k_FLAG44, sizeof(__pyx_k_FLAG44), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG45, __pyx_k_FLAG45, sizeof(__pyx_k_FLAG45), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG46, __pyx_k_FLAG46, sizeof(__pyx_k_FLAG46), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG47, __pyx_k_FLAG47, sizeof(__pyx_k_FLAG47), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG48, __pyx_k_FLAG48, sizeof(__pyx_k_FLAG48), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG49, __pyx_k_FLAG49, sizeof(__pyx_k_FLAG49), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG50, __pyx_k_FLAG50, sizeof(__pyx_k_FLAG50), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG51, __pyx_k_FLAG51, sizeof(__pyx_k_FLAG51), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG52, __pyx_k_FLAG52, sizeof(__pyx_k_FLAG52), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG53, __pyx_k_FLAG53, sizeof(__pyx_k_FLAG53), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG54, __pyx_k_FLAG54, sizeof(__pyx_k_FLAG54), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG55, __pyx_k_FLAG55, sizeof(__pyx_k_FLAG55), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG56, __pyx_k_FLAG56, sizeof(__pyx_k_FLAG56), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG57, __pyx_k_FLAG57, sizeof(__pyx_k_FLAG57), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG58, __pyx_k_FLAG58, sizeof(__pyx_k_FLAG58), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG59, __pyx_k_FLAG59, sizeof(__pyx_k_FLAG59), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG60, __pyx_k_FLAG60, sizeof(__pyx_k_FLAG60), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG61, __pyx_k_FLAG61, sizeof(__pyx_k_FLAG61), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG62, __pyx_k_FLAG62, sizeof(__pyx_k_FLAG62), 0, 1, 0, 1},
  {&__pyx_n_u_FLAG63, __pyx_k_FLAG63, sizeof(__pyx_k_FLAG63), 0, 1, 0, 1},
  {&__pyx_n_u_Foreign_foreign, __pyx_k_Foreign_foreign, sizeof(__pyx_k_Foreign_foreign), 0, 1, 0, 1},
  {&__pyx_n_u_Foreign_fscript, __pyx_k_Foreign_fscript, sizeof(__pyx_k_Foreign_fscript), 0, 1, 0, 1},
  {&__pyx_n_u_Foreign_tscript, __pyx_k_Foreign_tscript, sizeof(__pyx_k_Foreign_tscript), 0, 1, 0, 1},
  {&__pyx_n_u_Foreign_yes, __pyx_k_Foreign_yes, sizeof(__pyx_k_Foreign_yes), 0, 1, 0, 1},
  {&__pyx_n_u_GPE, __pyx_k_GPE, sizeof(__pyx_k_GPE), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_com, __pyx_k_Gender_com, sizeof(__pyx_k_Gender_com), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_dat_fem, __pyx_k_Gender_dat_fem, sizeof(__pyx_k_Gender_dat_fem), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_dat_masc, __pyx_k_Gender_dat_masc, sizeof(__pyx_k_Gender_dat_masc), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_erg_fem, __pyx_k_Gender_erg_fem, sizeof(__pyx_k_Gender_erg_fem), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_erg_masc, __pyx_k_Gender_erg_masc, sizeof(__pyx_k_Gender_erg_masc), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_fem, __pyx_k_Gender_fem, sizeof(__pyx_k_Gender_fem), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_masc, __pyx_k_Gender_masc, sizeof(__pyx_k_Gender_masc), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_neut, __pyx_k_Gender_neut, sizeof(__pyx_k_Gender_neut), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_psor_fem, __pyx_k_Gender_psor_fem, sizeof(__pyx_k_Gender_psor_fem), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_psor_masc, __pyx_k_Gender_psor_masc, sizeof(__pyx_k_Gender_psor_masc), 0, 1, 0, 1},
  {&__pyx_n_u_Gender_psor_neut, __pyx_k_Gender_psor_neut, sizeof(__pyx_k_Gender_psor_neut), 0, 1, 0, 1},
  {&__pyx_n_u_HEAD, __pyx_k_HEAD, sizeof(__pyx_k_HEAD), 0, 1, 0, 1},
  {&__pyx_n_u_Hyph_yes, __pyx_k_Hyph_yes, sizeof(__pyx_k_Hyph_yes), 0, 1, 0, 1},
  {&__pyx_n_u_ID, __pyx_k_ID, sizeof(__pyx_k_ID), 0, 1, 0, 1},
  {&__pyx_n_s_IDS, __pyx_k_IDS, sizeof(__pyx_k_IDS), 0, 0, 1, 1},
  {&__pyx_n_u_IDX, __pyx_k_IDX, sizeof(__pyx_k_IDX), 0, 1, 0, 1},
  {&__pyx_n_u_INTJ, __pyx_k_INTJ, sizeof(__pyx_k_INTJ), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ALPHA, __pyx_k_IS_ALPHA, sizeof(__pyx_k_IS_ALPHA), 0, 1, 0, 1},
  {&__pyx_n_u_IS_ASCII, __pyx_k_IS_ASCII, sizeof(__pyx_k_IS_ASCII), 0, 1, 0, 1},
  {&__pyx_n_u_IS_BRACKET, __pyx_k_IS_BRACKET, sizeof(__pyx_k_IS_BRACKET), 0, 1, 0, 1},
  {&__pyx_n_u_IS_CURRENCY, __pyx_k_IS_CURRENCY, sizeof(__pyx_k_IS_CURRENCY), 0, 1, 0, 1},
  {&__pyx_n_u_IS_DIGIT, __pyx_k_IS_DIGIT, sizeof(__pyx_k_IS_DIGIT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_LEFT_PUNCT, __pyx_k_IS_LEFT_PUNCT, sizeof(__pyx_k_IS_LEFT_PUNCT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_LOWER, __pyx_k_IS_LOWER, sizeof(__pyx_k_IS_LOWER), 0, 1, 0, 1},
  {&__pyx_n_u_IS_OOV_DEPRECATED, __pyx_k_IS_OOV_DEPRECATED, sizeof(__pyx_k_IS_OOV_DEPRECATED), 0, 1, 0, 1},
  {&__pyx_n_u_IS_PUNCT, __pyx_k_IS_PUNCT, sizeof(__pyx_k_IS_PUNCT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_QUOTE, __pyx_k_IS_QUOTE, sizeof(__pyx_k_IS_QUOTE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_RIGHT_PUNCT, __pyx_k_IS_RIGHT_PUNCT, sizeof(__pyx_k_IS_RIGHT_PUNCT), 0, 1, 0, 1},
  {&__pyx_n_u_IS_SPACE, __pyx_k_IS_SPACE, sizeof(__pyx_k_IS_SPACE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_STOP, __pyx_k_IS_STOP, sizeof(__pyx_k_IS_STOP), 0, 1, 0, 1},
  {&__pyx_n_u_IS_TITLE, __pyx_k_IS_TITLE, sizeof(__pyx_k_IS_TITLE), 0, 1, 0, 1},
  {&__pyx_n_u_IS_UPPER, __pyx_k_IS_UPPER, sizeof(__pyx_k_IS_UPPER), 0, 1, 0, 1},
  {&__pyx_n_u_InfForm_one, __pyx_k_InfForm_one, sizeof(__pyx_k_InfForm_one), 0, 1, 0, 1},
  {&__pyx_n_u_InfForm_three, __pyx_k_InfForm_three, sizeof(__pyx_k_InfForm_three), 0, 1, 0, 1},
  {&__pyx_n_u_InfForm_two, __pyx_k_InfForm_two, sizeof(__pyx_k_InfForm_two), 0, 1, 0, 1},
  {&__pyx_n_u_LANG, __pyx_k_LANG, sizeof(__pyx_k_LANG), 0, 1, 0, 1},
  {&__pyx_n_u_LANGUAGE, __pyx_k_LANGUAGE, sizeof(__pyx_k_LANGUAGE), 0, 1, 0, 1},
  {&__pyx_n_u_LAW, __pyx_k_LAW, sizeof(__pyx_k_LAW), 0, 1, 0, 1},
  {&__pyx_n_u_LEMMA, __pyx_k_LEMMA, sizeof(__pyx_k_LEMMA), 0, 1, 0, 1},
  {&__pyx_n_u_LENGTH, __pyx_k_LENGTH, sizeof(__pyx_k_LENGTH), 0, 1, 0, 1},
  {&__pyx_n_u_LIKE_EMAIL, __pyx_k_LIKE_EMAIL, sizeof(__pyx_k_LIKE_EMAIL), 0, 1, 0, 1},
  {&__pyx_n_u_LIKE_NUM, __pyx_k_LIKE_NUM, sizeof(__pyx_k_LIKE_NUM), 0, 1, 0, 1},
  {&__pyx_n_u_LIKE_URL, __pyx_k_LIKE_URL, sizeof(__pyx_k_LIKE_URL), 0, 1, 0, 1},
  {&__pyx_n_u_LOC, __pyx_k_LOC, sizeof(__pyx_k_LOC), 0, 1, 0, 1},
  {&__pyx_n_u_LOWER, __pyx_k_LOWER, sizeof(__pyx_k_LOWER), 0, 1, 0, 1},
  {&__pyx_n_u_MONEY, __pyx_k_MONEY, sizeof(__pyx_k_MONEY), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_adm, __pyx_k_Mood_adm, sizeof(__pyx_k_Mood_adm), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_cnd, __pyx_k_Mood_cnd, sizeof(__pyx_k_Mood_cnd), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_imp, __pyx_k_Mood_imp, sizeof(__pyx_k_Mood_imp), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_ind, __pyx_k_Mood_ind, sizeof(__pyx_k_Mood_ind), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_n, __pyx_k_Mood_n, sizeof(__pyx_k_Mood_n), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_opt, __pyx_k_Mood_opt, sizeof(__pyx_k_Mood_opt), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_pot, __pyx_k_Mood_pot, sizeof(__pyx_k_Mood_pot), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_prp, __pyx_k_Mood_prp, sizeof(__pyx_k_Mood_prp), 0, 1, 0, 1},
  {&__pyx_n_u_Mood_sub, __pyx_k_Mood_sub, sizeof(__pyx_k_Mood_sub), 0, 1, 0, 1},
  {&__pyx_n_s_NAMES, __pyx_k_NAMES, sizeof(__pyx_k_NAMES), 0, 0, 1, 1},
  {&__pyx_n_u_NORM, __pyx_k_NORM, sizeof(__pyx_k_NORM), 0, 1, 0, 1},
  {&__pyx_n_u_NORP, __pyx_k_NORP, sizeof(__pyx_k_NORP), 0, 1, 0, 1},
  {&__pyx_n_u_NOUN, __pyx_k_NOUN, sizeof(__pyx_k_NOUN), 0, 1, 0, 1},
  {&__pyx_n_u_NUM, __pyx_k_NUM, sizeof(__pyx_k_NUM), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_com, __pyx_k_NameType_com, sizeof(__pyx_k_NameType_com), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_geo, __pyx_k_NameType_geo, sizeof(__pyx_k_NameType_geo), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_giv, __pyx_k_NameType_giv, sizeof(__pyx_k_NameType_giv), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_nat, __pyx_k_NameType_nat, sizeof(__pyx_k_NameType_nat), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_oth, __pyx_k_NameType_oth, sizeof(__pyx_k_NameType_oth), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_pro, __pyx_k_NameType_pro, sizeof(__pyx_k_NameType_pro), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_prs, __pyx_k_NameType_prs, sizeof(__pyx_k_NameType_prs), 0, 1, 0, 1},
  {&__pyx_n_u_NameType_sur, __pyx_k_NameType_sur, sizeof(__pyx_k_NameType_sur), 0, 1, 0, 1},
  {&__pyx_n_u_Negative_neg, __pyx_k_Negative_neg, sizeof(__pyx_k_Negative_neg), 0, 1, 0, 1},
  {&__pyx_n_u_Negative_pos, __pyx_k_Negative_pos, sizeof(__pyx_k_Negative_pos), 0, 1, 0, 1},
  {&__pyx_n_u_Negative_yes, __pyx_k_Negative_yes, sizeof(__pyx_k_Negative_yes), 0, 1, 0, 1},
  {&__pyx_n_u_NounType_class, __pyx_k_NounType_class, sizeof(__pyx_k_NounType_class), 0, 1, 0, 1},
  {&__pyx_n_u_NounType_com, __pyx_k_NounType_com, sizeof(__pyx_k_NounType_com), 0, 1, 0, 1},
  {&__pyx_n_u_NounType_prop, __pyx_k_NounType_prop, sizeof(__pyx_k_NounType_prop), 0, 1, 0, 1},
  {&__pyx_n_u_NumForm_digit, __pyx_k_NumForm_digit, sizeof(__pyx_k_NumForm_digit), 0, 1, 0, 1},
  {&__pyx_n_u_NumForm_roman, __pyx_k_NumForm_roman, sizeof(__pyx_k_NumForm_roman), 0, 1, 0, 1},
  {&__pyx_n_u_NumForm_word, __pyx_k_NumForm_word, sizeof(__pyx_k_NumForm_word), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_card, __pyx_k_NumType_card, sizeof(__pyx_k_NumType_card), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_dist, __pyx_k_NumType_dist, sizeof(__pyx_k_NumType_dist), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_frac, __pyx_k_NumType_frac, sizeof(__pyx_k_NumType_frac), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_gen, __pyx_k_NumType_gen, sizeof(__pyx_k_NumType_gen), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_mult, __pyx_k_NumType_mult, sizeof(__pyx_k_NumType_mult), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_none, __pyx_k_NumType_none, sizeof(__pyx_k_NumType_none), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_ord, __pyx_k_NumType_ord, sizeof(__pyx_k_NumType_ord), 0, 1, 0, 1},
  {&__pyx_n_u_NumType_sets, __pyx_k_NumType_sets, sizeof(__pyx_k_NumType_sets), 0, 1, 0, 1},
  {&__pyx_n_u_NumValue_one, __pyx_k_NumValue_one, sizeof(__pyx_k_NumValue_one), 0, 1, 0, 1},
  {&__pyx_n_u_NumValue_three, __pyx_k_NumValue_three, sizeof(__pyx_k_NumValue_three), 0, 1, 0, 1},
  {&__pyx_n_u_NumValue_two, __pyx_k_NumValue_two, sizeof(__pyx_k_NumValue_two), 0, 1, 0, 1},
  {&__pyx_n_u_Number_abs_plur, __pyx_k_Number_abs_plur, sizeof(__pyx_k_Number_abs_plur), 0, 1, 0, 1},
  {&__pyx_n_u_Number_abs_sing, __pyx_k_Number_abs_sing, sizeof(__pyx_k_Number_abs_sing), 0, 1, 0, 1},
  {&__pyx_n_u_Number_com, __pyx_k_Number_com, sizeof(__pyx_k_Number_com), 0, 1, 0, 1},
  {&__pyx_n_u_Number_count, __pyx_k_Number_count, sizeof(__pyx_k_Number_count), 0, 1, 0, 1},
  {&__pyx_n_u_Number_dat_plur, __pyx_k_Number_dat_plur, sizeof(__pyx_k_Number_dat_plur), 0, 1, 0, 1},
  {&__pyx_n_u_Number_dat_sing, __pyx_k_Number_dat_sing, sizeof(__pyx_k_Number_dat_sing), 0, 1, 0, 1},
  {&__pyx_n_u_Number_dual, __pyx_k_Number_dual, sizeof(__pyx_k_Number_dual), 0, 1, 0, 1},
  {&__pyx_n_u_Number_erg_plur, __pyx_k_Number_erg_plur, sizeof(__pyx_k_Number_erg_plur), 0, 1, 0, 1},
  {&__pyx_n_u_Number_erg_sing, __pyx_k_Number_erg_sing, sizeof(__pyx_k_Number_erg_sing), 0, 1, 0, 1},
  {&__pyx_n_u_Number_grpa, __pyx_k_Number_grpa, sizeof(__pyx_k_Number_grpa), 0, 1, 0, 1},
  {&__pyx_n_u_Number_grpl, __pyx_k_Number_grpl, sizeof(__pyx_k_Number_grpl), 0, 1, 0, 1},
  {&__pyx_n_u_Number_inv, __pyx_k_Number_inv, sizeof(__pyx_k_Number_inv), 0, 1, 0, 1},
  {&__pyx_n_u_Number_none, __pyx_k_Number_none, sizeof(__pyx_k_Number_none), 0, 1, 0, 1},
  {&__pyx_n_u_Number_pauc, __pyx_k_Number_pauc, sizeof(__pyx_k_Number_pauc), 0, 1, 0, 1},
  {&__pyx_n_u_Number_plur, __pyx_k_Number_plur, sizeof(__pyx_k_Number_plur), 0, 1, 0, 1},
  {&__pyx_n_u_Number_psee_plur, __pyx_k_Number_psee_plur, sizeof(__pyx_k_Number_psee_plur), 0, 1, 0, 1},
  {&__pyx_n_u_Number_psee_sing, __pyx_k_Number_psee_sing, sizeof(__pyx_k_Number_psee_sing), 0, 1, 0, 1},
  {&__pyx_n_u_Number_psor_plur, __pyx_k_Number_psor_plur, sizeof(__pyx_k_Number_psor_plur), 0, 1, 0, 1},
  {&__pyx_n_u_Number_psor_sing, __pyx_k_Number_psor_sing, sizeof(__pyx_k_Number_psor_sing), 0, 1, 0, 1},
  {&__pyx_n_u_Number_ptan, __pyx_k_Number_ptan, sizeof(__pyx_k_Number_ptan), 0, 1, 0, 1},
  {&__pyx_n_u_Number_sing, __pyx_k_Number_sing, sizeof(__pyx_k_Number_sing), 0, 1, 0, 1},
  {&__pyx_n_u_Number_tri, __pyx_k_Number_tri, sizeof(__pyx_k_Number_tri), 0, 1, 0, 1},
  {&__pyx_n_u_ORDINAL, __pyx_k_ORDINAL, sizeof(__pyx_k_ORDINAL), 0, 1, 0, 1},
  {&__pyx_n_u_ORG, __pyx_k_ORG, sizeof(__pyx_k_ORG), 0, 1, 0, 1},
  {&__pyx_n_u_ORTH, __pyx_k_ORTH, sizeof(__pyx_k_ORTH), 0, 1, 0, 1},
  {&__pyx_n_u_PART, __pyx_k_PART, sizeof(__pyx_k_PART), 0, 1, 0, 1},
  {&__pyx_n_u_PERCENT, __pyx_k_PERCENT, sizeof(__pyx_k_PERCENT), 0, 1, 0, 1},
  {&__pyx_n_u_PERSON, __pyx_k_PERSON, sizeof(__pyx_k_PERSON), 0, 1, 0, 1},
  {&__pyx_n_u_POS, __pyx_k_POS, sizeof(__pyx_k_POS), 0, 1, 0, 1},
  {&__pyx_n_u_PREFIX, __pyx_k_PREFIX, sizeof(__pyx_k_PREFIX), 0, 1, 0, 1},
  {&__pyx_n_u_PROB, __pyx_k_PROB, sizeof(__pyx_k_PROB), 0, 1, 0, 1},
  {&__pyx_n_u_PRODUCT, __pyx_k_PRODUCT, sizeof(__pyx_k_PRODUCT), 0, 1, 0, 1},
  {&__pyx_n_u_PRON, __pyx_k_PRON, sizeof(__pyx_k_PRON), 0, 1, 0, 1},
  {&__pyx_kp_u_PRON_2, __pyx_k_PRON_2, sizeof(__pyx_k_PRON_2), 0, 1, 0, 0},
  {&__pyx_n_s_PRON_LEMMA, __pyx_k_PRON_LEMMA, sizeof(__pyx_k_PRON_LEMMA), 0, 0, 1, 1},
  {&__pyx_n_u_PROPN, __pyx_k_PROPN, sizeof(__pyx_k_PROPN), 0, 1, 0, 1},
  {&__pyx_n_u_PUNCT, __pyx_k_PUNCT, sizeof(__pyx_k_PUNCT), 0, 1, 0, 1},
  {&__pyx_n_u_PartForm_agt, __pyx_k_PartForm_agt, sizeof(__pyx_k_PartForm_agt), 0, 1, 0, 1},
  {&__pyx_n_u_PartForm_neg, __pyx_k_PartForm_neg, sizeof(__pyx_k_PartForm_neg), 0, 1, 0, 1},
  {&__pyx_n_u_PartForm_past, __pyx_k_PartForm_past, sizeof(__pyx_k_PartForm_past), 0, 1, 0, 1},
  {&__pyx_n_u_PartForm_pres, __pyx_k_PartForm_pres, sizeof(__pyx_k_PartForm_pres), 0, 1, 0, 1},
  {&__pyx_n_u_PartType_emp, __pyx_k_PartType_emp, sizeof(__pyx_k_PartType_emp), 0, 1, 0, 1},
  {&__pyx_n_u_PartType_inf, __pyx_k_PartType_inf, sizeof(__pyx_k_PartType_inf), 0, 1, 0, 1},
  {&__pyx_n_u_PartType_mod, __pyx_k_PartType_mod, sizeof(__pyx_k_PartType_mod), 0, 1, 0, 1},
  {&__pyx_n_u_PartType_res, __pyx_k_PartType_res, sizeof(__pyx_k_PartType_res), 0, 1, 0, 1},
  {&__pyx_n_u_PartType_vbp, __pyx_k_PartType_vbp, sizeof(__pyx_k_PartType_vbp), 0, 1, 0, 1},
  {&__pyx_n_u_Person_abs_one, __pyx_k_Person_abs_one, sizeof(__pyx_k_Person_abs_one), 0, 1, 0, 1},
  {&__pyx_n_u_Person_abs_three, __pyx_k_Person_abs_three, sizeof(__pyx_k_Person_abs_three), 0, 1, 0, 1},
  {&__pyx_n_u_Person_abs_two, __pyx_k_Person_abs_two, sizeof(__pyx_k_Person_abs_two), 0, 1, 0, 1},
  {&__pyx_n_u_Person_dat_one, __pyx_k_Person_dat_one, sizeof(__pyx_k_Person_dat_one), 0, 1, 0, 1},
  {&__pyx_n_u_Person_dat_three, __pyx_k_Person_dat_three, sizeof(__pyx_k_Person_dat_three), 0, 1, 0, 1},
  {&__pyx_n_u_Person_dat_two, __pyx_k_Person_dat_two, sizeof(__pyx_k_Person_dat_two), 0, 1, 0, 1},
  {&__pyx_n_u_Person_erg_one, __pyx_k_Person_erg_one, sizeof(__pyx_k_Person_erg_one), 0, 1, 0, 1},
  {&__pyx_n_u_Person_erg_three, __pyx_k_Person_erg_three, sizeof(__pyx_k_Person_erg_three), 0, 1, 0, 1},
  {&__pyx_n_u_Person_erg_two, __pyx_k_Person_erg_two, sizeof(__pyx_k_Person_erg_two), 0, 1, 0, 1},
  {&__pyx_n_u_Person_four, __pyx_k_Person_four, sizeof(__pyx_k_Person_four), 0, 1, 0, 1},
  {&__pyx_n_u_Person_none, __pyx_k_Person_none, sizeof(__pyx_k_Person_none), 0, 1, 0, 1},
  {&__pyx_n_u_Person_one, __pyx_k_Person_one, sizeof(__pyx_k_Person_one), 0, 1, 0, 1},
  {&__pyx_n_u_Person_psor_one, __pyx_k_Person_psor_one, sizeof(__pyx_k_Person_psor_one), 0, 1, 0, 1},
  {&__pyx_n_u_Person_psor_three, __pyx_k_Person_psor_three, sizeof(__pyx_k_Person_psor_three), 0, 1, 0, 1},
  {&__pyx_n_u_Person_psor_two, __pyx_k_Person_psor_two, sizeof(__pyx_k_Person_psor_two), 0, 1, 0, 1},
  {&__pyx_n_u_Person_three, __pyx_k_Person_three, sizeof(__pyx_k_Person_three), 0, 1, 0, 1},
  {&__pyx_n_u_Person_two, __pyx_k_Person_two, sizeof(__pyx_k_Person_two), 0, 1, 0, 1},
  {&__pyx_n_u_Person_zero, __pyx_k_Person_zero, sizeof(__pyx_k_Person_zero), 0, 1, 0, 1},
  {&__pyx_n_u_Polarity_neg, __pyx_k_Polarity_neg, sizeof(__pyx_k_Polarity_neg), 0, 1, 0, 1},
  {&__pyx_n_u_Polarity_pos, __pyx_k_Polarity_pos, sizeof(__pyx_k_Polarity_pos), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_abs_inf, __pyx_k_Polite_abs_inf, sizeof(__pyx_k_Polite_abs_inf), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_abs_pol, __pyx_k_Polite_abs_pol, sizeof(__pyx_k_Polite_abs_pol), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_dat_inf, __pyx_k_Polite_dat_inf, sizeof(__pyx_k_Polite_dat_inf), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_dat_pol, __pyx_k_Polite_dat_pol, sizeof(__pyx_k_Polite_dat_pol), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_erg_inf, __pyx_k_Polite_erg_inf, sizeof(__pyx_k_Polite_erg_inf), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_erg_pol, __pyx_k_Polite_erg_pol, sizeof(__pyx_k_Polite_erg_pol), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_form, __pyx_k_Polite_form, sizeof(__pyx_k_Polite_form), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_form_elev, __pyx_k_Polite_form_elev, sizeof(__pyx_k_Polite_form_elev), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_form_humb, __pyx_k_Polite_form_humb, sizeof(__pyx_k_Polite_form_humb), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_inf, __pyx_k_Polite_inf, sizeof(__pyx_k_Polite_inf), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_infm, __pyx_k_Polite_infm, sizeof(__pyx_k_Polite_infm), 0, 1, 0, 1},
  {&__pyx_n_u_Polite_pol, __pyx_k_Polite_pol, sizeof(__pyx_k_Polite_pol), 0, 1, 0, 1},
  {&__pyx_n_u_Poss_yes, __pyx_k_Poss_yes, sizeof(__pyx_k_Poss_yes), 0, 1, 0, 1},
  {&__pyx_n_u_Prefix_yes, __pyx_k_Prefix_yes, sizeof(__pyx_k_Prefix_yes), 0, 1, 0, 1},
  {&__pyx_n_u_PrepCase_npr, __pyx_k_PrepCase_npr, sizeof(__pyx_k_PrepCase_npr), 0, 1, 0, 1},
  {&__pyx_n_u_PrepCase_pre, __pyx_k_PrepCase_pre, sizeof(__pyx_k_PrepCase_pre), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_advPart, __pyx_k_PronType_advPart, sizeof(__pyx_k_PronType_advPart), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_art, __pyx_k_PronType_art, sizeof(__pyx_k_PronType_art), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_clit, __pyx_k_PronType_clit, sizeof(__pyx_k_PronType_clit), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_default, __pyx_k_PronType_default, sizeof(__pyx_k_PronType_default), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_dem, __pyx_k_PronType_dem, sizeof(__pyx_k_PronType_dem), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_emp, __pyx_k_PronType_emp, sizeof(__pyx_k_PronType_emp), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_exc, __pyx_k_PronType_exc, sizeof(__pyx_k_PronType_exc), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_ind, __pyx_k_PronType_ind, sizeof(__pyx_k_PronType_ind), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_int, __pyx_k_PronType_int, sizeof(__pyx_k_PronType_int), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_neg, __pyx_k_PronType_neg, sizeof(__pyx_k_PronType_neg), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_prs, __pyx_k_PronType_prs, sizeof(__pyx_k_PronType_prs), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_rcp, __pyx_k_PronType_rcp, sizeof(__pyx_k_PronType_rcp), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_rel, __pyx_k_PronType_rel, sizeof(__pyx_k_PronType_rel), 0, 1, 0, 1},
  {&__pyx_n_u_PronType_tot, __pyx_k_PronType_tot, sizeof(__pyx_k_PronType_tot), 0, 1, 0, 1},
  {&__pyx_n_u_PunctSide_fin, __pyx_k_PunctSide_fin, sizeof(__pyx_k_PunctSide_fin), 0, 1, 0, 1},
  {&__pyx_n_u_PunctSide_ini, __pyx_k_PunctSide_ini, sizeof(__pyx_k_PunctSide_ini), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_brck, __pyx_k_PunctType_brck, sizeof(__pyx_k_PunctType_brck), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_colo, __pyx_k_PunctType_colo, sizeof(__pyx_k_PunctType_colo), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_comm, __pyx_k_PunctType_comm, sizeof(__pyx_k_PunctType_comm), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_dash, __pyx_k_PunctType_dash, sizeof(__pyx_k_PunctType_dash), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_excl, __pyx_k_PunctType_excl, sizeof(__pyx_k_PunctType_excl), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_peri, __pyx_k_PunctType_peri, sizeof(__pyx_k_PunctType_peri), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_qest, __pyx_k_PunctType_qest, sizeof(__pyx_k_PunctType_qest), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_quot, __pyx_k_PunctType_quot, sizeof(__pyx_k_PunctType_quot), 0, 1, 0, 1},
  {&__pyx_n_u_PunctType_semi, __pyx_k_PunctType_semi, sizeof(__pyx_k_PunctType_semi), 0, 1, 0, 1},
  {&__pyx_n_u_QUANTITY, __pyx_k_QUANTITY, sizeof(__pyx_k_QUANTITY), 0, 1, 0, 1},
  {&__pyx_n_u_Reflex_yes, __pyx_k_Reflex_yes, sizeof(__pyx_k_Reflex_yes), 0, 1, 0, 1},
  {&__pyx_n_u_SCONJ, __pyx_k_SCONJ, sizeof(__pyx_k_SCONJ), 0, 1, 0, 1},
  {&__pyx_n_u_SENT_START, __pyx_k_SENT_START, sizeof(__pyx_k_SENT_START), 0, 1, 0, 1},
  {&__pyx_n_u_SHAPE, __pyx_k_SHAPE, sizeof(__pyx_k_SHAPE), 0, 1, 0, 1},
  {&__pyx_n_u_SPACE, __pyx_k_SPACE, sizeof(__pyx_k_SPACE), 0, 1, 0, 1},
  {&__pyx_n_u_SPACY, __pyx_k_SPACY, sizeof(__pyx_k_SPACY), 0, 1, 0, 1},
  {&__pyx_n_u_SUFFIX, __pyx_k_SUFFIX, sizeof(__pyx_k_SUFFIX), 0, 1, 0, 1},
  {&__pyx_n_u_SYM, __pyx_k_SYM, sizeof(__pyx_k_SYM), 0, 1, 0, 1},
  {&__pyx_n_u_StyleVariant_styleBound, __pyx_k_StyleVariant_styleBound, sizeof(__pyx_k_StyleVariant_styleBound), 0, 1, 0, 1},
  {&__pyx_n_u_StyleVariant_styleShort, __pyx_k_StyleVariant_styleShort, sizeof(__pyx_k_StyleVariant_styleShort), 0, 1, 0, 1},
  {&__pyx_n_u_Style_arch, __pyx_k_Style_arch, sizeof(__pyx_k_Style_arch), 0, 1, 0, 1},
  {&__pyx_n_u_Style_coll, __pyx_k_Style_coll, sizeof(__pyx_k_Style_coll), 0, 1, 0, 1},
  {&__pyx_n_u_Style_derg, __pyx_k_Style_derg, sizeof(__pyx_k_Style_derg), 0, 1, 0, 1},
  {&__pyx_n_u_Style_expr, __pyx_k_Style_expr, sizeof(__pyx_k_Style_expr), 0, 1, 0, 1},
  {&__pyx_n_u_Style_norm, __pyx_k_Style_norm, sizeof(__pyx_k_Style_norm), 0, 1, 0, 1},
  {&__pyx_n_u_Style_poet, __pyx_k_Style_poet, sizeof(__pyx_k_Style_poet), 0, 1, 0, 1},
  {&__pyx_n_u_Style_rare, __pyx_k_Style_rare, sizeof(__pyx_k_Style_rare), 0, 1, 0, 1},
  {&__pyx_n_u_Style_sing, __pyx_k_Style_sing, sizeof(__pyx_k_Style_sing), 0, 1, 0, 1},
  {&__pyx_n_u_Style_vrnc, __pyx_k_Style_vrnc, sizeof(__pyx_k_Style_vrnc), 0, 1, 0, 1},
  {&__pyx_n_u_Style_vulg, __pyx_k_Style_vulg, sizeof(__pyx_k_Style_vulg), 0, 1, 0, 1},
  {&__pyx_n_u_Style_yes, __pyx_k_Style_yes, sizeof(__pyx_k_Style_yes), 0, 1, 0, 1},
  {&__pyx_n_u_TAG, __pyx_k_TAG, sizeof(__pyx_k_TAG), 0, 1, 0, 1},
  {&__pyx_n_u_TIME, __pyx_k_TIME, sizeof(__pyx_k_TIME), 0, 1, 0, 1},
  {&__pyx_n_u_Tense_fut, __pyx_k_Tense_fut, sizeof(__pyx_k_Tense_fut), 0, 1, 0, 1},
  {&__pyx_n_u_Tense_imp, __pyx_k_Tense_imp, sizeof(__pyx_k_Tense_imp), 0, 1, 0, 1},
  {&__pyx_n_u_Tense_past, __pyx_k_Tense_past, sizeof(__pyx_k_Tense_past), 0, 1, 0, 1},
  {&__pyx_n_u_Tense_pres, __pyx_k_Tense_pres, sizeof(__pyx_k_Tense_pres), 0, 1, 0, 1},
  {&__pyx_n_u_VERB, __pyx_k_VERB, sizeof(__pyx_k_VERB), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_conv, __pyx_k_VerbForm_conv, sizeof(__pyx_k_VerbForm_conv), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_fin, __pyx_k_VerbForm_fin, sizeof(__pyx_k_VerbForm_fin), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_gdv, __pyx_k_VerbForm_gdv, sizeof(__pyx_k_VerbForm_gdv), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_ger, __pyx_k_VerbForm_ger, sizeof(__pyx_k_VerbForm_ger), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_inf, __pyx_k_VerbForm_inf, sizeof(__pyx_k_VerbForm_inf), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_none, __pyx_k_VerbForm_none, sizeof(__pyx_k_VerbForm_none), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_part, __pyx_k_VerbForm_part, sizeof(__pyx_k_VerbForm_part), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_partFut, __pyx_k_VerbForm_partFut, sizeof(__pyx_k_VerbForm_partFut), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_partPast, __pyx_k_VerbForm_partPast, sizeof(__pyx_k_VerbForm_partPast), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_partPres, __pyx_k_VerbForm_partPres, sizeof(__pyx_k_VerbForm_partPres), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_sup, __pyx_k_VerbForm_sup, sizeof(__pyx_k_VerbForm_sup), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_trans, __pyx_k_VerbForm_trans, sizeof(__pyx_k_VerbForm_trans), 0, 1, 0, 1},
  {&__pyx_n_u_VerbForm_vnoun, __pyx_k_VerbForm_vnoun, sizeof(__pyx_k_VerbForm_vnoun), 0, 1, 0, 1},
  {&__pyx_n_u_VerbType_aux, __pyx_k_VerbType_aux, sizeof(__pyx_k_VerbType_aux), 0, 1, 0, 1},
  {&__pyx_n_u_VerbType_cop, __pyx_k_VerbType_cop, sizeof(__pyx_k_VerbType_cop), 0, 1, 0, 1},
  {&__pyx_n_u_VerbType_light, __pyx_k_VerbType_light, sizeof(__pyx_k_VerbType_light), 0, 1, 0, 1},
  {&__pyx_n_u_VerbType_mod, __pyx_k_VerbType_mod, sizeof(__pyx_k_VerbType_mod), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_act, __pyx_k_Voice_act, sizeof(__pyx_k_Voice_act), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_antip, __pyx_k_Voice_antip, sizeof(__pyx_k_Voice_antip), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_cau, __pyx_k_Voice_cau, sizeof(__pyx_k_Voice_cau), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_dir, __pyx_k_Voice_dir, sizeof(__pyx_k_Voice_dir), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_int, __pyx_k_Voice_int, sizeof(__pyx_k_Voice_int), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_inv, __pyx_k_Voice_inv, sizeof(__pyx_k_Voice_inv), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_mid, __pyx_k_Voice_mid, sizeof(__pyx_k_Voice_mid), 0, 1, 0, 1},
  {&__pyx_n_u_Voice_pass, __pyx_k_Voice_pass, sizeof(__pyx_k_Voice_pass), 0, 1, 0, 1},
  {&__pyx_n_u_WORK_OF_ART, __pyx_k_WORK_OF_ART, sizeof(__pyx_k_WORK_OF_ART), 0, 1, 0, 1},
  {&__pyx_n_u_X, __pyx_k_X, sizeof(__pyx_k_X), 0, 1, 0, 1},
  {&__pyx_n_u_acl, __pyx_k_acl, sizeof(__pyx_k_acl), 0, 1, 0, 1},
  {&__pyx_n_u_acomp, __pyx_k_acomp, sizeof(__pyx_k_acomp), 0, 1, 0, 1},
  {&__pyx_n_u_advcl, __pyx_k_advcl, sizeof(__pyx_k_advcl), 0, 1, 0, 1},
  {&__pyx_n_u_advmod, __pyx_k_advmod, sizeof(__pyx_k_advmod), 0, 1, 0, 1},
  {&__pyx_n_u_agent, __pyx_k_agent, sizeof(__pyx_k_agent), 0, 1, 0, 1},
  {&__pyx_n_u_amod, __pyx_k_amod, sizeof(__pyx_k_amod), 0, 1, 0, 1},
  {&__pyx_n_u_appos, __pyx_k_appos, sizeof(__pyx_k_appos), 0, 1, 0, 1},
  {&__pyx_n_u_attr, __pyx_k_attr, sizeof(__pyx_k_attr), 0, 1, 0, 1},
  {&__pyx_n_u_aux, __pyx_k_aux, sizeof(__pyx_k_aux), 0, 1, 0, 1},
  {&__pyx_n_u_auxpass, __pyx_k_auxpass, sizeof(__pyx_k_auxpass), 0, 1, 0, 1},
  {&__pyx_n_u_cc, __pyx_k_cc, sizeof(__pyx_k_cc), 0, 1, 0, 1},
  {&__pyx_n_u_ccomp, __pyx_k_ccomp, sizeof(__pyx_k_ccomp), 0, 1, 0, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_u_complm, __pyx_k_complm, sizeof(__pyx_k_complm), 0, 1, 0, 1},
  {&__pyx_n_u_conj, __pyx_k_conj, sizeof(__pyx_k_conj), 0, 1, 0, 1},
  {&__pyx_n_u_cop, __pyx_k_cop, sizeof(__pyx_k_cop), 0, 1, 0, 1},
  {&__pyx_n_u_csubj, __pyx_k_csubj, sizeof(__pyx_k_csubj), 0, 1, 0, 1},
  {&__pyx_n_u_csubjpass, __pyx_k_csubjpass, sizeof(__pyx_k_csubjpass), 0, 1, 0, 1},
  {&__pyx_n_u_dep, __pyx_k_dep, sizeof(__pyx_k_dep), 0, 1, 0, 1},
  {&__pyx_n_u_det, __pyx_k_det, sizeof(__pyx_k_det), 0, 1, 0, 1},
  {&__pyx_n_u_dobj, __pyx_k_dobj, sizeof(__pyx_k_dobj), 0, 1, 0, 1},
  {&__pyx_n_u_expl, __pyx_k_expl, sizeof(__pyx_k_expl), 0, 1, 0, 1},
  {&__pyx_n_u_hmod, __pyx_k_hmod, sizeof(__pyx_k_hmod), 0, 1, 0, 1},
  {&__pyx_n_u_hyph, __pyx_k_hyph, sizeof(__pyx_k_hyph), 0, 1, 0, 1},
  {&__pyx_n_u_infmod, __pyx_k_infmod, sizeof(__pyx_k_infmod), 0, 1, 0, 1},
  {&__pyx_n_u_intj, __pyx_k_intj, sizeof(__pyx_k_intj), 0, 1, 0, 1},
  {&__pyx_n_u_iobj, __pyx_k_iobj, sizeof(__pyx_k_iobj), 0, 1, 0, 1},
  {&__pyx_n_s_it, __pyx_k_it, sizeof(__pyx_k_it), 0, 0, 1, 1},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_u_mark, __pyx_k_mark, sizeof(__pyx_k_mark), 0, 1, 0, 1},
  {&__pyx_n_u_meta, __pyx_k_meta, sizeof(__pyx_k_meta), 0, 1, 0, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_u_neg, __pyx_k_neg, sizeof(__pyx_k_neg), 0, 1, 0, 1},
  {&__pyx_n_u_nmod, __pyx_k_nmod, sizeof(__pyx_k_nmod), 0, 1, 0, 1},
  {&__pyx_n_u_nn, __pyx_k_nn, sizeof(__pyx_k_nn), 0, 1, 0, 1},
  {&__pyx_n_u_npadvmod, __pyx_k_npadvmod, sizeof(__pyx_k_npadvmod), 0, 1, 0, 1},
  {&__pyx_n_u_nsubj, __pyx_k_nsubj, sizeof(__pyx_k_nsubj), 0, 1, 0, 1},
  {&__pyx_n_u_nsubjpass, __pyx_k_nsubjpass, sizeof(__pyx_k_nsubjpass), 0, 1, 0, 1},
  {&__pyx_n_u_num, __pyx_k_num, sizeof(__pyx_k_num), 0, 1, 0, 1},
  {&__pyx_n_u_number, __pyx_k_number, sizeof(__pyx_k_number), 0, 1, 0, 1},
  {&__pyx_n_u_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 1, 0, 1},
  {&__pyx_n_u_obl, __pyx_k_obl, sizeof(__pyx_k_obl), 0, 1, 0, 1},
  {&__pyx_n_u_oprd, __pyx_k_oprd, sizeof(__pyx_k_oprd), 0, 1, 0, 1},
  {&__pyx_n_u_parataxis, __pyx_k_parataxis, sizeof(__pyx_k_parataxis), 0, 1, 0, 1},
  {&__pyx_n_u_partmod, __pyx_k_partmod, sizeof(__pyx_k_partmod), 0, 1, 0, 1},
  {&__pyx_n_u_pcomp, __pyx_k_pcomp, sizeof(__pyx_k_pcomp), 0, 1, 0, 1},
  {&__pyx_n_u_pobj, __pyx_k_pobj, sizeof(__pyx_k_pobj), 0, 1, 0, 1},
  {&__pyx_n_u_poss, __pyx_k_poss, sizeof(__pyx_k_poss), 0, 1, 0, 1},
  {&__pyx_n_u_possessive, __pyx_k_possessive, sizeof(__pyx_k_possessive), 0, 1, 0, 1},
  {&__pyx_n_u_preconj, __pyx_k_preconj, sizeof(__pyx_k_preconj), 0, 1, 0, 1},
  {&__pyx_n_u_prep, __pyx_k_prep, sizeof(__pyx_k_prep), 0, 1, 0, 1},
  {&__pyx_n_u_prt, __pyx_k_prt, sizeof(__pyx_k_prt), 0, 1, 0, 1},
  {&__pyx_n_u_punct, __pyx_k_punct, sizeof(__pyx_k_punct), 0, 1, 0, 1},
  {&__pyx_n_u_quantmod, __pyx_k_quantmod, sizeof(__pyx_k_quantmod), 0, 1, 0, 1},
  {&__pyx_n_u_rcmod, __pyx_k_rcmod, sizeof(__pyx_k_rcmod), 0, 1, 0, 1},
  {&__pyx_n_u_relcl, __pyx_k_relcl, sizeof(__pyx_k_relcl), 0, 1, 0, 1},
  {&__pyx_n_u_root, __pyx_k_root, sizeof(__pyx_k_root), 0, 1, 0, 1},
  {&__pyx_n_s_sort_nums, __pyx_k_sort_nums, sizeof(__pyx_k_sort_nums), 0, 0, 1, 1},
  {&__pyx_n_s_sorted, __pyx_k_sorted, sizeof(__pyx_k_sorted), 0, 0, 1, 1},
  {&__pyx_n_s_spacy_symbols, __pyx_k_spacy_symbols, sizeof(__pyx_k_spacy_symbols), 0, 0, 1, 1},
  {&__pyx_kp_s_symbols_pyx, __pyx_k_symbols_pyx, sizeof(__pyx_k_symbols_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {&__pyx_n_u_xcomp, __pyx_k_xcomp, sizeof(__pyx_k_xcomp), 0, 1, 0, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_sorted = __Pyx_GetBuiltinName(__pyx_n_s_sorted); if (!__pyx_builtin_sorted) __PYX_ERR(0, 479, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "spacy/symbols.pyx":474
 * 
 * 
 * def sort_nums(x):             # <<<<<<<<<<<<<<
 *     return x[1]
 * 
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_n_s_x); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);
  __pyx_codeobj__3 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__2, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_symbols_pyx, __pyx_n_s_sort_nums, 474, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__3)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initsymbols(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initsymbols(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_symbols(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_symbols(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_symbols(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'symbols' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_symbols(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("symbols", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_spacy__symbols) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "spacy.symbols")) {
      if (unlikely(PyDict_SetItemString(modules, "spacy.symbols", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "spacy/symbols.pyx":7
 * 
 * IDS = {
 *     "": NIL,             # <<<<<<<<<<<<<<
 *     "IS_ALPHA": IS_ALPHA,
 *     "IS_ASCII": IS_ASCII,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(455); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NIL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":8
 * IDS = {
 *     "": NIL,
 *     "IS_ALPHA": IS_ALPHA,             # <<<<<<<<<<<<<<
 *     "IS_ASCII": IS_ASCII,
 *     "IS_DIGIT": IS_DIGIT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_ALPHA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_ALPHA, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":9
 *     "": NIL,
 *     "IS_ALPHA": IS_ALPHA,
 *     "IS_ASCII": IS_ASCII,             # <<<<<<<<<<<<<<
 *     "IS_DIGIT": IS_DIGIT,
 *     "IS_LOWER": IS_LOWER,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_ASCII); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_ASCII, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":10
 *     "IS_ALPHA": IS_ALPHA,
 *     "IS_ASCII": IS_ASCII,
 *     "IS_DIGIT": IS_DIGIT,             # <<<<<<<<<<<<<<
 *     "IS_LOWER": IS_LOWER,
 *     "IS_PUNCT": IS_PUNCT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_DIGIT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_DIGIT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":11
 *     "IS_ASCII": IS_ASCII,
 *     "IS_DIGIT": IS_DIGIT,
 *     "IS_LOWER": IS_LOWER,             # <<<<<<<<<<<<<<
 *     "IS_PUNCT": IS_PUNCT,
 *     "IS_SPACE": IS_SPACE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_LOWER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_LOWER, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":12
 *     "IS_DIGIT": IS_DIGIT,
 *     "IS_LOWER": IS_LOWER,
 *     "IS_PUNCT": IS_PUNCT,             # <<<<<<<<<<<<<<
 *     "IS_SPACE": IS_SPACE,
 *     "IS_TITLE": IS_TITLE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_PUNCT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_PUNCT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":13
 *     "IS_LOWER": IS_LOWER,
 *     "IS_PUNCT": IS_PUNCT,
 *     "IS_SPACE": IS_SPACE,             # <<<<<<<<<<<<<<
 *     "IS_TITLE": IS_TITLE,
 *     "IS_UPPER": IS_UPPER,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_SPACE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_SPACE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":14
 *     "IS_PUNCT": IS_PUNCT,
 *     "IS_SPACE": IS_SPACE,
 *     "IS_TITLE": IS_TITLE,             # <<<<<<<<<<<<<<
 *     "IS_UPPER": IS_UPPER,
 *     "LIKE_URL": LIKE_URL,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_TITLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_TITLE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":15
 *     "IS_SPACE": IS_SPACE,
 *     "IS_TITLE": IS_TITLE,
 *     "IS_UPPER": IS_UPPER,             # <<<<<<<<<<<<<<
 *     "LIKE_URL": LIKE_URL,
 *     "LIKE_NUM": LIKE_NUM,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_UPPER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_UPPER, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":16
 *     "IS_TITLE": IS_TITLE,
 *     "IS_UPPER": IS_UPPER,
 *     "LIKE_URL": LIKE_URL,             # <<<<<<<<<<<<<<
 *     "LIKE_NUM": LIKE_NUM,
 *     "LIKE_EMAIL": LIKE_EMAIL,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LIKE_URL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LIKE_URL, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":17
 *     "IS_UPPER": IS_UPPER,
 *     "LIKE_URL": LIKE_URL,
 *     "LIKE_NUM": LIKE_NUM,             # <<<<<<<<<<<<<<
 *     "LIKE_EMAIL": LIKE_EMAIL,
 *     "IS_STOP": IS_STOP,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LIKE_NUM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LIKE_NUM, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":18
 *     "LIKE_URL": LIKE_URL,
 *     "LIKE_NUM": LIKE_NUM,
 *     "LIKE_EMAIL": LIKE_EMAIL,             # <<<<<<<<<<<<<<
 *     "IS_STOP": IS_STOP,
 *     "IS_OOV_DEPRECATED": IS_OOV_DEPRECATED,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LIKE_EMAIL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LIKE_EMAIL, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":19
 *     "LIKE_NUM": LIKE_NUM,
 *     "LIKE_EMAIL": LIKE_EMAIL,
 *     "IS_STOP": IS_STOP,             # <<<<<<<<<<<<<<
 *     "IS_OOV_DEPRECATED": IS_OOV_DEPRECATED,
 *     "IS_BRACKET": IS_BRACKET,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_STOP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_STOP, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":20
 *     "LIKE_EMAIL": LIKE_EMAIL,
 *     "IS_STOP": IS_STOP,
 *     "IS_OOV_DEPRECATED": IS_OOV_DEPRECATED,             # <<<<<<<<<<<<<<
 *     "IS_BRACKET": IS_BRACKET,
 *     "IS_QUOTE": IS_QUOTE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_OOV_DEPRECATED); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_OOV_DEPRECATED, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":21
 *     "IS_STOP": IS_STOP,
 *     "IS_OOV_DEPRECATED": IS_OOV_DEPRECATED,
 *     "IS_BRACKET": IS_BRACKET,             # <<<<<<<<<<<<<<
 *     "IS_QUOTE": IS_QUOTE,
 *     "IS_LEFT_PUNCT": IS_LEFT_PUNCT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_BRACKET); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_BRACKET, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":22
 *     "IS_OOV_DEPRECATED": IS_OOV_DEPRECATED,
 *     "IS_BRACKET": IS_BRACKET,
 *     "IS_QUOTE": IS_QUOTE,             # <<<<<<<<<<<<<<
 *     "IS_LEFT_PUNCT": IS_LEFT_PUNCT,
 *     "IS_RIGHT_PUNCT": IS_RIGHT_PUNCT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_QUOTE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_QUOTE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":23
 *     "IS_BRACKET": IS_BRACKET,
 *     "IS_QUOTE": IS_QUOTE,
 *     "IS_LEFT_PUNCT": IS_LEFT_PUNCT,             # <<<<<<<<<<<<<<
 *     "IS_RIGHT_PUNCT": IS_RIGHT_PUNCT,
 *     "IS_CURRENCY": IS_CURRENCY,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_LEFT_PUNCT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_LEFT_PUNCT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":24
 *     "IS_QUOTE": IS_QUOTE,
 *     "IS_LEFT_PUNCT": IS_LEFT_PUNCT,
 *     "IS_RIGHT_PUNCT": IS_RIGHT_PUNCT,             # <<<<<<<<<<<<<<
 *     "IS_CURRENCY": IS_CURRENCY,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_RIGHT_PUNCT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_RIGHT_PUNCT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":25
 *     "IS_LEFT_PUNCT": IS_LEFT_PUNCT,
 *     "IS_RIGHT_PUNCT": IS_RIGHT_PUNCT,
 *     "IS_CURRENCY": IS_CURRENCY,             # <<<<<<<<<<<<<<
 * 
 *     "FLAG19": FLAG19,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IS_CURRENCY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IS_CURRENCY, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":27
 *     "IS_CURRENCY": IS_CURRENCY,
 * 
 *     "FLAG19": FLAG19,             # <<<<<<<<<<<<<<
 *     "FLAG20": FLAG20,
 *     "FLAG21": FLAG21,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG19, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":28
 * 
 *     "FLAG19": FLAG19,
 *     "FLAG20": FLAG20,             # <<<<<<<<<<<<<<
 *     "FLAG21": FLAG21,
 *     "FLAG22": FLAG22,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG20); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG20, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":29
 *     "FLAG19": FLAG19,
 *     "FLAG20": FLAG20,
 *     "FLAG21": FLAG21,             # <<<<<<<<<<<<<<
 *     "FLAG22": FLAG22,
 *     "FLAG23": FLAG23,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG21); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG21, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":30
 *     "FLAG20": FLAG20,
 *     "FLAG21": FLAG21,
 *     "FLAG22": FLAG22,             # <<<<<<<<<<<<<<
 *     "FLAG23": FLAG23,
 *     "FLAG24": FLAG24,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG22); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG22, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":31
 *     "FLAG21": FLAG21,
 *     "FLAG22": FLAG22,
 *     "FLAG23": FLAG23,             # <<<<<<<<<<<<<<
 *     "FLAG24": FLAG24,
 *     "FLAG25": FLAG25,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG23); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG23, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":32
 *     "FLAG22": FLAG22,
 *     "FLAG23": FLAG23,
 *     "FLAG24": FLAG24,             # <<<<<<<<<<<<<<
 *     "FLAG25": FLAG25,
 *     "FLAG26": FLAG26,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG24); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG24, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":33
 *     "FLAG23": FLAG23,
 *     "FLAG24": FLAG24,
 *     "FLAG25": FLAG25,             # <<<<<<<<<<<<<<
 *     "FLAG26": FLAG26,
 *     "FLAG27": FLAG27,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG25); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG25, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":34
 *     "FLAG24": FLAG24,
 *     "FLAG25": FLAG25,
 *     "FLAG26": FLAG26,             # <<<<<<<<<<<<<<
 *     "FLAG27": FLAG27,
 *     "FLAG28": FLAG28,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG26); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG26, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":35
 *     "FLAG25": FLAG25,
 *     "FLAG26": FLAG26,
 *     "FLAG27": FLAG27,             # <<<<<<<<<<<<<<
 *     "FLAG28": FLAG28,
 *     "FLAG29": FLAG29,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG27); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG27, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":36
 *     "FLAG26": FLAG26,
 *     "FLAG27": FLAG27,
 *     "FLAG28": FLAG28,             # <<<<<<<<<<<<<<
 *     "FLAG29": FLAG29,
 *     "FLAG30": FLAG30,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG28); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG28, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":37
 *     "FLAG27": FLAG27,
 *     "FLAG28": FLAG28,
 *     "FLAG29": FLAG29,             # <<<<<<<<<<<<<<
 *     "FLAG30": FLAG30,
 *     "FLAG31": FLAG31,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG29); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG29, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":38
 *     "FLAG28": FLAG28,
 *     "FLAG29": FLAG29,
 *     "FLAG30": FLAG30,             # <<<<<<<<<<<<<<
 *     "FLAG31": FLAG31,
 *     "FLAG32": FLAG32,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG30); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG30, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":39
 *     "FLAG29": FLAG29,
 *     "FLAG30": FLAG30,
 *     "FLAG31": FLAG31,             # <<<<<<<<<<<<<<
 *     "FLAG32": FLAG32,
 *     "FLAG33": FLAG33,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG31); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG31, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":40
 *     "FLAG30": FLAG30,
 *     "FLAG31": FLAG31,
 *     "FLAG32": FLAG32,             # <<<<<<<<<<<<<<
 *     "FLAG33": FLAG33,
 *     "FLAG34": FLAG34,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG32); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG32, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":41
 *     "FLAG31": FLAG31,
 *     "FLAG32": FLAG32,
 *     "FLAG33": FLAG33,             # <<<<<<<<<<<<<<
 *     "FLAG34": FLAG34,
 *     "FLAG35": FLAG35,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG33); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG33, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":42
 *     "FLAG32": FLAG32,
 *     "FLAG33": FLAG33,
 *     "FLAG34": FLAG34,             # <<<<<<<<<<<<<<
 *     "FLAG35": FLAG35,
 *     "FLAG36": FLAG36,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG34); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG34, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":43
 *     "FLAG33": FLAG33,
 *     "FLAG34": FLAG34,
 *     "FLAG35": FLAG35,             # <<<<<<<<<<<<<<
 *     "FLAG36": FLAG36,
 *     "FLAG37": FLAG37,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG35); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG35, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":44
 *     "FLAG34": FLAG34,
 *     "FLAG35": FLAG35,
 *     "FLAG36": FLAG36,             # <<<<<<<<<<<<<<
 *     "FLAG37": FLAG37,
 *     "FLAG38": FLAG38,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG36); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG36, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":45
 *     "FLAG35": FLAG35,
 *     "FLAG36": FLAG36,
 *     "FLAG37": FLAG37,             # <<<<<<<<<<<<<<
 *     "FLAG38": FLAG38,
 *     "FLAG39": FLAG39,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG37); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG37, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":46
 *     "FLAG36": FLAG36,
 *     "FLAG37": FLAG37,
 *     "FLAG38": FLAG38,             # <<<<<<<<<<<<<<
 *     "FLAG39": FLAG39,
 *     "FLAG40": FLAG40,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG38); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG38, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":47
 *     "FLAG37": FLAG37,
 *     "FLAG38": FLAG38,
 *     "FLAG39": FLAG39,             # <<<<<<<<<<<<<<
 *     "FLAG40": FLAG40,
 *     "FLAG41": FLAG41,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG39); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG39, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":48
 *     "FLAG38": FLAG38,
 *     "FLAG39": FLAG39,
 *     "FLAG40": FLAG40,             # <<<<<<<<<<<<<<
 *     "FLAG41": FLAG41,
 *     "FLAG42": FLAG42,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG40); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG40, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":49
 *     "FLAG39": FLAG39,
 *     "FLAG40": FLAG40,
 *     "FLAG41": FLAG41,             # <<<<<<<<<<<<<<
 *     "FLAG42": FLAG42,
 *     "FLAG43": FLAG43,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG41); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG41, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":50
 *     "FLAG40": FLAG40,
 *     "FLAG41": FLAG41,
 *     "FLAG42": FLAG42,             # <<<<<<<<<<<<<<
 *     "FLAG43": FLAG43,
 *     "FLAG44": FLAG44,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG42); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG42, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":51
 *     "FLAG41": FLAG41,
 *     "FLAG42": FLAG42,
 *     "FLAG43": FLAG43,             # <<<<<<<<<<<<<<
 *     "FLAG44": FLAG44,
 *     "FLAG45": FLAG45,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG43); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG43, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":52
 *     "FLAG42": FLAG42,
 *     "FLAG43": FLAG43,
 *     "FLAG44": FLAG44,             # <<<<<<<<<<<<<<
 *     "FLAG45": FLAG45,
 *     "FLAG46": FLAG46,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG44); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG44, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":53
 *     "FLAG43": FLAG43,
 *     "FLAG44": FLAG44,
 *     "FLAG45": FLAG45,             # <<<<<<<<<<<<<<
 *     "FLAG46": FLAG46,
 *     "FLAG47": FLAG47,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG45); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG45, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":54
 *     "FLAG44": FLAG44,
 *     "FLAG45": FLAG45,
 *     "FLAG46": FLAG46,             # <<<<<<<<<<<<<<
 *     "FLAG47": FLAG47,
 *     "FLAG48": FLAG48,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG46); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG46, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":55
 *     "FLAG45": FLAG45,
 *     "FLAG46": FLAG46,
 *     "FLAG47": FLAG47,             # <<<<<<<<<<<<<<
 *     "FLAG48": FLAG48,
 *     "FLAG49": FLAG49,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG47); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG47, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":56
 *     "FLAG46": FLAG46,
 *     "FLAG47": FLAG47,
 *     "FLAG48": FLAG48,             # <<<<<<<<<<<<<<
 *     "FLAG49": FLAG49,
 *     "FLAG50": FLAG50,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG48); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG48, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":57
 *     "FLAG47": FLAG47,
 *     "FLAG48": FLAG48,
 *     "FLAG49": FLAG49,             # <<<<<<<<<<<<<<
 *     "FLAG50": FLAG50,
 *     "FLAG51": FLAG51,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG49); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG49, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":58
 *     "FLAG48": FLAG48,
 *     "FLAG49": FLAG49,
 *     "FLAG50": FLAG50,             # <<<<<<<<<<<<<<
 *     "FLAG51": FLAG51,
 *     "FLAG52": FLAG52,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG50); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG50, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":59
 *     "FLAG49": FLAG49,
 *     "FLAG50": FLAG50,
 *     "FLAG51": FLAG51,             # <<<<<<<<<<<<<<
 *     "FLAG52": FLAG52,
 *     "FLAG53": FLAG53,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG51); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG51, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":60
 *     "FLAG50": FLAG50,
 *     "FLAG51": FLAG51,
 *     "FLAG52": FLAG52,             # <<<<<<<<<<<<<<
 *     "FLAG53": FLAG53,
 *     "FLAG54": FLAG54,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG52); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG52, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":61
 *     "FLAG51": FLAG51,
 *     "FLAG52": FLAG52,
 *     "FLAG53": FLAG53,             # <<<<<<<<<<<<<<
 *     "FLAG54": FLAG54,
 *     "FLAG55": FLAG55,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG53); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG53, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":62
 *     "FLAG52": FLAG52,
 *     "FLAG53": FLAG53,
 *     "FLAG54": FLAG54,             # <<<<<<<<<<<<<<
 *     "FLAG55": FLAG55,
 *     "FLAG56": FLAG56,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG54); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG54, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":63
 *     "FLAG53": FLAG53,
 *     "FLAG54": FLAG54,
 *     "FLAG55": FLAG55,             # <<<<<<<<<<<<<<
 *     "FLAG56": FLAG56,
 *     "FLAG57": FLAG57,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG55); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG55, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":64
 *     "FLAG54": FLAG54,
 *     "FLAG55": FLAG55,
 *     "FLAG56": FLAG56,             # <<<<<<<<<<<<<<
 *     "FLAG57": FLAG57,
 *     "FLAG58": FLAG58,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG56); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG56, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":65
 *     "FLAG55": FLAG55,
 *     "FLAG56": FLAG56,
 *     "FLAG57": FLAG57,             # <<<<<<<<<<<<<<
 *     "FLAG58": FLAG58,
 *     "FLAG59": FLAG59,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG57); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG57, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":66
 *     "FLAG56": FLAG56,
 *     "FLAG57": FLAG57,
 *     "FLAG58": FLAG58,             # <<<<<<<<<<<<<<
 *     "FLAG59": FLAG59,
 *     "FLAG60": FLAG60,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG58); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG58, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":67
 *     "FLAG57": FLAG57,
 *     "FLAG58": FLAG58,
 *     "FLAG59": FLAG59,             # <<<<<<<<<<<<<<
 *     "FLAG60": FLAG60,
 *     "FLAG61": FLAG61,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG59); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG59, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":68
 *     "FLAG58": FLAG58,
 *     "FLAG59": FLAG59,
 *     "FLAG60": FLAG60,             # <<<<<<<<<<<<<<
 *     "FLAG61": FLAG61,
 *     "FLAG62": FLAG62,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG60); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG60, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":69
 *     "FLAG59": FLAG59,
 *     "FLAG60": FLAG60,
 *     "FLAG61": FLAG61,             # <<<<<<<<<<<<<<
 *     "FLAG62": FLAG62,
 *     "FLAG63": FLAG63,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG61); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG61, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":70
 *     "FLAG60": FLAG60,
 *     "FLAG61": FLAG61,
 *     "FLAG62": FLAG62,             # <<<<<<<<<<<<<<
 *     "FLAG63": FLAG63,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG62); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG62, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":71
 *     "FLAG61": FLAG61,
 *     "FLAG62": FLAG62,
 *     "FLAG63": FLAG63,             # <<<<<<<<<<<<<<
 * 
 *     "ID": ID,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FLAG63); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FLAG63, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":73
 *     "FLAG63": FLAG63,
 * 
 *     "ID": ID,             # <<<<<<<<<<<<<<
 *     "ORTH": ORTH,
 *     "LOWER": LOWER,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ID, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":74
 * 
 *     "ID": ID,
 *     "ORTH": ORTH,             # <<<<<<<<<<<<<<
 *     "LOWER": LOWER,
 *     "NORM": NORM,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ORTH); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ORTH, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":75
 *     "ID": ID,
 *     "ORTH": ORTH,
 *     "LOWER": LOWER,             # <<<<<<<<<<<<<<
 *     "NORM": NORM,
 *     "SHAPE": SHAPE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LOWER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LOWER, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":76
 *     "ORTH": ORTH,
 *     "LOWER": LOWER,
 *     "NORM": NORM,             # <<<<<<<<<<<<<<
 *     "SHAPE": SHAPE,
 *     "PREFIX": PREFIX,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NORM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NORM, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":77
 *     "LOWER": LOWER,
 *     "NORM": NORM,
 *     "SHAPE": SHAPE,             # <<<<<<<<<<<<<<
 *     "PREFIX": PREFIX,
 *     "SUFFIX": SUFFIX,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_SHAPE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SHAPE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":78
 *     "NORM": NORM,
 *     "SHAPE": SHAPE,
 *     "PREFIX": PREFIX,             # <<<<<<<<<<<<<<
 *     "SUFFIX": SUFFIX,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PREFIX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PREFIX, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":79
 *     "SHAPE": SHAPE,
 *     "PREFIX": PREFIX,
 *     "SUFFIX": SUFFIX,             # <<<<<<<<<<<<<<
 * 
 *     "LENGTH": LENGTH,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_SUFFIX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SUFFIX, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":81
 *     "SUFFIX": SUFFIX,
 * 
 *     "LENGTH": LENGTH,             # <<<<<<<<<<<<<<
 *     "CLUSTER": CLUSTER,
 *     "LEMMA": LEMMA,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LENGTH); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LENGTH, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":82
 * 
 *     "LENGTH": LENGTH,
 *     "CLUSTER": CLUSTER,             # <<<<<<<<<<<<<<
 *     "LEMMA": LEMMA,
 *     "POS": POS,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_CLUSTER); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_CLUSTER, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":83
 *     "LENGTH": LENGTH,
 *     "CLUSTER": CLUSTER,
 *     "LEMMA": LEMMA,             # <<<<<<<<<<<<<<
 *     "POS": POS,
 *     "TAG": TAG,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LEMMA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LEMMA, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":84
 *     "CLUSTER": CLUSTER,
 *     "LEMMA": LEMMA,
 *     "POS": POS,             # <<<<<<<<<<<<<<
 *     "TAG": TAG,
 *     "DEP": DEP,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_POS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_POS, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":85
 *     "LEMMA": LEMMA,
 *     "POS": POS,
 *     "TAG": TAG,             # <<<<<<<<<<<<<<
 *     "DEP": DEP,
 *     "ENT_IOB": ENT_IOB,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_TAG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_TAG, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":86
 *     "POS": POS,
 *     "TAG": TAG,
 *     "DEP": DEP,             # <<<<<<<<<<<<<<
 *     "ENT_IOB": ENT_IOB,
 *     "ENT_TYPE": ENT_TYPE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_DEP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_DEP, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":87
 *     "TAG": TAG,
 *     "DEP": DEP,
 *     "ENT_IOB": ENT_IOB,             # <<<<<<<<<<<<<<
 *     "ENT_TYPE": ENT_TYPE,
 *     "ENT_ID": ENT_ID,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ENT_IOB); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ENT_IOB, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":88
 *     "DEP": DEP,
 *     "ENT_IOB": ENT_IOB,
 *     "ENT_TYPE": ENT_TYPE,             # <<<<<<<<<<<<<<
 *     "ENT_ID": ENT_ID,
 *     "ENT_KB_ID": ENT_KB_ID,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ENT_TYPE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ENT_TYPE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":89
 *     "ENT_IOB": ENT_IOB,
 *     "ENT_TYPE": ENT_TYPE,
 *     "ENT_ID": ENT_ID,             # <<<<<<<<<<<<<<
 *     "ENT_KB_ID": ENT_KB_ID,
 *     "HEAD": HEAD,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ENT_ID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ENT_ID, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":90
 *     "ENT_TYPE": ENT_TYPE,
 *     "ENT_ID": ENT_ID,
 *     "ENT_KB_ID": ENT_KB_ID,             # <<<<<<<<<<<<<<
 *     "HEAD": HEAD,
 *     "SENT_START": SENT_START,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ENT_KB_ID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ENT_KB_ID, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":91
 *     "ENT_ID": ENT_ID,
 *     "ENT_KB_ID": ENT_KB_ID,
 *     "HEAD": HEAD,             # <<<<<<<<<<<<<<
 *     "SENT_START": SENT_START,
 *     "SPACY": SPACY,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_HEAD); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_HEAD, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":92
 *     "ENT_KB_ID": ENT_KB_ID,
 *     "HEAD": HEAD,
 *     "SENT_START": SENT_START,             # <<<<<<<<<<<<<<
 *     "SPACY": SPACY,
 *     "PROB": PROB,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_SENT_START); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SENT_START, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":93
 *     "HEAD": HEAD,
 *     "SENT_START": SENT_START,
 *     "SPACY": SPACY,             # <<<<<<<<<<<<<<
 *     "PROB": PROB,
 *     "LANG": LANG,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_SPACY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SPACY, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":94
 *     "SENT_START": SENT_START,
 *     "SPACY": SPACY,
 *     "PROB": PROB,             # <<<<<<<<<<<<<<
 *     "LANG": LANG,
 *     "IDX": IDX,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PROB); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PROB, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":95
 *     "SPACY": SPACY,
 *     "PROB": PROB,
 *     "LANG": LANG,             # <<<<<<<<<<<<<<
 *     "IDX": IDX,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LANG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LANG, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":96
 *     "PROB": PROB,
 *     "LANG": LANG,
 *     "IDX": IDX,             # <<<<<<<<<<<<<<
 * 
 *     "ADJ": ADJ,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_IDX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_IDX, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":98
 *     "IDX": IDX,
 * 
 *     "ADJ": ADJ,             # <<<<<<<<<<<<<<
 *     "ADP": ADP,
 *     "ADV": ADV,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ADJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ADJ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":99
 * 
 *     "ADJ": ADJ,
 *     "ADP": ADP,             # <<<<<<<<<<<<<<
 *     "ADV": ADV,
 *     "AUX": AUX,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ADP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ADP, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":100
 *     "ADJ": ADJ,
 *     "ADP": ADP,
 *     "ADV": ADV,             # <<<<<<<<<<<<<<
 *     "AUX": AUX,
 *     "CONJ": CONJ,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ADV); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ADV, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":101
 *     "ADP": ADP,
 *     "ADV": ADV,
 *     "AUX": AUX,             # <<<<<<<<<<<<<<
 *     "CONJ": CONJ,
 *     "CCONJ": CCONJ, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AUX); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AUX, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":102
 *     "ADV": ADV,
 *     "AUX": AUX,
 *     "CONJ": CONJ,             # <<<<<<<<<<<<<<
 *     "CCONJ": CCONJ, # U20
 *     "DET": DET,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_CONJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_CONJ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":103
 *     "AUX": AUX,
 *     "CONJ": CONJ,
 *     "CCONJ": CCONJ, # U20             # <<<<<<<<<<<<<<
 *     "DET": DET,
 *     "INTJ": INTJ,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_CCONJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_CCONJ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":104
 *     "CONJ": CONJ,
 *     "CCONJ": CCONJ, # U20
 *     "DET": DET,             # <<<<<<<<<<<<<<
 *     "INTJ": INTJ,
 *     "NOUN": NOUN,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_DET); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_DET, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":105
 *     "CCONJ": CCONJ, # U20
 *     "DET": DET,
 *     "INTJ": INTJ,             # <<<<<<<<<<<<<<
 *     "NOUN": NOUN,
 *     "NUM": NUM,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_INTJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_INTJ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":106
 *     "DET": DET,
 *     "INTJ": INTJ,
 *     "NOUN": NOUN,             # <<<<<<<<<<<<<<
 *     "NUM": NUM,
 *     "PART": PART,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NOUN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NOUN, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":107
 *     "INTJ": INTJ,
 *     "NOUN": NOUN,
 *     "NUM": NUM,             # <<<<<<<<<<<<<<
 *     "PART": PART,
 *     "PRON": PRON,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NUM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NUM, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":108
 *     "NOUN": NOUN,
 *     "NUM": NUM,
 *     "PART": PART,             # <<<<<<<<<<<<<<
 *     "PRON": PRON,
 *     "PROPN": PROPN,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PART); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PART, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":109
 *     "NUM": NUM,
 *     "PART": PART,
 *     "PRON": PRON,             # <<<<<<<<<<<<<<
 *     "PROPN": PROPN,
 *     "PUNCT": PUNCT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PRON); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PRON, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":110
 *     "PART": PART,
 *     "PRON": PRON,
 *     "PROPN": PROPN,             # <<<<<<<<<<<<<<
 *     "PUNCT": PUNCT,
 *     "SCONJ": SCONJ,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PROPN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PROPN, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":111
 *     "PRON": PRON,
 *     "PROPN": PROPN,
 *     "PUNCT": PUNCT,             # <<<<<<<<<<<<<<
 *     "SCONJ": SCONJ,
 *     "SYM": SYM,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PUNCT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PUNCT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":112
 *     "PROPN": PROPN,
 *     "PUNCT": PUNCT,
 *     "SCONJ": SCONJ,             # <<<<<<<<<<<<<<
 *     "SYM": SYM,
 *     "VERB": VERB,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_SCONJ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SCONJ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":113
 *     "PUNCT": PUNCT,
 *     "SCONJ": SCONJ,
 *     "SYM": SYM,             # <<<<<<<<<<<<<<
 *     "VERB": VERB,
 *     "X": X,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_SYM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SYM, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":114
 *     "SCONJ": SCONJ,
 *     "SYM": SYM,
 *     "VERB": VERB,             # <<<<<<<<<<<<<<
 *     "X": X,
 *     "EOL": EOL,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VERB); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VERB, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":115
 *     "SYM": SYM,
 *     "VERB": VERB,
 *     "X": X,             # <<<<<<<<<<<<<<
 *     "EOL": EOL,
 *     "SPACE": SPACE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_X); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_X, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":116
 *     "VERB": VERB,
 *     "X": X,
 *     "EOL": EOL,             # <<<<<<<<<<<<<<
 *     "SPACE": SPACE,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_EOL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_EOL, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":117
 *     "X": X,
 *     "EOL": EOL,
 *     "SPACE": SPACE,             # <<<<<<<<<<<<<<
 * 
 *     "Animacy_anim": Animacy_anim,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_SPACE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SPACE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":119
 *     "SPACE": SPACE,
 * 
 *     "Animacy_anim": Animacy_anim,             # <<<<<<<<<<<<<<
 *     "Animacy_inam": Animacy_inan,
 *     "Animacy_hum": Animacy_hum, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Animacy_anim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Animacy_anim, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":120
 * 
 *     "Animacy_anim": Animacy_anim,
 *     "Animacy_inam": Animacy_inan,             # <<<<<<<<<<<<<<
 *     "Animacy_hum": Animacy_hum, # U20
 *     "Animacy_nhum": Animacy_nhum,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Animacy_inan); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Animacy_inam, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":121
 *     "Animacy_anim": Animacy_anim,
 *     "Animacy_inam": Animacy_inan,
 *     "Animacy_hum": Animacy_hum, # U20             # <<<<<<<<<<<<<<
 *     "Animacy_nhum": Animacy_nhum,
 *     "Aspect_freq": Aspect_freq,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Animacy_hum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Animacy_hum, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":122
 *     "Animacy_inam": Animacy_inan,
 *     "Animacy_hum": Animacy_hum, # U20
 *     "Animacy_nhum": Animacy_nhum,             # <<<<<<<<<<<<<<
 *     "Aspect_freq": Aspect_freq,
 *     "Aspect_imp": Aspect_imp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Animacy_nhum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Animacy_nhum, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":123
 *     "Animacy_hum": Animacy_hum, # U20
 *     "Animacy_nhum": Animacy_nhum,
 *     "Aspect_freq": Aspect_freq,             # <<<<<<<<<<<<<<
 *     "Aspect_imp": Aspect_imp,
 *     "Aspect_mod": Aspect_mod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Aspect_freq); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Aspect_freq, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":124
 *     "Animacy_nhum": Animacy_nhum,
 *     "Aspect_freq": Aspect_freq,
 *     "Aspect_imp": Aspect_imp,             # <<<<<<<<<<<<<<
 *     "Aspect_mod": Aspect_mod,
 *     "Aspect_none": Aspect_none,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Aspect_imp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Aspect_imp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":125
 *     "Aspect_freq": Aspect_freq,
 *     "Aspect_imp": Aspect_imp,
 *     "Aspect_mod": Aspect_mod,             # <<<<<<<<<<<<<<
 *     "Aspect_none": Aspect_none,
 *     "Aspect_perf": Aspect_perf,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Aspect_mod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Aspect_mod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":126
 *     "Aspect_imp": Aspect_imp,
 *     "Aspect_mod": Aspect_mod,
 *     "Aspect_none": Aspect_none,             # <<<<<<<<<<<<<<
 *     "Aspect_perf": Aspect_perf,
 *     "Aspect_iter": Aspect_iter, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Aspect_none); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Aspect_none, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":127
 *     "Aspect_mod": Aspect_mod,
 *     "Aspect_none": Aspect_none,
 *     "Aspect_perf": Aspect_perf,             # <<<<<<<<<<<<<<
 *     "Aspect_iter": Aspect_iter, # U20
 *     "Aspect_hab": Aspect_hab, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Aspect_perf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Aspect_perf, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":128
 *     "Aspect_none": Aspect_none,
 *     "Aspect_perf": Aspect_perf,
 *     "Aspect_iter": Aspect_iter, # U20             # <<<<<<<<<<<<<<
 *     "Aspect_hab": Aspect_hab, # U20
 *     "Case_abe": Case_abe,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Aspect_iter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Aspect_iter, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":129
 *     "Aspect_perf": Aspect_perf,
 *     "Aspect_iter": Aspect_iter, # U20
 *     "Aspect_hab": Aspect_hab, # U20             # <<<<<<<<<<<<<<
 *     "Case_abe": Case_abe,
 *     "Case_abl": Case_abl,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Aspect_hab); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Aspect_hab, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":130
 *     "Aspect_iter": Aspect_iter, # U20
 *     "Aspect_hab": Aspect_hab, # U20
 *     "Case_abe": Case_abe,             # <<<<<<<<<<<<<<
 *     "Case_abl": Case_abl,
 *     "Case_abs": Case_abs,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_abe); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_abe, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":131
 *     "Aspect_hab": Aspect_hab, # U20
 *     "Case_abe": Case_abe,
 *     "Case_abl": Case_abl,             # <<<<<<<<<<<<<<
 *     "Case_abs": Case_abs,
 *     "Case_acc": Case_acc,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_abl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_abl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":132
 *     "Case_abe": Case_abe,
 *     "Case_abl": Case_abl,
 *     "Case_abs": Case_abs,             # <<<<<<<<<<<<<<
 *     "Case_acc": Case_acc,
 *     "Case_ade": Case_ade,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_abs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_abs, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":133
 *     "Case_abl": Case_abl,
 *     "Case_abs": Case_abs,
 *     "Case_acc": Case_acc,             # <<<<<<<<<<<<<<
 *     "Case_ade": Case_ade,
 *     "Case_all": Case_all,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_acc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_acc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":134
 *     "Case_abs": Case_abs,
 *     "Case_acc": Case_acc,
 *     "Case_ade": Case_ade,             # <<<<<<<<<<<<<<
 *     "Case_all": Case_all,
 *     "Case_cau": Case_cau,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_ade); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_ade, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":135
 *     "Case_acc": Case_acc,
 *     "Case_ade": Case_ade,
 *     "Case_all": Case_all,             # <<<<<<<<<<<<<<
 *     "Case_cau": Case_cau,
 *     "Case_com": Case_com,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_all); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_all, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":136
 *     "Case_ade": Case_ade,
 *     "Case_all": Case_all,
 *     "Case_cau": Case_cau,             # <<<<<<<<<<<<<<
 *     "Case_com": Case_com,
 *     "Case_cmp": Case_cmp, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_cau); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_cau, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":137
 *     "Case_all": Case_all,
 *     "Case_cau": Case_cau,
 *     "Case_com": Case_com,             # <<<<<<<<<<<<<<
 *     "Case_cmp": Case_cmp, # U20
 *     "Case_dat": Case_dat,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_com); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_com, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":138
 *     "Case_cau": Case_cau,
 *     "Case_com": Case_com,
 *     "Case_cmp": Case_cmp, # U20             # <<<<<<<<<<<<<<
 *     "Case_dat": Case_dat,
 *     "Case_del": Case_del,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_cmp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_cmp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":139
 *     "Case_com": Case_com,
 *     "Case_cmp": Case_cmp, # U20
 *     "Case_dat": Case_dat,             # <<<<<<<<<<<<<<
 *     "Case_del": Case_del,
 *     "Case_dis": Case_dis,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_dat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_dat, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":140
 *     "Case_cmp": Case_cmp, # U20
 *     "Case_dat": Case_dat,
 *     "Case_del": Case_del,             # <<<<<<<<<<<<<<
 *     "Case_dis": Case_dis,
 *     "Case_ela": Case_ela,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_del); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_del, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":141
 *     "Case_dat": Case_dat,
 *     "Case_del": Case_del,
 *     "Case_dis": Case_dis,             # <<<<<<<<<<<<<<
 *     "Case_ela": Case_ela,
 *     "Case_equ": Case_equ, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_dis); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_dis, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":142
 *     "Case_del": Case_del,
 *     "Case_dis": Case_dis,
 *     "Case_ela": Case_ela,             # <<<<<<<<<<<<<<
 *     "Case_equ": Case_equ, # U20
 *     "Case_ess": Case_ess,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_ela); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_ela, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":143
 *     "Case_dis": Case_dis,
 *     "Case_ela": Case_ela,
 *     "Case_equ": Case_equ, # U20             # <<<<<<<<<<<<<<
 *     "Case_ess": Case_ess,
 *     "Case_gen": Case_gen,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_equ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_equ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":144
 *     "Case_ela": Case_ela,
 *     "Case_equ": Case_equ, # U20
 *     "Case_ess": Case_ess,             # <<<<<<<<<<<<<<
 *     "Case_gen": Case_gen,
 *     "Case_ill": Case_ill,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_ess); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_ess, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":145
 *     "Case_equ": Case_equ, # U20
 *     "Case_ess": Case_ess,
 *     "Case_gen": Case_gen,             # <<<<<<<<<<<<<<
 *     "Case_ill": Case_ill,
 *     "Case_ine": Case_ine,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_gen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_gen, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":146
 *     "Case_ess": Case_ess,
 *     "Case_gen": Case_gen,
 *     "Case_ill": Case_ill,             # <<<<<<<<<<<<<<
 *     "Case_ine": Case_ine,
 *     "Case_ins": Case_ins,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_ill); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_ill, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":147
 *     "Case_gen": Case_gen,
 *     "Case_ill": Case_ill,
 *     "Case_ine": Case_ine,             # <<<<<<<<<<<<<<
 *     "Case_ins": Case_ins,
 *     "Case_loc": Case_loc,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_ine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_ine, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":148
 *     "Case_ill": Case_ill,
 *     "Case_ine": Case_ine,
 *     "Case_ins": Case_ins,             # <<<<<<<<<<<<<<
 *     "Case_loc": Case_loc,
 *     "Case_lat": Case_lat,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_ins); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_ins, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":149
 *     "Case_ine": Case_ine,
 *     "Case_ins": Case_ins,
 *     "Case_loc": Case_loc,             # <<<<<<<<<<<<<<
 *     "Case_lat": Case_lat,
 *     "Case_nom": Case_nom,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_loc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":150
 *     "Case_ins": Case_ins,
 *     "Case_loc": Case_loc,
 *     "Case_lat": Case_lat,             # <<<<<<<<<<<<<<
 *     "Case_nom": Case_nom,
 *     "Case_par": Case_par,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_lat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_lat, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":151
 *     "Case_loc": Case_loc,
 *     "Case_lat": Case_lat,
 *     "Case_nom": Case_nom,             # <<<<<<<<<<<<<<
 *     "Case_par": Case_par,
 *     "Case_sub": Case_sub,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_nom); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_nom, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":152
 *     "Case_lat": Case_lat,
 *     "Case_nom": Case_nom,
 *     "Case_par": Case_par,             # <<<<<<<<<<<<<<
 *     "Case_sub": Case_sub,
 *     "Case_sup": Case_sup,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_par); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_par, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":153
 *     "Case_nom": Case_nom,
 *     "Case_par": Case_par,
 *     "Case_sub": Case_sub,             # <<<<<<<<<<<<<<
 *     "Case_sup": Case_sup,
 *     "Case_tem": Case_tem,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_sub); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_sub, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":154
 *     "Case_par": Case_par,
 *     "Case_sub": Case_sub,
 *     "Case_sup": Case_sup,             # <<<<<<<<<<<<<<
 *     "Case_tem": Case_tem,
 *     "Case_ter": Case_ter,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_sup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_sup, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":155
 *     "Case_sub": Case_sub,
 *     "Case_sup": Case_sup,
 *     "Case_tem": Case_tem,             # <<<<<<<<<<<<<<
 *     "Case_ter": Case_ter,
 *     "Case_tra": Case_tra,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_tem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_tem, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":156
 *     "Case_sup": Case_sup,
 *     "Case_tem": Case_tem,
 *     "Case_ter": Case_ter,             # <<<<<<<<<<<<<<
 *     "Case_tra": Case_tra,
 *     "Case_voc": Case_voc,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_ter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_ter, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":157
 *     "Case_tem": Case_tem,
 *     "Case_ter": Case_ter,
 *     "Case_tra": Case_tra,             # <<<<<<<<<<<<<<
 *     "Case_voc": Case_voc,
 *     "Definite_two": Definite_two,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_tra); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_tra, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":158
 *     "Case_ter": Case_ter,
 *     "Case_tra": Case_tra,
 *     "Case_voc": Case_voc,             # <<<<<<<<<<<<<<
 *     "Definite_two": Definite_two,
 *     "Definite_def": Definite_def,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Case_voc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Case_voc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":159
 *     "Case_tra": Case_tra,
 *     "Case_voc": Case_voc,
 *     "Definite_two": Definite_two,             # <<<<<<<<<<<<<<
 *     "Definite_def": Definite_def,
 *     "Definite_red": Definite_red,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Definite_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Definite_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":160
 *     "Case_voc": Case_voc,
 *     "Definite_two": Definite_two,
 *     "Definite_def": Definite_def,             # <<<<<<<<<<<<<<
 *     "Definite_red": Definite_red,
 *     "Definite_cons": Definite_cons, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Definite_def); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Definite_def, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":161
 *     "Definite_two": Definite_two,
 *     "Definite_def": Definite_def,
 *     "Definite_red": Definite_red,             # <<<<<<<<<<<<<<
 *     "Definite_cons": Definite_cons, # U20
 *     "Definite_ind": Definite_ind,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Definite_red); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Definite_red, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":162
 *     "Definite_def": Definite_def,
 *     "Definite_red": Definite_red,
 *     "Definite_cons": Definite_cons, # U20             # <<<<<<<<<<<<<<
 *     "Definite_ind": Definite_ind,
 *     "Definite_spec": Definite_spec, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Definite_cons); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Definite_cons, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":163
 *     "Definite_red": Definite_red,
 *     "Definite_cons": Definite_cons, # U20
 *     "Definite_ind": Definite_ind,             # <<<<<<<<<<<<<<
 *     "Definite_spec": Definite_spec, # U20
 *     "Degree_cmp": Degree_cmp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Definite_ind); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Definite_ind, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":164
 *     "Definite_cons": Definite_cons, # U20
 *     "Definite_ind": Definite_ind,
 *     "Definite_spec": Definite_spec, # U20             # <<<<<<<<<<<<<<
 *     "Degree_cmp": Degree_cmp,
 *     "Degree_comp": Degree_comp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Definite_spec); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Definite_spec, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":165
 *     "Definite_ind": Definite_ind,
 *     "Definite_spec": Definite_spec, # U20
 *     "Degree_cmp": Degree_cmp,             # <<<<<<<<<<<<<<
 *     "Degree_comp": Degree_comp,
 *     "Degree_none": Degree_none,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_cmp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_cmp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":166
 *     "Definite_spec": Definite_spec, # U20
 *     "Degree_cmp": Degree_cmp,
 *     "Degree_comp": Degree_comp,             # <<<<<<<<<<<<<<
 *     "Degree_none": Degree_none,
 *     "Degree_pos": Degree_pos,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_comp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_comp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":167
 *     "Degree_cmp": Degree_cmp,
 *     "Degree_comp": Degree_comp,
 *     "Degree_none": Degree_none,             # <<<<<<<<<<<<<<
 *     "Degree_pos": Degree_pos,
 *     "Degree_sup": Degree_sup,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_none); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_none, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":168
 *     "Degree_comp": Degree_comp,
 *     "Degree_none": Degree_none,
 *     "Degree_pos": Degree_pos,             # <<<<<<<<<<<<<<
 *     "Degree_sup": Degree_sup,
 *     "Degree_abs": Degree_abs,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_pos, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":169
 *     "Degree_none": Degree_none,
 *     "Degree_pos": Degree_pos,
 *     "Degree_sup": Degree_sup,             # <<<<<<<<<<<<<<
 *     "Degree_abs": Degree_abs,
 *     "Degree_com": Degree_com,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_sup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_sup, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":170
 *     "Degree_pos": Degree_pos,
 *     "Degree_sup": Degree_sup,
 *     "Degree_abs": Degree_abs,             # <<<<<<<<<<<<<<
 *     "Degree_com": Degree_com,
 *     "Degree_dim": Degree_dim, # du
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_abs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_abs, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":171
 *     "Degree_sup": Degree_sup,
 *     "Degree_abs": Degree_abs,
 *     "Degree_com": Degree_com,             # <<<<<<<<<<<<<<
 *     "Degree_dim": Degree_dim, # du
 *     "Degree_equ": Degree_equ, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_com); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_com, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":172
 *     "Degree_abs": Degree_abs,
 *     "Degree_com": Degree_com,
 *     "Degree_dim": Degree_dim, # du             # <<<<<<<<<<<<<<
 *     "Degree_equ": Degree_equ, # U20
 *     "Evident_nfh": Evident_nfh, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_dim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_dim, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":173
 *     "Degree_com": Degree_com,
 *     "Degree_dim": Degree_dim, # du
 *     "Degree_equ": Degree_equ, # U20             # <<<<<<<<<<<<<<
 *     "Evident_nfh": Evident_nfh, # U20
 *     "Gender_com": Gender_com,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Degree_equ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Degree_equ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":174
 *     "Degree_dim": Degree_dim, # du
 *     "Degree_equ": Degree_equ, # U20
 *     "Evident_nfh": Evident_nfh, # U20             # <<<<<<<<<<<<<<
 *     "Gender_com": Gender_com,
 *     "Gender_fem": Gender_fem,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Evident_nfh); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Evident_nfh, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":175
 *     "Degree_equ": Degree_equ, # U20
 *     "Evident_nfh": Evident_nfh, # U20
 *     "Gender_com": Gender_com,             # <<<<<<<<<<<<<<
 *     "Gender_fem": Gender_fem,
 *     "Gender_masc": Gender_masc,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_com); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_com, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":176
 *     "Evident_nfh": Evident_nfh, # U20
 *     "Gender_com": Gender_com,
 *     "Gender_fem": Gender_fem,             # <<<<<<<<<<<<<<
 *     "Gender_masc": Gender_masc,
 *     "Gender_neut": Gender_neut,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_fem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_fem, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":177
 *     "Gender_com": Gender_com,
 *     "Gender_fem": Gender_fem,
 *     "Gender_masc": Gender_masc,             # <<<<<<<<<<<<<<
 *     "Gender_neut": Gender_neut,
 *     "Mood_cnd": Mood_cnd,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_masc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_masc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":178
 *     "Gender_fem": Gender_fem,
 *     "Gender_masc": Gender_masc,
 *     "Gender_neut": Gender_neut,             # <<<<<<<<<<<<<<
 *     "Mood_cnd": Mood_cnd,
 *     "Mood_imp": Mood_imp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_neut); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_neut, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":179
 *     "Gender_masc": Gender_masc,
 *     "Gender_neut": Gender_neut,
 *     "Mood_cnd": Mood_cnd,             # <<<<<<<<<<<<<<
 *     "Mood_imp": Mood_imp,
 *     "Mood_ind": Mood_ind,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_cnd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_cnd, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":180
 *     "Gender_neut": Gender_neut,
 *     "Mood_cnd": Mood_cnd,
 *     "Mood_imp": Mood_imp,             # <<<<<<<<<<<<<<
 *     "Mood_ind": Mood_ind,
 *     "Mood_n": Mood_n,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_imp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_imp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":181
 *     "Mood_cnd": Mood_cnd,
 *     "Mood_imp": Mood_imp,
 *     "Mood_ind": Mood_ind,             # <<<<<<<<<<<<<<
 *     "Mood_n": Mood_n,
 *     "Mood_pot": Mood_pot,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_ind); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_ind, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":182
 *     "Mood_imp": Mood_imp,
 *     "Mood_ind": Mood_ind,
 *     "Mood_n": Mood_n,             # <<<<<<<<<<<<<<
 *     "Mood_pot": Mood_pot,
 *     "Mood_sub": Mood_sub,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_n, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":183
 *     "Mood_ind": Mood_ind,
 *     "Mood_n": Mood_n,
 *     "Mood_pot": Mood_pot,             # <<<<<<<<<<<<<<
 *     "Mood_sub": Mood_sub,
 *     "Mood_opt": Mood_opt,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_pot); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_pot, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":184
 *     "Mood_n": Mood_n,
 *     "Mood_pot": Mood_pot,
 *     "Mood_sub": Mood_sub,             # <<<<<<<<<<<<<<
 *     "Mood_opt": Mood_opt,
 *     "Mood_prp": Mood_prp, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_sub); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_sub, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":185
 *     "Mood_pot": Mood_pot,
 *     "Mood_sub": Mood_sub,
 *     "Mood_opt": Mood_opt,             # <<<<<<<<<<<<<<
 *     "Mood_prp": Mood_prp, # U20
 *     "Mood_adm": Mood_adm, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_opt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_opt, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":186
 *     "Mood_sub": Mood_sub,
 *     "Mood_opt": Mood_opt,
 *     "Mood_prp": Mood_prp, # U20             # <<<<<<<<<<<<<<
 *     "Mood_adm": Mood_adm, # U20
 *     "Negative_neg": Negative_neg,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_prp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_prp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":187
 *     "Mood_opt": Mood_opt,
 *     "Mood_prp": Mood_prp, # U20
 *     "Mood_adm": Mood_adm, # U20             # <<<<<<<<<<<<<<
 *     "Negative_neg": Negative_neg,
 *     "Negative_pos": Negative_pos,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Mood_adm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Mood_adm, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":188
 *     "Mood_prp": Mood_prp, # U20
 *     "Mood_adm": Mood_adm, # U20
 *     "Negative_neg": Negative_neg,             # <<<<<<<<<<<<<<
 *     "Negative_pos": Negative_pos,
 *     "Negative_yes": Negative_yes,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Negative_neg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Negative_neg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":189
 *     "Mood_adm": Mood_adm, # U20
 *     "Negative_neg": Negative_neg,
 *     "Negative_pos": Negative_pos,             # <<<<<<<<<<<<<<
 *     "Negative_yes": Negative_yes,
 *     "Polarity_neg": Polarity_neg, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Negative_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Negative_pos, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":190
 *     "Negative_neg": Negative_neg,
 *     "Negative_pos": Negative_pos,
 *     "Negative_yes": Negative_yes,             # <<<<<<<<<<<<<<
 *     "Polarity_neg": Polarity_neg, # U20
 *     "Polarity_pos": Polarity_pos, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Negative_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Negative_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":191
 *     "Negative_pos": Negative_pos,
 *     "Negative_yes": Negative_yes,
 *     "Polarity_neg": Polarity_neg, # U20             # <<<<<<<<<<<<<<
 *     "Polarity_pos": Polarity_pos, # U20
 *     "Number_com": Number_com,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polarity_neg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polarity_neg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":192
 *     "Negative_yes": Negative_yes,
 *     "Polarity_neg": Polarity_neg, # U20
 *     "Polarity_pos": Polarity_pos, # U20             # <<<<<<<<<<<<<<
 *     "Number_com": Number_com,
 *     "Number_dual": Number_dual,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polarity_pos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polarity_pos, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":193
 *     "Polarity_neg": Polarity_neg, # U20
 *     "Polarity_pos": Polarity_pos, # U20
 *     "Number_com": Number_com,             # <<<<<<<<<<<<<<
 *     "Number_dual": Number_dual,
 *     "Number_none": Number_none,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_com); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_com, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":194
 *     "Polarity_pos": Polarity_pos, # U20
 *     "Number_com": Number_com,
 *     "Number_dual": Number_dual,             # <<<<<<<<<<<<<<
 *     "Number_none": Number_none,
 *     "Number_plur": Number_plur,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_dual); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_dual, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":195
 *     "Number_com": Number_com,
 *     "Number_dual": Number_dual,
 *     "Number_none": Number_none,             # <<<<<<<<<<<<<<
 *     "Number_plur": Number_plur,
 *     "Number_sing": Number_sing,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_none); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_none, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":196
 *     "Number_dual": Number_dual,
 *     "Number_none": Number_none,
 *     "Number_plur": Number_plur,             # <<<<<<<<<<<<<<
 *     "Number_sing": Number_sing,
 *     "Number_ptan": Number_ptan, # bg
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_plur); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_plur, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":197
 *     "Number_none": Number_none,
 *     "Number_plur": Number_plur,
 *     "Number_sing": Number_sing,             # <<<<<<<<<<<<<<
 *     "Number_ptan": Number_ptan, # bg
 *     "Number_count": Number_count, # bg, U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_sing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_sing, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":198
 *     "Number_plur": Number_plur,
 *     "Number_sing": Number_sing,
 *     "Number_ptan": Number_ptan, # bg             # <<<<<<<<<<<<<<
 *     "Number_count": Number_count, # bg, U20
 *     "Number_tri": Number_tri, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_ptan); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_ptan, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":199
 *     "Number_sing": Number_sing,
 *     "Number_ptan": Number_ptan, # bg
 *     "Number_count": Number_count, # bg, U20             # <<<<<<<<<<<<<<
 *     "Number_tri": Number_tri, # U20
 *     "NumType_card": NumType_card,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_count); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_count, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":200
 *     "Number_ptan": Number_ptan, # bg
 *     "Number_count": Number_count, # bg, U20
 *     "Number_tri": Number_tri, # U20             # <<<<<<<<<<<<<<
 *     "NumType_card": NumType_card,
 *     "NumType_dist": NumType_dist,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_tri); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_tri, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":201
 *     "Number_count": Number_count, # bg, U20
 *     "Number_tri": Number_tri, # U20
 *     "NumType_card": NumType_card,             # <<<<<<<<<<<<<<
 *     "NumType_dist": NumType_dist,
 *     "NumType_frac": NumType_frac,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_card); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_card, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":202
 *     "Number_tri": Number_tri, # U20
 *     "NumType_card": NumType_card,
 *     "NumType_dist": NumType_dist,             # <<<<<<<<<<<<<<
 *     "NumType_frac": NumType_frac,
 *     "NumType_gen": NumType_gen,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_dist); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_dist, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":203
 *     "NumType_card": NumType_card,
 *     "NumType_dist": NumType_dist,
 *     "NumType_frac": NumType_frac,             # <<<<<<<<<<<<<<
 *     "NumType_gen": NumType_gen,
 *     "NumType_mult": NumType_mult,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_frac); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_frac, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":204
 *     "NumType_dist": NumType_dist,
 *     "NumType_frac": NumType_frac,
 *     "NumType_gen": NumType_gen,             # <<<<<<<<<<<<<<
 *     "NumType_mult": NumType_mult,
 *     "NumType_none": NumType_none,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_gen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_gen, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":205
 *     "NumType_frac": NumType_frac,
 *     "NumType_gen": NumType_gen,
 *     "NumType_mult": NumType_mult,             # <<<<<<<<<<<<<<
 *     "NumType_none": NumType_none,
 *     "NumType_ord": NumType_ord,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_mult); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_mult, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":206
 *     "NumType_gen": NumType_gen,
 *     "NumType_mult": NumType_mult,
 *     "NumType_none": NumType_none,             # <<<<<<<<<<<<<<
 *     "NumType_ord": NumType_ord,
 *     "NumType_sets": NumType_sets,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_none); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_none, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":207
 *     "NumType_mult": NumType_mult,
 *     "NumType_none": NumType_none,
 *     "NumType_ord": NumType_ord,             # <<<<<<<<<<<<<<
 *     "NumType_sets": NumType_sets,
 *     "Person_one": Person_one,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_ord); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_ord, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":208
 *     "NumType_none": NumType_none,
 *     "NumType_ord": NumType_ord,
 *     "NumType_sets": NumType_sets,             # <<<<<<<<<<<<<<
 *     "Person_one": Person_one,
 *     "Person_two": Person_two,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumType_sets); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumType_sets, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":209
 *     "NumType_ord": NumType_ord,
 *     "NumType_sets": NumType_sets,
 *     "Person_one": Person_one,             # <<<<<<<<<<<<<<
 *     "Person_two": Person_two,
 *     "Person_three": Person_three,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_one); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_one, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":210
 *     "NumType_sets": NumType_sets,
 *     "Person_one": Person_one,
 *     "Person_two": Person_two,             # <<<<<<<<<<<<<<
 *     "Person_three": Person_three,
 *     "Person_none": Person_none,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":211
 *     "Person_one": Person_one,
 *     "Person_two": Person_two,
 *     "Person_three": Person_three,             # <<<<<<<<<<<<<<
 *     "Person_none": Person_none,
 *     "Poss_yes": Poss_yes,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_three); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_three, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":212
 *     "Person_two": Person_two,
 *     "Person_three": Person_three,
 *     "Person_none": Person_none,             # <<<<<<<<<<<<<<
 *     "Poss_yes": Poss_yes,
 *     "PronType_advPart": PronType_advPart,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_none); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_none, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":213
 *     "Person_three": Person_three,
 *     "Person_none": Person_none,
 *     "Poss_yes": Poss_yes,             # <<<<<<<<<<<<<<
 *     "PronType_advPart": PronType_advPart,
 *     "PronType_art": PronType_art,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Poss_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Poss_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":214
 *     "Person_none": Person_none,
 *     "Poss_yes": Poss_yes,
 *     "PronType_advPart": PronType_advPart,             # <<<<<<<<<<<<<<
 *     "PronType_art": PronType_art,
 *     "PronType_default": PronType_default,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_advPart); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_advPart, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":215
 *     "Poss_yes": Poss_yes,
 *     "PronType_advPart": PronType_advPart,
 *     "PronType_art": PronType_art,             # <<<<<<<<<<<<<<
 *     "PronType_default": PronType_default,
 *     "PronType_dem": PronType_dem,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_art); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_art, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":216
 *     "PronType_advPart": PronType_advPart,
 *     "PronType_art": PronType_art,
 *     "PronType_default": PronType_default,             # <<<<<<<<<<<<<<
 *     "PronType_dem": PronType_dem,
 *     "PronType_ind": PronType_ind,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_default); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_default, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":217
 *     "PronType_art": PronType_art,
 *     "PronType_default": PronType_default,
 *     "PronType_dem": PronType_dem,             # <<<<<<<<<<<<<<
 *     "PronType_ind": PronType_ind,
 *     "PronType_int": PronType_int,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_dem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_dem, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":218
 *     "PronType_default": PronType_default,
 *     "PronType_dem": PronType_dem,
 *     "PronType_ind": PronType_ind,             # <<<<<<<<<<<<<<
 *     "PronType_int": PronType_int,
 *     "PronType_neg": PronType_neg,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_ind); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_ind, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":219
 *     "PronType_dem": PronType_dem,
 *     "PronType_ind": PronType_ind,
 *     "PronType_int": PronType_int,             # <<<<<<<<<<<<<<
 *     "PronType_neg": PronType_neg,
 *     "PronType_prs": PronType_prs,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_int); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_int, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":220
 *     "PronType_ind": PronType_ind,
 *     "PronType_int": PronType_int,
 *     "PronType_neg": PronType_neg,             # <<<<<<<<<<<<<<
 *     "PronType_prs": PronType_prs,
 *     "PronType_rcp": PronType_rcp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_neg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_neg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":221
 *     "PronType_int": PronType_int,
 *     "PronType_neg": PronType_neg,
 *     "PronType_prs": PronType_prs,             # <<<<<<<<<<<<<<
 *     "PronType_rcp": PronType_rcp,
 *     "PronType_rel": PronType_rel,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_prs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_prs, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":222
 *     "PronType_neg": PronType_neg,
 *     "PronType_prs": PronType_prs,
 *     "PronType_rcp": PronType_rcp,             # <<<<<<<<<<<<<<
 *     "PronType_rel": PronType_rel,
 *     "PronType_tot": PronType_tot,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_rcp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_rcp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":223
 *     "PronType_prs": PronType_prs,
 *     "PronType_rcp": PronType_rcp,
 *     "PronType_rel": PronType_rel,             # <<<<<<<<<<<<<<
 *     "PronType_tot": PronType_tot,
 *     "PronType_clit": PronType_clit,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_rel); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_rel, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":224
 *     "PronType_rcp": PronType_rcp,
 *     "PronType_rel": PronType_rel,
 *     "PronType_tot": PronType_tot,             # <<<<<<<<<<<<<<
 *     "PronType_clit": PronType_clit,
 *     "PronType_exc": PronType_exc, # es, ca, it, fa, U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_tot); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_tot, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":225
 *     "PronType_rel": PronType_rel,
 *     "PronType_tot": PronType_tot,
 *     "PronType_clit": PronType_clit,             # <<<<<<<<<<<<<<
 *     "PronType_exc": PronType_exc, # es, ca, it, fa, U20
 *     "PronType_emp": PronType_emp, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_clit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_clit, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":226
 *     "PronType_tot": PronType_tot,
 *     "PronType_clit": PronType_clit,
 *     "PronType_exc": PronType_exc, # es, ca, it, fa, U20             # <<<<<<<<<<<<<<
 *     "PronType_emp": PronType_emp, # U20
 *     "Reflex_yes": Reflex_yes,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_exc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_exc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":227
 *     "PronType_clit": PronType_clit,
 *     "PronType_exc": PronType_exc, # es, ca, it, fa, U20
 *     "PronType_emp": PronType_emp, # U20             # <<<<<<<<<<<<<<
 *     "Reflex_yes": Reflex_yes,
 *     "Tense_fut": Tense_fut,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PronType_emp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PronType_emp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":228
 *     "PronType_exc": PronType_exc, # es, ca, it, fa, U20
 *     "PronType_emp": PronType_emp, # U20
 *     "Reflex_yes": Reflex_yes,             # <<<<<<<<<<<<<<
 *     "Tense_fut": Tense_fut,
 *     "Tense_imp": Tense_imp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Reflex_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Reflex_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":229
 *     "PronType_emp": PronType_emp, # U20
 *     "Reflex_yes": Reflex_yes,
 *     "Tense_fut": Tense_fut,             # <<<<<<<<<<<<<<
 *     "Tense_imp": Tense_imp,
 *     "Tense_past": Tense_past,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Tense_fut); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Tense_fut, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":230
 *     "Reflex_yes": Reflex_yes,
 *     "Tense_fut": Tense_fut,
 *     "Tense_imp": Tense_imp,             # <<<<<<<<<<<<<<
 *     "Tense_past": Tense_past,
 *     "Tense_pres": Tense_pres,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Tense_imp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Tense_imp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":231
 *     "Tense_fut": Tense_fut,
 *     "Tense_imp": Tense_imp,
 *     "Tense_past": Tense_past,             # <<<<<<<<<<<<<<
 *     "Tense_pres": Tense_pres,
 *     "VerbForm_fin": VerbForm_fin,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Tense_past); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Tense_past, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":232
 *     "Tense_imp": Tense_imp,
 *     "Tense_past": Tense_past,
 *     "Tense_pres": Tense_pres,             # <<<<<<<<<<<<<<
 *     "VerbForm_fin": VerbForm_fin,
 *     "VerbForm_ger": VerbForm_ger,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Tense_pres); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Tense_pres, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":233
 *     "Tense_past": Tense_past,
 *     "Tense_pres": Tense_pres,
 *     "VerbForm_fin": VerbForm_fin,             # <<<<<<<<<<<<<<
 *     "VerbForm_ger": VerbForm_ger,
 *     "VerbForm_inf": VerbForm_inf,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_fin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_fin, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":234
 *     "Tense_pres": Tense_pres,
 *     "VerbForm_fin": VerbForm_fin,
 *     "VerbForm_ger": VerbForm_ger,             # <<<<<<<<<<<<<<
 *     "VerbForm_inf": VerbForm_inf,
 *     "VerbForm_none": VerbForm_none,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_ger); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_ger, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":235
 *     "VerbForm_fin": VerbForm_fin,
 *     "VerbForm_ger": VerbForm_ger,
 *     "VerbForm_inf": VerbForm_inf,             # <<<<<<<<<<<<<<
 *     "VerbForm_none": VerbForm_none,
 *     "VerbForm_part": VerbForm_part,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_inf, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":236
 *     "VerbForm_ger": VerbForm_ger,
 *     "VerbForm_inf": VerbForm_inf,
 *     "VerbForm_none": VerbForm_none,             # <<<<<<<<<<<<<<
 *     "VerbForm_part": VerbForm_part,
 *     "VerbForm_partFut": VerbForm_partFut,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_none); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_none, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":237
 *     "VerbForm_inf": VerbForm_inf,
 *     "VerbForm_none": VerbForm_none,
 *     "VerbForm_part": VerbForm_part,             # <<<<<<<<<<<<<<
 *     "VerbForm_partFut": VerbForm_partFut,
 *     "VerbForm_partPast": VerbForm_partPast,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_part); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_part, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":238
 *     "VerbForm_none": VerbForm_none,
 *     "VerbForm_part": VerbForm_part,
 *     "VerbForm_partFut": VerbForm_partFut,             # <<<<<<<<<<<<<<
 *     "VerbForm_partPast": VerbForm_partPast,
 *     "VerbForm_partPres": VerbForm_partPres,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_partFut); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_partFut, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":239
 *     "VerbForm_part": VerbForm_part,
 *     "VerbForm_partFut": VerbForm_partFut,
 *     "VerbForm_partPast": VerbForm_partPast,             # <<<<<<<<<<<<<<
 *     "VerbForm_partPres": VerbForm_partPres,
 *     "VerbForm_sup": VerbForm_sup,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_partPast); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_partPast, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":240
 *     "VerbForm_partFut": VerbForm_partFut,
 *     "VerbForm_partPast": VerbForm_partPast,
 *     "VerbForm_partPres": VerbForm_partPres,             # <<<<<<<<<<<<<<
 *     "VerbForm_sup": VerbForm_sup,
 *     "VerbForm_trans": VerbForm_trans,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_partPres); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_partPres, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":241
 *     "VerbForm_partPast": VerbForm_partPast,
 *     "VerbForm_partPres": VerbForm_partPres,
 *     "VerbForm_sup": VerbForm_sup,             # <<<<<<<<<<<<<<
 *     "VerbForm_trans": VerbForm_trans,
 *     "VerbForm_conv": VerbForm_conv, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_sup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_sup, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":242
 *     "VerbForm_partPres": VerbForm_partPres,
 *     "VerbForm_sup": VerbForm_sup,
 *     "VerbForm_trans": VerbForm_trans,             # <<<<<<<<<<<<<<
 *     "VerbForm_conv": VerbForm_conv, # U20
 *     "VerbForm_gdv": VerbForm_gdv, # la,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_trans); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_trans, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":243
 *     "VerbForm_sup": VerbForm_sup,
 *     "VerbForm_trans": VerbForm_trans,
 *     "VerbForm_conv": VerbForm_conv, # U20             # <<<<<<<<<<<<<<
 *     "VerbForm_gdv": VerbForm_gdv, # la,
 *     "VerbForm_vnoun": VerbForm_vnoun, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_conv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_conv, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":244
 *     "VerbForm_trans": VerbForm_trans,
 *     "VerbForm_conv": VerbForm_conv, # U20
 *     "VerbForm_gdv": VerbForm_gdv, # la,             # <<<<<<<<<<<<<<
 *     "VerbForm_vnoun": VerbForm_vnoun, # U20
 *     "Voice_act": Voice_act,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_gdv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_gdv, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":245
 *     "VerbForm_conv": VerbForm_conv, # U20
 *     "VerbForm_gdv": VerbForm_gdv, # la,
 *     "VerbForm_vnoun": VerbForm_vnoun, # U20             # <<<<<<<<<<<<<<
 *     "Voice_act": Voice_act,
 *     "Voice_cau": Voice_cau,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbForm_vnoun); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbForm_vnoun, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":246
 *     "VerbForm_gdv": VerbForm_gdv, # la,
 *     "VerbForm_vnoun": VerbForm_vnoun, # U20
 *     "Voice_act": Voice_act,             # <<<<<<<<<<<<<<
 *     "Voice_cau": Voice_cau,
 *     "Voice_pass": Voice_pass,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_act); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_act, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":247
 *     "VerbForm_vnoun": VerbForm_vnoun, # U20
 *     "Voice_act": Voice_act,
 *     "Voice_cau": Voice_cau,             # <<<<<<<<<<<<<<
 *     "Voice_pass": Voice_pass,
 *     "Voice_mid": Voice_mid, # gkc, U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_cau); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_cau, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":248
 *     "Voice_act": Voice_act,
 *     "Voice_cau": Voice_cau,
 *     "Voice_pass": Voice_pass,             # <<<<<<<<<<<<<<
 *     "Voice_mid": Voice_mid, # gkc, U20
 *     "Voice_int": Voice_int, # hb,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_pass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_pass, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":249
 *     "Voice_cau": Voice_cau,
 *     "Voice_pass": Voice_pass,
 *     "Voice_mid": Voice_mid, # gkc, U20             # <<<<<<<<<<<<<<
 *     "Voice_int": Voice_int, # hb,
 *     "Voice_antip": Voice_antip, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_mid); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_mid, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":250
 *     "Voice_pass": Voice_pass,
 *     "Voice_mid": Voice_mid, # gkc, U20
 *     "Voice_int": Voice_int, # hb,             # <<<<<<<<<<<<<<
 *     "Voice_antip": Voice_antip, # U20
 *     "Voice_dir": Voice_dir, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_int); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_int, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":251
 *     "Voice_mid": Voice_mid, # gkc, U20
 *     "Voice_int": Voice_int, # hb,
 *     "Voice_antip": Voice_antip, # U20             # <<<<<<<<<<<<<<
 *     "Voice_dir": Voice_dir, # U20
 *     "Voice_inv": Voice_inv, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_antip); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_antip, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":252
 *     "Voice_int": Voice_int, # hb,
 *     "Voice_antip": Voice_antip, # U20
 *     "Voice_dir": Voice_dir, # U20             # <<<<<<<<<<<<<<
 *     "Voice_inv": Voice_inv, # U20
 *     "Abbr_yes": Abbr_yes, # cz, fi, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_dir); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_dir, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":253
 *     "Voice_antip": Voice_antip, # U20
 *     "Voice_dir": Voice_dir, # U20
 *     "Voice_inv": Voice_inv, # U20             # <<<<<<<<<<<<<<
 *     "Abbr_yes": Abbr_yes, # cz, fi, sl, U,
 *     "AdpType_prep": AdpType_prep, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Voice_inv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Voice_inv, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":254
 *     "Voice_dir": Voice_dir, # U20
 *     "Voice_inv": Voice_inv, # U20
 *     "Abbr_yes": Abbr_yes, # cz, fi, sl, U,             # <<<<<<<<<<<<<<
 *     "AdpType_prep": AdpType_prep, # cz, U,
 *     "AdpType_post": AdpType_post, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Abbr_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Abbr_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":255
 *     "Voice_inv": Voice_inv, # U20
 *     "Abbr_yes": Abbr_yes, # cz, fi, sl, U,
 *     "AdpType_prep": AdpType_prep, # cz, U,             # <<<<<<<<<<<<<<
 *     "AdpType_post": AdpType_post, # U,
 *     "AdpType_voc": AdpType_voc, # cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdpType_prep); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdpType_prep, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":256
 *     "Abbr_yes": Abbr_yes, # cz, fi, sl, U,
 *     "AdpType_prep": AdpType_prep, # cz, U,
 *     "AdpType_post": AdpType_post, # U,             # <<<<<<<<<<<<<<
 *     "AdpType_voc": AdpType_voc, # cz,
 *     "AdpType_comprep": AdpType_comprep, # cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdpType_post); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdpType_post, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":257
 *     "AdpType_prep": AdpType_prep, # cz, U,
 *     "AdpType_post": AdpType_post, # U,
 *     "AdpType_voc": AdpType_voc, # cz,             # <<<<<<<<<<<<<<
 *     "AdpType_comprep": AdpType_comprep, # cz,
 *     "AdpType_circ": AdpType_circ, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdpType_voc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdpType_voc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":258
 *     "AdpType_post": AdpType_post, # U,
 *     "AdpType_voc": AdpType_voc, # cz,
 *     "AdpType_comprep": AdpType_comprep, # cz,             # <<<<<<<<<<<<<<
 *     "AdpType_circ": AdpType_circ, # U,
 *     "AdvType_man": AdvType_man,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdpType_comprep); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdpType_comprep, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":259
 *     "AdpType_voc": AdpType_voc, # cz,
 *     "AdpType_comprep": AdpType_comprep, # cz,
 *     "AdpType_circ": AdpType_circ, # U,             # <<<<<<<<<<<<<<
 *     "AdvType_man": AdvType_man,
 *     "AdvType_loc": AdvType_loc,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdpType_circ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdpType_circ, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":260
 *     "AdpType_comprep": AdpType_comprep, # cz,
 *     "AdpType_circ": AdpType_circ, # U,
 *     "AdvType_man": AdvType_man,             # <<<<<<<<<<<<<<
 *     "AdvType_loc": AdvType_loc,
 *     "AdvType_tim": AdvType_tim,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_man); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_man, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":261
 *     "AdpType_circ": AdpType_circ, # U,
 *     "AdvType_man": AdvType_man,
 *     "AdvType_loc": AdvType_loc,             # <<<<<<<<<<<<<<
 *     "AdvType_tim": AdvType_tim,
 *     "AdvType_deg": AdvType_deg,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_loc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_loc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":262
 *     "AdvType_man": AdvType_man,
 *     "AdvType_loc": AdvType_loc,
 *     "AdvType_tim": AdvType_tim,             # <<<<<<<<<<<<<<
 *     "AdvType_deg": AdvType_deg,
 *     "AdvType_cau": AdvType_cau,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_tim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_tim, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":263
 *     "AdvType_loc": AdvType_loc,
 *     "AdvType_tim": AdvType_tim,
 *     "AdvType_deg": AdvType_deg,             # <<<<<<<<<<<<<<
 *     "AdvType_cau": AdvType_cau,
 *     "AdvType_mod": AdvType_mod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_deg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_deg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":264
 *     "AdvType_tim": AdvType_tim,
 *     "AdvType_deg": AdvType_deg,
 *     "AdvType_cau": AdvType_cau,             # <<<<<<<<<<<<<<
 *     "AdvType_mod": AdvType_mod,
 *     "AdvType_sta": AdvType_sta,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_cau); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_cau, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":265
 *     "AdvType_deg": AdvType_deg,
 *     "AdvType_cau": AdvType_cau,
 *     "AdvType_mod": AdvType_mod,             # <<<<<<<<<<<<<<
 *     "AdvType_sta": AdvType_sta,
 *     "AdvType_ex": AdvType_ex,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_mod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_mod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":266
 *     "AdvType_cau": AdvType_cau,
 *     "AdvType_mod": AdvType_mod,
 *     "AdvType_sta": AdvType_sta,             # <<<<<<<<<<<<<<
 *     "AdvType_ex": AdvType_ex,
 *     "AdvType_adadj": AdvType_adadj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_sta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_sta, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":267
 *     "AdvType_mod": AdvType_mod,
 *     "AdvType_sta": AdvType_sta,
 *     "AdvType_ex": AdvType_ex,             # <<<<<<<<<<<<<<
 *     "AdvType_adadj": AdvType_adadj,
 *     "ConjType_oper": ConjType_oper, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_ex); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_ex, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":268
 *     "AdvType_sta": AdvType_sta,
 *     "AdvType_ex": AdvType_ex,
 *     "AdvType_adadj": AdvType_adadj,             # <<<<<<<<<<<<<<
 *     "ConjType_oper": ConjType_oper, # cz, U,
 *     "ConjType_comp": ConjType_comp, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_AdvType_adadj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_AdvType_adadj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":269
 *     "AdvType_ex": AdvType_ex,
 *     "AdvType_adadj": AdvType_adadj,
 *     "ConjType_oper": ConjType_oper, # cz, U,             # <<<<<<<<<<<<<<
 *     "ConjType_comp": ConjType_comp, # cz, U,
 *     "Connegative_yes": Connegative_yes, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ConjType_oper); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ConjType_oper, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":270
 *     "AdvType_adadj": AdvType_adadj,
 *     "ConjType_oper": ConjType_oper, # cz, U,
 *     "ConjType_comp": ConjType_comp, # cz, U,             # <<<<<<<<<<<<<<
 *     "Connegative_yes": Connegative_yes, # fi,
 *     "Derivation_minen": Derivation_minen, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ConjType_comp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ConjType_comp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":271
 *     "ConjType_oper": ConjType_oper, # cz, U,
 *     "ConjType_comp": ConjType_comp, # cz, U,
 *     "Connegative_yes": Connegative_yes, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_minen": Derivation_minen, # fi,
 *     "Derivation_sti": Derivation_sti, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Connegative_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Connegative_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":272
 *     "ConjType_comp": ConjType_comp, # cz, U,
 *     "Connegative_yes": Connegative_yes, # fi,
 *     "Derivation_minen": Derivation_minen, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_sti": Derivation_sti, # fi,
 *     "Derivation_inen": Derivation_inen, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_minen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_minen, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":273
 *     "Connegative_yes": Connegative_yes, # fi,
 *     "Derivation_minen": Derivation_minen, # fi,
 *     "Derivation_sti": Derivation_sti, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_inen": Derivation_inen, # fi,
 *     "Derivation_lainen": Derivation_lainen, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_sti); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_sti, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":274
 *     "Derivation_minen": Derivation_minen, # fi,
 *     "Derivation_sti": Derivation_sti, # fi,
 *     "Derivation_inen": Derivation_inen, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_lainen": Derivation_lainen, # fi,
 *     "Derivation_ja": Derivation_ja, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_inen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_inen, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":275
 *     "Derivation_sti": Derivation_sti, # fi,
 *     "Derivation_inen": Derivation_inen, # fi,
 *     "Derivation_lainen": Derivation_lainen, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_ja": Derivation_ja, # fi,
 *     "Derivation_ton": Derivation_ton, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_lainen); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_lainen, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":276
 *     "Derivation_inen": Derivation_inen, # fi,
 *     "Derivation_lainen": Derivation_lainen, # fi,
 *     "Derivation_ja": Derivation_ja, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_ton": Derivation_ton, # fi,
 *     "Derivation_vs": Derivation_vs, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_ja); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_ja, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":277
 *     "Derivation_lainen": Derivation_lainen, # fi,
 *     "Derivation_ja": Derivation_ja, # fi,
 *     "Derivation_ton": Derivation_ton, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_vs": Derivation_vs, # fi,
 *     "Derivation_ttain": Derivation_ttain, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_ton); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_ton, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":278
 *     "Derivation_ja": Derivation_ja, # fi,
 *     "Derivation_ton": Derivation_ton, # fi,
 *     "Derivation_vs": Derivation_vs, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_ttain": Derivation_ttain, # fi,
 *     "Derivation_ttaa": Derivation_ttaa, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_vs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_vs, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":279
 *     "Derivation_ton": Derivation_ton, # fi,
 *     "Derivation_vs": Derivation_vs, # fi,
 *     "Derivation_ttain": Derivation_ttain, # fi,             # <<<<<<<<<<<<<<
 *     "Derivation_ttaa": Derivation_ttaa, # fi,
 *     "Echo_rdp": Echo_rdp, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_ttain); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_ttain, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":280
 *     "Derivation_vs": Derivation_vs, # fi,
 *     "Derivation_ttain": Derivation_ttain, # fi,
 *     "Derivation_ttaa": Derivation_ttaa, # fi,             # <<<<<<<<<<<<<<
 *     "Echo_rdp": Echo_rdp, # U,
 *     "Echo_ech": Echo_ech, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Derivation_ttaa); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Derivation_ttaa, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":281
 *     "Derivation_ttain": Derivation_ttain, # fi,
 *     "Derivation_ttaa": Derivation_ttaa, # fi,
 *     "Echo_rdp": Echo_rdp, # U,             # <<<<<<<<<<<<<<
 *     "Echo_ech": Echo_ech, # U,
 *     "Foreign_foreign": Foreign_foreign, # cz, fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Echo_rdp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Echo_rdp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":282
 *     "Derivation_ttaa": Derivation_ttaa, # fi,
 *     "Echo_rdp": Echo_rdp, # U,
 *     "Echo_ech": Echo_ech, # U,             # <<<<<<<<<<<<<<
 *     "Foreign_foreign": Foreign_foreign, # cz, fi, U,
 *     "Foreign_fscript": Foreign_fscript, # cz, fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Echo_ech); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Echo_ech, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":283
 *     "Echo_rdp": Echo_rdp, # U,
 *     "Echo_ech": Echo_ech, # U,
 *     "Foreign_foreign": Foreign_foreign, # cz, fi, U,             # <<<<<<<<<<<<<<
 *     "Foreign_fscript": Foreign_fscript, # cz, fi, U,
 *     "Foreign_tscript": Foreign_tscript, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Foreign_foreign); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Foreign_foreign, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":284
 *     "Echo_ech": Echo_ech, # U,
 *     "Foreign_foreign": Foreign_foreign, # cz, fi, U,
 *     "Foreign_fscript": Foreign_fscript, # cz, fi, U,             # <<<<<<<<<<<<<<
 *     "Foreign_tscript": Foreign_tscript, # cz, U,
 *     "Foreign_yes": Foreign_yes, # sl,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Foreign_fscript); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Foreign_fscript, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":285
 *     "Foreign_foreign": Foreign_foreign, # cz, fi, U,
 *     "Foreign_fscript": Foreign_fscript, # cz, fi, U,
 *     "Foreign_tscript": Foreign_tscript, # cz, U,             # <<<<<<<<<<<<<<
 *     "Foreign_yes": Foreign_yes, # sl,
 *     "Gender_dat_masc": Gender_dat_masc, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Foreign_tscript); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Foreign_tscript, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":286
 *     "Foreign_fscript": Foreign_fscript, # cz, fi, U,
 *     "Foreign_tscript": Foreign_tscript, # cz, U,
 *     "Foreign_yes": Foreign_yes, # sl,             # <<<<<<<<<<<<<<
 *     "Gender_dat_masc": Gender_dat_masc, # bq, U,
 *     "Gender_dat_fem": Gender_dat_fem, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Foreign_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Foreign_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":287
 *     "Foreign_tscript": Foreign_tscript, # cz, U,
 *     "Foreign_yes": Foreign_yes, # sl,
 *     "Gender_dat_masc": Gender_dat_masc, # bq, U,             # <<<<<<<<<<<<<<
 *     "Gender_dat_fem": Gender_dat_fem, # bq, U,
 *     "Gender_erg_masc": Gender_erg_masc, # bq,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_dat_masc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_dat_masc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":288
 *     "Foreign_yes": Foreign_yes, # sl,
 *     "Gender_dat_masc": Gender_dat_masc, # bq, U,
 *     "Gender_dat_fem": Gender_dat_fem, # bq, U,             # <<<<<<<<<<<<<<
 *     "Gender_erg_masc": Gender_erg_masc, # bq,
 *     "Gender_erg_fem": Gender_erg_fem, # bq,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_dat_fem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_dat_fem, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":289
 *     "Gender_dat_masc": Gender_dat_masc, # bq, U,
 *     "Gender_dat_fem": Gender_dat_fem, # bq, U,
 *     "Gender_erg_masc": Gender_erg_masc, # bq,             # <<<<<<<<<<<<<<
 *     "Gender_erg_fem": Gender_erg_fem, # bq,
 *     "Gender_psor_masc": Gender_psor_masc, # cz, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_erg_masc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_erg_masc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":290
 *     "Gender_dat_fem": Gender_dat_fem, # bq, U,
 *     "Gender_erg_masc": Gender_erg_masc, # bq,
 *     "Gender_erg_fem": Gender_erg_fem, # bq,             # <<<<<<<<<<<<<<
 *     "Gender_psor_masc": Gender_psor_masc, # cz, sl, U,
 *     "Gender_psor_fem": Gender_psor_fem, # cz, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_erg_fem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_erg_fem, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":291
 *     "Gender_erg_masc": Gender_erg_masc, # bq,
 *     "Gender_erg_fem": Gender_erg_fem, # bq,
 *     "Gender_psor_masc": Gender_psor_masc, # cz, sl, U,             # <<<<<<<<<<<<<<
 *     "Gender_psor_fem": Gender_psor_fem, # cz, sl, U,
 *     "Gender_psor_neut": Gender_psor_neut, # sl,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_psor_masc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_psor_masc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":292
 *     "Gender_erg_fem": Gender_erg_fem, # bq,
 *     "Gender_psor_masc": Gender_psor_masc, # cz, sl, U,
 *     "Gender_psor_fem": Gender_psor_fem, # cz, sl, U,             # <<<<<<<<<<<<<<
 *     "Gender_psor_neut": Gender_psor_neut, # sl,
 *     "Hyph_yes": Hyph_yes, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_psor_fem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_psor_fem, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":293
 *     "Gender_psor_masc": Gender_psor_masc, # cz, sl, U,
 *     "Gender_psor_fem": Gender_psor_fem, # cz, sl, U,
 *     "Gender_psor_neut": Gender_psor_neut, # sl,             # <<<<<<<<<<<<<<
 *     "Hyph_yes": Hyph_yes, # cz, U,
 *     "InfForm_one": InfForm_one, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Gender_psor_neut); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Gender_psor_neut, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":294
 *     "Gender_psor_fem": Gender_psor_fem, # cz, sl, U,
 *     "Gender_psor_neut": Gender_psor_neut, # sl,
 *     "Hyph_yes": Hyph_yes, # cz, U,             # <<<<<<<<<<<<<<
 *     "InfForm_one": InfForm_one, # fi,
 *     "InfForm_two": InfForm_two, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Hyph_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Hyph_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":295
 *     "Gender_psor_neut": Gender_psor_neut, # sl,
 *     "Hyph_yes": Hyph_yes, # cz, U,
 *     "InfForm_one": InfForm_one, # fi,             # <<<<<<<<<<<<<<
 *     "InfForm_two": InfForm_two, # fi,
 *     "InfForm_three": InfForm_three, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_InfForm_one); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_InfForm_one, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":296
 *     "Hyph_yes": Hyph_yes, # cz, U,
 *     "InfForm_one": InfForm_one, # fi,
 *     "InfForm_two": InfForm_two, # fi,             # <<<<<<<<<<<<<<
 *     "InfForm_three": InfForm_three, # fi,
 *     "NameType_geo": NameType_geo, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_InfForm_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_InfForm_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":297
 *     "InfForm_one": InfForm_one, # fi,
 *     "InfForm_two": InfForm_two, # fi,
 *     "InfForm_three": InfForm_three, # fi,             # <<<<<<<<<<<<<<
 *     "NameType_geo": NameType_geo, # U, cz,
 *     "NameType_prs": NameType_prs, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_InfForm_three); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_InfForm_three, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":298
 *     "InfForm_two": InfForm_two, # fi,
 *     "InfForm_three": InfForm_three, # fi,
 *     "NameType_geo": NameType_geo, # U, cz,             # <<<<<<<<<<<<<<
 *     "NameType_prs": NameType_prs, # U, cz,
 *     "NameType_giv": NameType_giv, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_geo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_geo, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":299
 *     "InfForm_three": InfForm_three, # fi,
 *     "NameType_geo": NameType_geo, # U, cz,
 *     "NameType_prs": NameType_prs, # U, cz,             # <<<<<<<<<<<<<<
 *     "NameType_giv": NameType_giv, # U, cz,
 *     "NameType_sur": NameType_sur, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_prs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_prs, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":300
 *     "NameType_geo": NameType_geo, # U, cz,
 *     "NameType_prs": NameType_prs, # U, cz,
 *     "NameType_giv": NameType_giv, # U, cz,             # <<<<<<<<<<<<<<
 *     "NameType_sur": NameType_sur, # U, cz,
 *     "NameType_nat": NameType_nat, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_giv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_giv, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":301
 *     "NameType_prs": NameType_prs, # U, cz,
 *     "NameType_giv": NameType_giv, # U, cz,
 *     "NameType_sur": NameType_sur, # U, cz,             # <<<<<<<<<<<<<<
 *     "NameType_nat": NameType_nat, # U, cz,
 *     "NameType_com": NameType_com, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_sur); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_sur, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":302
 *     "NameType_giv": NameType_giv, # U, cz,
 *     "NameType_sur": NameType_sur, # U, cz,
 *     "NameType_nat": NameType_nat, # U, cz,             # <<<<<<<<<<<<<<
 *     "NameType_com": NameType_com, # U, cz,
 *     "NameType_pro": NameType_pro, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_nat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_nat, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":303
 *     "NameType_sur": NameType_sur, # U, cz,
 *     "NameType_nat": NameType_nat, # U, cz,
 *     "NameType_com": NameType_com, # U, cz,             # <<<<<<<<<<<<<<
 *     "NameType_pro": NameType_pro, # U, cz,
 *     "NameType_oth": NameType_oth, # U, cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_com); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_com, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":304
 *     "NameType_nat": NameType_nat, # U, cz,
 *     "NameType_com": NameType_com, # U, cz,
 *     "NameType_pro": NameType_pro, # U, cz,             # <<<<<<<<<<<<<<
 *     "NameType_oth": NameType_oth, # U, cz,
 *     "NounType_com": NounType_com, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_pro); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_pro, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":305
 *     "NameType_com": NameType_com, # U, cz,
 *     "NameType_pro": NameType_pro, # U, cz,
 *     "NameType_oth": NameType_oth, # U, cz,             # <<<<<<<<<<<<<<
 *     "NounType_com": NounType_com, # U,
 *     "NounType_prop": NounType_prop, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NameType_oth); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NameType_oth, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":306
 *     "NameType_pro": NameType_pro, # U, cz,
 *     "NameType_oth": NameType_oth, # U, cz,
 *     "NounType_com": NounType_com, # U,             # <<<<<<<<<<<<<<
 *     "NounType_prop": NounType_prop, # U,
 *     "NounType_class": NounType_class, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NounType_com); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NounType_com, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":307
 *     "NameType_oth": NameType_oth, # U, cz,
 *     "NounType_com": NounType_com, # U,
 *     "NounType_prop": NounType_prop, # U,             # <<<<<<<<<<<<<<
 *     "NounType_class": NounType_class, # U,
 *     "Number_abs_sing": Number_abs_sing, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NounType_prop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NounType_prop, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":308
 *     "NounType_com": NounType_com, # U,
 *     "NounType_prop": NounType_prop, # U,
 *     "NounType_class": NounType_class, # U,             # <<<<<<<<<<<<<<
 *     "Number_abs_sing": Number_abs_sing, # bq, U,
 *     "Number_abs_plur": Number_abs_plur, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NounType_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NounType_class, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":309
 *     "NounType_prop": NounType_prop, # U,
 *     "NounType_class": NounType_class, # U,
 *     "Number_abs_sing": Number_abs_sing, # bq, U,             # <<<<<<<<<<<<<<
 *     "Number_abs_plur": Number_abs_plur, # bq, U,
 *     "Number_dat_sing": Number_dat_sing, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_abs_sing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_abs_sing, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":310
 *     "NounType_class": NounType_class, # U,
 *     "Number_abs_sing": Number_abs_sing, # bq, U,
 *     "Number_abs_plur": Number_abs_plur, # bq, U,             # <<<<<<<<<<<<<<
 *     "Number_dat_sing": Number_dat_sing, # bq, U,
 *     "Number_dat_plur": Number_dat_plur, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_abs_plur); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_abs_plur, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":311
 *     "Number_abs_sing": Number_abs_sing, # bq, U,
 *     "Number_abs_plur": Number_abs_plur, # bq, U,
 *     "Number_dat_sing": Number_dat_sing, # bq, U,             # <<<<<<<<<<<<<<
 *     "Number_dat_plur": Number_dat_plur, # bq, U,
 *     "Number_erg_sing": Number_erg_sing, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_dat_sing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_dat_sing, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":312
 *     "Number_abs_plur": Number_abs_plur, # bq, U,
 *     "Number_dat_sing": Number_dat_sing, # bq, U,
 *     "Number_dat_plur": Number_dat_plur, # bq, U,             # <<<<<<<<<<<<<<
 *     "Number_erg_sing": Number_erg_sing, # bq, U,
 *     "Number_erg_plur": Number_erg_plur, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_dat_plur); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_dat_plur, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":313
 *     "Number_dat_sing": Number_dat_sing, # bq, U,
 *     "Number_dat_plur": Number_dat_plur, # bq, U,
 *     "Number_erg_sing": Number_erg_sing, # bq, U,             # <<<<<<<<<<<<<<
 *     "Number_erg_plur": Number_erg_plur, # bq, U,
 *     "Number_psee_sing": Number_psee_sing, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_erg_sing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_erg_sing, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":314
 *     "Number_dat_plur": Number_dat_plur, # bq, U,
 *     "Number_erg_sing": Number_erg_sing, # bq, U,
 *     "Number_erg_plur": Number_erg_plur, # bq, U,             # <<<<<<<<<<<<<<
 *     "Number_psee_sing": Number_psee_sing, # U,
 *     "Number_psee_plur": Number_psee_plur, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_erg_plur); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_erg_plur, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":315
 *     "Number_erg_sing": Number_erg_sing, # bq, U,
 *     "Number_erg_plur": Number_erg_plur, # bq, U,
 *     "Number_psee_sing": Number_psee_sing, # U,             # <<<<<<<<<<<<<<
 *     "Number_psee_plur": Number_psee_plur, # U,
 *     "Number_psor_sing": Number_psor_sing, # cz, fi, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_psee_sing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_psee_sing, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":316
 *     "Number_erg_plur": Number_erg_plur, # bq, U,
 *     "Number_psee_sing": Number_psee_sing, # U,
 *     "Number_psee_plur": Number_psee_plur, # U,             # <<<<<<<<<<<<<<
 *     "Number_psor_sing": Number_psor_sing, # cz, fi, sl, U,
 *     "Number_psor_plur": Number_psor_plur, # cz, fi, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_psee_plur); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_psee_plur, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":317
 *     "Number_psee_sing": Number_psee_sing, # U,
 *     "Number_psee_plur": Number_psee_plur, # U,
 *     "Number_psor_sing": Number_psor_sing, # cz, fi, sl, U,             # <<<<<<<<<<<<<<
 *     "Number_psor_plur": Number_psor_plur, # cz, fi, sl, U,
 *     "Number_pauc": Number_pauc, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_psor_sing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_psor_sing, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":318
 *     "Number_psee_plur": Number_psee_plur, # U,
 *     "Number_psor_sing": Number_psor_sing, # cz, fi, sl, U,
 *     "Number_psor_plur": Number_psor_plur, # cz, fi, sl, U,             # <<<<<<<<<<<<<<
 *     "Number_pauc": Number_pauc, # U20
 *     "Number_grpa": Number_grpa, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_psor_plur); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_psor_plur, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":319
 *     "Number_psor_sing": Number_psor_sing, # cz, fi, sl, U,
 *     "Number_psor_plur": Number_psor_plur, # cz, fi, sl, U,
 *     "Number_pauc": Number_pauc, # U20             # <<<<<<<<<<<<<<
 *     "Number_grpa": Number_grpa, # U20
 *     "Number_grpl": Number_grpl, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_pauc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_pauc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":320
 *     "Number_psor_plur": Number_psor_plur, # cz, fi, sl, U,
 *     "Number_pauc": Number_pauc, # U20
 *     "Number_grpa": Number_grpa, # U20             # <<<<<<<<<<<<<<
 *     "Number_grpl": Number_grpl, # U20
 *     "Number_inv": Number_inv, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_grpa); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_grpa, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":321
 *     "Number_pauc": Number_pauc, # U20
 *     "Number_grpa": Number_grpa, # U20
 *     "Number_grpl": Number_grpl, # U20             # <<<<<<<<<<<<<<
 *     "Number_inv": Number_inv, # U20
 *     "NumForm_digit": NumForm_digit, # cz, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_grpl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_grpl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":322
 *     "Number_grpa": Number_grpa, # U20
 *     "Number_grpl": Number_grpl, # U20
 *     "Number_inv": Number_inv, # U20             # <<<<<<<<<<<<<<
 *     "NumForm_digit": NumForm_digit, # cz, sl, U,
 *     "NumForm_roman": NumForm_roman, # cz, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Number_inv); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Number_inv, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":323
 *     "Number_grpl": Number_grpl, # U20
 *     "Number_inv": Number_inv, # U20
 *     "NumForm_digit": NumForm_digit, # cz, sl, U,             # <<<<<<<<<<<<<<
 *     "NumForm_roman": NumForm_roman, # cz, sl, U,
 *     "NumForm_word": NumForm_word, # cz, sl, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumForm_digit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumForm_digit, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":324
 *     "Number_inv": Number_inv, # U20
 *     "NumForm_digit": NumForm_digit, # cz, sl, U,
 *     "NumForm_roman": NumForm_roman, # cz, sl, U,             # <<<<<<<<<<<<<<
 *     "NumForm_word": NumForm_word, # cz, sl, U,
 *     "NumValue_one": NumValue_one, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumForm_roman); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumForm_roman, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":325
 *     "NumForm_digit": NumForm_digit, # cz, sl, U,
 *     "NumForm_roman": NumForm_roman, # cz, sl, U,
 *     "NumForm_word": NumForm_word, # cz, sl, U,             # <<<<<<<<<<<<<<
 *     "NumValue_one": NumValue_one, # cz, U,
 *     "NumValue_two": NumValue_two, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumForm_word); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumForm_word, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":326
 *     "NumForm_roman": NumForm_roman, # cz, sl, U,
 *     "NumForm_word": NumForm_word, # cz, sl, U,
 *     "NumValue_one": NumValue_one, # cz, U,             # <<<<<<<<<<<<<<
 *     "NumValue_two": NumValue_two, # cz, U,
 *     "NumValue_three": NumValue_three, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumValue_one); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumValue_one, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":327
 *     "NumForm_word": NumForm_word, # cz, sl, U,
 *     "NumValue_one": NumValue_one, # cz, U,
 *     "NumValue_two": NumValue_two, # cz, U,             # <<<<<<<<<<<<<<
 *     "NumValue_three": NumValue_three, # cz, U,
 *     "PartForm_pres": PartForm_pres, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumValue_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumValue_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":328
 *     "NumValue_one": NumValue_one, # cz, U,
 *     "NumValue_two": NumValue_two, # cz, U,
 *     "NumValue_three": NumValue_three, # cz, U,             # <<<<<<<<<<<<<<
 *     "PartForm_pres": PartForm_pres, # fi,
 *     "PartForm_past": PartForm_past, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NumValue_three); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NumValue_three, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":329
 *     "NumValue_two": NumValue_two, # cz, U,
 *     "NumValue_three": NumValue_three, # cz, U,
 *     "PartForm_pres": PartForm_pres, # fi,             # <<<<<<<<<<<<<<
 *     "PartForm_past": PartForm_past, # fi,
 *     "PartForm_agt": PartForm_agt, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartForm_pres); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartForm_pres, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":330
 *     "NumValue_three": NumValue_three, # cz, U,
 *     "PartForm_pres": PartForm_pres, # fi,
 *     "PartForm_past": PartForm_past, # fi,             # <<<<<<<<<<<<<<
 *     "PartForm_agt": PartForm_agt, # fi,
 *     "PartForm_neg": PartForm_neg, # fi,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartForm_past); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartForm_past, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":331
 *     "PartForm_pres": PartForm_pres, # fi,
 *     "PartForm_past": PartForm_past, # fi,
 *     "PartForm_agt": PartForm_agt, # fi,             # <<<<<<<<<<<<<<
 *     "PartForm_neg": PartForm_neg, # fi,
 *     "PartType_mod": PartType_mod, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartForm_agt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartForm_agt, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":332
 *     "PartForm_past": PartForm_past, # fi,
 *     "PartForm_agt": PartForm_agt, # fi,
 *     "PartForm_neg": PartForm_neg, # fi,             # <<<<<<<<<<<<<<
 *     "PartType_mod": PartType_mod, # U,
 *     "PartType_emp": PartType_emp, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartForm_neg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartForm_neg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":333
 *     "PartForm_agt": PartForm_agt, # fi,
 *     "PartForm_neg": PartForm_neg, # fi,
 *     "PartType_mod": PartType_mod, # U,             # <<<<<<<<<<<<<<
 *     "PartType_emp": PartType_emp, # U,
 *     "PartType_res": PartType_res, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartType_mod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartType_mod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":334
 *     "PartForm_neg": PartForm_neg, # fi,
 *     "PartType_mod": PartType_mod, # U,
 *     "PartType_emp": PartType_emp, # U,             # <<<<<<<<<<<<<<
 *     "PartType_res": PartType_res, # U,
 *     "PartType_inf": PartType_inf, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartType_emp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartType_emp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":335
 *     "PartType_mod": PartType_mod, # U,
 *     "PartType_emp": PartType_emp, # U,
 *     "PartType_res": PartType_res, # U,             # <<<<<<<<<<<<<<
 *     "PartType_inf": PartType_inf, # U,
 *     "PartType_vbp": PartType_vbp, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartType_res); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartType_res, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":336
 *     "PartType_emp": PartType_emp, # U,
 *     "PartType_res": PartType_res, # U,
 *     "PartType_inf": PartType_inf, # U,             # <<<<<<<<<<<<<<
 *     "PartType_vbp": PartType_vbp, # U,
 *     "Person_abs_one": Person_abs_one, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartType_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartType_inf, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":337
 *     "PartType_res": PartType_res, # U,
 *     "PartType_inf": PartType_inf, # U,
 *     "PartType_vbp": PartType_vbp, # U,             # <<<<<<<<<<<<<<
 *     "Person_abs_one": Person_abs_one, # bq, U,
 *     "Person_abs_two": Person_abs_two, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PartType_vbp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PartType_vbp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":338
 *     "PartType_inf": PartType_inf, # U,
 *     "PartType_vbp": PartType_vbp, # U,
 *     "Person_abs_one": Person_abs_one, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_abs_two": Person_abs_two, # bq, U,
 *     "Person_abs_three": Person_abs_three, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_abs_one); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_abs_one, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":339
 *     "PartType_vbp": PartType_vbp, # U,
 *     "Person_abs_one": Person_abs_one, # bq, U,
 *     "Person_abs_two": Person_abs_two, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_abs_three": Person_abs_three, # bq, U,
 *     "Person_dat_one": Person_dat_one, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_abs_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_abs_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":340
 *     "Person_abs_one": Person_abs_one, # bq, U,
 *     "Person_abs_two": Person_abs_two, # bq, U,
 *     "Person_abs_three": Person_abs_three, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_dat_one": Person_dat_one, # bq, U,
 *     "Person_dat_two": Person_dat_two, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_abs_three); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_abs_three, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":341
 *     "Person_abs_two": Person_abs_two, # bq, U,
 *     "Person_abs_three": Person_abs_three, # bq, U,
 *     "Person_dat_one": Person_dat_one, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_dat_two": Person_dat_two, # bq, U,
 *     "Person_dat_three": Person_dat_three, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_dat_one); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_dat_one, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":342
 *     "Person_abs_three": Person_abs_three, # bq, U,
 *     "Person_dat_one": Person_dat_one, # bq, U,
 *     "Person_dat_two": Person_dat_two, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_dat_three": Person_dat_three, # bq, U,
 *     "Person_erg_one": Person_erg_one, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_dat_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_dat_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":343
 *     "Person_dat_one": Person_dat_one, # bq, U,
 *     "Person_dat_two": Person_dat_two, # bq, U,
 *     "Person_dat_three": Person_dat_three, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_erg_one": Person_erg_one, # bq, U,
 *     "Person_erg_two": Person_erg_two, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_dat_three); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_dat_three, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":344
 *     "Person_dat_two": Person_dat_two, # bq, U,
 *     "Person_dat_three": Person_dat_three, # bq, U,
 *     "Person_erg_one": Person_erg_one, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_erg_two": Person_erg_two, # bq, U,
 *     "Person_erg_three": Person_erg_three, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_erg_one); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_erg_one, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":345
 *     "Person_dat_three": Person_dat_three, # bq, U,
 *     "Person_erg_one": Person_erg_one, # bq, U,
 *     "Person_erg_two": Person_erg_two, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_erg_three": Person_erg_three, # bq, U,
 *     "Person_psor_one": Person_psor_one, # fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_erg_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_erg_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":346
 *     "Person_erg_one": Person_erg_one, # bq, U,
 *     "Person_erg_two": Person_erg_two, # bq, U,
 *     "Person_erg_three": Person_erg_three, # bq, U,             # <<<<<<<<<<<<<<
 *     "Person_psor_one": Person_psor_one, # fi, U,
 *     "Person_psor_two": Person_psor_two, # fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_erg_three); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_erg_three, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":347
 *     "Person_erg_two": Person_erg_two, # bq, U,
 *     "Person_erg_three": Person_erg_three, # bq, U,
 *     "Person_psor_one": Person_psor_one, # fi, U,             # <<<<<<<<<<<<<<
 *     "Person_psor_two": Person_psor_two, # fi, U,
 *     "Person_psor_three": Person_psor_three, # fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_psor_one); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_psor_one, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":348
 *     "Person_erg_three": Person_erg_three, # bq, U,
 *     "Person_psor_one": Person_psor_one, # fi, U,
 *     "Person_psor_two": Person_psor_two, # fi, U,             # <<<<<<<<<<<<<<
 *     "Person_psor_three": Person_psor_three, # fi, U,
 *     "Person_zero": Person_zero, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_psor_two); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_psor_two, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":349
 *     "Person_psor_one": Person_psor_one, # fi, U,
 *     "Person_psor_two": Person_psor_two, # fi, U,
 *     "Person_psor_three": Person_psor_three, # fi, U,             # <<<<<<<<<<<<<<
 *     "Person_zero": Person_zero, # U20
 *     "Person_four": Person_four, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_psor_three); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_psor_three, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":350
 *     "Person_psor_two": Person_psor_two, # fi, U,
 *     "Person_psor_three": Person_psor_three, # fi, U,
 *     "Person_zero": Person_zero, # U20             # <<<<<<<<<<<<<<
 *     "Person_four": Person_four, # U20
 *     "Polite_inf": Polite_inf, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_zero); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_zero, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":351
 *     "Person_psor_three": Person_psor_three, # fi, U,
 *     "Person_zero": Person_zero, # U20
 *     "Person_four": Person_four, # U20             # <<<<<<<<<<<<<<
 *     "Polite_inf": Polite_inf, # bq, U,
 *     "Polite_pol": Polite_pol, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Person_four); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Person_four, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":352
 *     "Person_zero": Person_zero, # U20
 *     "Person_four": Person_four, # U20
 *     "Polite_inf": Polite_inf, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_pol": Polite_pol, # bq, U,
 *     "Polite_abs_inf": Polite_abs_inf, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_inf, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":353
 *     "Person_four": Person_four, # U20
 *     "Polite_inf": Polite_inf, # bq, U,
 *     "Polite_pol": Polite_pol, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_abs_inf": Polite_abs_inf, # bq, U,
 *     "Polite_abs_pol": Polite_abs_pol, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_pol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_pol, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":354
 *     "Polite_inf": Polite_inf, # bq, U,
 *     "Polite_pol": Polite_pol, # bq, U,
 *     "Polite_abs_inf": Polite_abs_inf, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_abs_pol": Polite_abs_pol, # bq, U,
 *     "Polite_erg_inf": Polite_erg_inf, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_abs_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_abs_inf, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":355
 *     "Polite_pol": Polite_pol, # bq, U,
 *     "Polite_abs_inf": Polite_abs_inf, # bq, U,
 *     "Polite_abs_pol": Polite_abs_pol, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_erg_inf": Polite_erg_inf, # bq, U,
 *     "Polite_erg_pol": Polite_erg_pol, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_abs_pol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_abs_pol, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":356
 *     "Polite_abs_inf": Polite_abs_inf, # bq, U,
 *     "Polite_abs_pol": Polite_abs_pol, # bq, U,
 *     "Polite_erg_inf": Polite_erg_inf, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_erg_pol": Polite_erg_pol, # bq, U,
 *     "Polite_dat_inf": Polite_dat_inf, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_erg_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_erg_inf, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":357
 *     "Polite_abs_pol": Polite_abs_pol, # bq, U,
 *     "Polite_erg_inf": Polite_erg_inf, # bq, U,
 *     "Polite_erg_pol": Polite_erg_pol, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_dat_inf": Polite_dat_inf, # bq, U,
 *     "Polite_dat_pol": Polite_dat_pol, # bq, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_erg_pol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_erg_pol, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":358
 *     "Polite_erg_inf": Polite_erg_inf, # bq, U,
 *     "Polite_erg_pol": Polite_erg_pol, # bq, U,
 *     "Polite_dat_inf": Polite_dat_inf, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_dat_pol": Polite_dat_pol, # bq, U,
 *     "Polite_infm": Polite_infm, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_dat_inf); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_dat_inf, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":359
 *     "Polite_erg_pol": Polite_erg_pol, # bq, U,
 *     "Polite_dat_inf": Polite_dat_inf, # bq, U,
 *     "Polite_dat_pol": Polite_dat_pol, # bq, U,             # <<<<<<<<<<<<<<
 *     "Polite_infm": Polite_infm, # U20
 *     "Polite_form": Polite_form, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_dat_pol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_dat_pol, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":360
 *     "Polite_dat_inf": Polite_dat_inf, # bq, U,
 *     "Polite_dat_pol": Polite_dat_pol, # bq, U,
 *     "Polite_infm": Polite_infm, # U20             # <<<<<<<<<<<<<<
 *     "Polite_form": Polite_form, # U20
 *     "Polite_form_elev": Polite_form_elev, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_infm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_infm, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":361
 *     "Polite_dat_pol": Polite_dat_pol, # bq, U,
 *     "Polite_infm": Polite_infm, # U20
 *     "Polite_form": Polite_form, # U20             # <<<<<<<<<<<<<<
 *     "Polite_form_elev": Polite_form_elev, # U20
 *     "Polite_form_humb": Polite_form_humb, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_form); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_form, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":362
 *     "Polite_infm": Polite_infm, # U20
 *     "Polite_form": Polite_form, # U20
 *     "Polite_form_elev": Polite_form_elev, # U20             # <<<<<<<<<<<<<<
 *     "Polite_form_humb": Polite_form_humb, # U20
 *     "Prefix_yes": Prefix_yes, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_form_elev); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_form_elev, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":363
 *     "Polite_form": Polite_form, # U20
 *     "Polite_form_elev": Polite_form_elev, # U20
 *     "Polite_form_humb": Polite_form_humb, # U20             # <<<<<<<<<<<<<<
 *     "Prefix_yes": Prefix_yes, # U,
 *     "PrepCase_npr": PrepCase_npr, # cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Polite_form_humb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Polite_form_humb, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":364
 *     "Polite_form_elev": Polite_form_elev, # U20
 *     "Polite_form_humb": Polite_form_humb, # U20
 *     "Prefix_yes": Prefix_yes, # U,             # <<<<<<<<<<<<<<
 *     "PrepCase_npr": PrepCase_npr, # cz,
 *     "PrepCase_pre": PrepCase_pre, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Prefix_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Prefix_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":365
 *     "Polite_form_humb": Polite_form_humb, # U20
 *     "Prefix_yes": Prefix_yes, # U,
 *     "PrepCase_npr": PrepCase_npr, # cz,             # <<<<<<<<<<<<<<
 *     "PrepCase_pre": PrepCase_pre, # U,
 *     "PunctSide_ini": PunctSide_ini, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PrepCase_npr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PrepCase_npr, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":366
 *     "Prefix_yes": Prefix_yes, # U,
 *     "PrepCase_npr": PrepCase_npr, # cz,
 *     "PrepCase_pre": PrepCase_pre, # U,             # <<<<<<<<<<<<<<
 *     "PunctSide_ini": PunctSide_ini, # U,
 *     "PunctSide_fin": PunctSide_fin, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PrepCase_pre); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PrepCase_pre, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":367
 *     "PrepCase_npr": PrepCase_npr, # cz,
 *     "PrepCase_pre": PrepCase_pre, # U,
 *     "PunctSide_ini": PunctSide_ini, # U,             # <<<<<<<<<<<<<<
 *     "PunctSide_fin": PunctSide_fin, # U,
 *     "PunctType_peri": PunctType_peri, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctSide_ini); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctSide_ini, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":368
 *     "PrepCase_pre": PrepCase_pre, # U,
 *     "PunctSide_ini": PunctSide_ini, # U,
 *     "PunctSide_fin": PunctSide_fin, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_peri": PunctType_peri, # U,
 *     "PunctType_qest": PunctType_qest, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctSide_fin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctSide_fin, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":369
 *     "PunctSide_ini": PunctSide_ini, # U,
 *     "PunctSide_fin": PunctSide_fin, # U,
 *     "PunctType_peri": PunctType_peri, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_qest": PunctType_qest, # U,
 *     "PunctType_excl": PunctType_excl, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_peri); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_peri, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":370
 *     "PunctSide_fin": PunctSide_fin, # U,
 *     "PunctType_peri": PunctType_peri, # U,
 *     "PunctType_qest": PunctType_qest, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_excl": PunctType_excl, # U,
 *     "PunctType_quot": PunctType_quot, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_qest); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_qest, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":371
 *     "PunctType_peri": PunctType_peri, # U,
 *     "PunctType_qest": PunctType_qest, # U,
 *     "PunctType_excl": PunctType_excl, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_quot": PunctType_quot, # U,
 *     "PunctType_brck": PunctType_brck, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_excl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_excl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":372
 *     "PunctType_qest": PunctType_qest, # U,
 *     "PunctType_excl": PunctType_excl, # U,
 *     "PunctType_quot": PunctType_quot, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_brck": PunctType_brck, # U,
 *     "PunctType_comm": PunctType_comm, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_quot); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_quot, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":373
 *     "PunctType_excl": PunctType_excl, # U,
 *     "PunctType_quot": PunctType_quot, # U,
 *     "PunctType_brck": PunctType_brck, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_comm": PunctType_comm, # U,
 *     "PunctType_colo": PunctType_colo, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_brck); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_brck, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":374
 *     "PunctType_quot": PunctType_quot, # U,
 *     "PunctType_brck": PunctType_brck, # U,
 *     "PunctType_comm": PunctType_comm, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_colo": PunctType_colo, # U,
 *     "PunctType_semi": PunctType_semi, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_comm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_comm, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":375
 *     "PunctType_brck": PunctType_brck, # U,
 *     "PunctType_comm": PunctType_comm, # U,
 *     "PunctType_colo": PunctType_colo, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_semi": PunctType_semi, # U,
 *     "PunctType_dash": PunctType_dash, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_colo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_colo, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":376
 *     "PunctType_comm": PunctType_comm, # U,
 *     "PunctType_colo": PunctType_colo, # U,
 *     "PunctType_semi": PunctType_semi, # U,             # <<<<<<<<<<<<<<
 *     "PunctType_dash": PunctType_dash, # U,
 *     "Style_arch": Style_arch, # cz, fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_semi); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_semi, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":377
 *     "PunctType_colo": PunctType_colo, # U,
 *     "PunctType_semi": PunctType_semi, # U,
 *     "PunctType_dash": PunctType_dash, # U,             # <<<<<<<<<<<<<<
 *     "Style_arch": Style_arch, # cz, fi, U,
 *     "Style_rare": Style_rare, # cz, fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PunctType_dash); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PunctType_dash, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":378
 *     "PunctType_semi": PunctType_semi, # U,
 *     "PunctType_dash": PunctType_dash, # U,
 *     "Style_arch": Style_arch, # cz, fi, U,             # <<<<<<<<<<<<<<
 *     "Style_rare": Style_rare, # cz, fi, U,
 *     "Style_poet": Style_poet, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_arch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_arch, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":379
 *     "PunctType_dash": PunctType_dash, # U,
 *     "Style_arch": Style_arch, # cz, fi, U,
 *     "Style_rare": Style_rare, # cz, fi, U,             # <<<<<<<<<<<<<<
 *     "Style_poet": Style_poet, # cz, U,
 *     "Style_norm": Style_norm, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_rare); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_rare, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":380
 *     "Style_arch": Style_arch, # cz, fi, U,
 *     "Style_rare": Style_rare, # cz, fi, U,
 *     "Style_poet": Style_poet, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_norm": Style_norm, # cz, U,
 *     "Style_coll": Style_coll, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_poet); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_poet, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":381
 *     "Style_rare": Style_rare, # cz, fi, U,
 *     "Style_poet": Style_poet, # cz, U,
 *     "Style_norm": Style_norm, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_coll": Style_coll, # cz, U,
 *     "Style_vrnc": Style_vrnc, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_norm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_norm, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":382
 *     "Style_poet": Style_poet, # cz, U,
 *     "Style_norm": Style_norm, # cz, U,
 *     "Style_coll": Style_coll, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_vrnc": Style_vrnc, # cz, U,
 *     "Style_sing": Style_sing, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_coll); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_coll, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":383
 *     "Style_norm": Style_norm, # cz, U,
 *     "Style_coll": Style_coll, # cz, U,
 *     "Style_vrnc": Style_vrnc, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_sing": Style_sing, # cz, U,
 *     "Style_expr": Style_expr, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_vrnc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_vrnc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":384
 *     "Style_coll": Style_coll, # cz, U,
 *     "Style_vrnc": Style_vrnc, # cz, U,
 *     "Style_sing": Style_sing, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_expr": Style_expr, # cz, U,
 *     "Style_derg": Style_derg, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_sing); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_sing, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":385
 *     "Style_vrnc": Style_vrnc, # cz, U,
 *     "Style_sing": Style_sing, # cz, U,
 *     "Style_expr": Style_expr, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_derg": Style_derg, # cz, U,
 *     "Style_vulg": Style_vulg, # cz, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_expr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_expr, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":386
 *     "Style_sing": Style_sing, # cz, U,
 *     "Style_expr": Style_expr, # cz, U,
 *     "Style_derg": Style_derg, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_vulg": Style_vulg, # cz, U,
 *     "Style_yes": Style_yes, # fi, U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_derg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_derg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":387
 *     "Style_expr": Style_expr, # cz, U,
 *     "Style_derg": Style_derg, # cz, U,
 *     "Style_vulg": Style_vulg, # cz, U,             # <<<<<<<<<<<<<<
 *     "Style_yes": Style_yes, # fi, U,
 *     "StyleVariant_styleShort": StyleVariant_styleShort, # cz,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_vulg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_vulg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":388
 *     "Style_derg": Style_derg, # cz, U,
 *     "Style_vulg": Style_vulg, # cz, U,
 *     "Style_yes": Style_yes, # fi, U,             # <<<<<<<<<<<<<<
 *     "StyleVariant_styleShort": StyleVariant_styleShort, # cz,
 *     "StyleVariant_styleBound": StyleVariant_styleBound, # cz, sl,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_Style_yes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Style_yes, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":389
 *     "Style_vulg": Style_vulg, # cz, U,
 *     "Style_yes": Style_yes, # fi, U,
 *     "StyleVariant_styleShort": StyleVariant_styleShort, # cz,             # <<<<<<<<<<<<<<
 *     "StyleVariant_styleBound": StyleVariant_styleBound, # cz, sl,
 *     "VerbType_aux": VerbType_aux, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_StyleVariant_styleShort); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_StyleVariant_styleShort, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":390
 *     "Style_yes": Style_yes, # fi, U,
 *     "StyleVariant_styleShort": StyleVariant_styleShort, # cz,
 *     "StyleVariant_styleBound": StyleVariant_styleBound, # cz, sl,             # <<<<<<<<<<<<<<
 *     "VerbType_aux": VerbType_aux, # U,
 *     "VerbType_cop": VerbType_cop, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_StyleVariant_styleBound); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_StyleVariant_styleBound, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":391
 *     "StyleVariant_styleShort": StyleVariant_styleShort, # cz,
 *     "StyleVariant_styleBound": StyleVariant_styleBound, # cz, sl,
 *     "VerbType_aux": VerbType_aux, # U,             # <<<<<<<<<<<<<<
 *     "VerbType_cop": VerbType_cop, # U,
 *     "VerbType_mod": VerbType_mod, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbType_aux); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbType_aux, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":392
 *     "StyleVariant_styleBound": StyleVariant_styleBound, # cz, sl,
 *     "VerbType_aux": VerbType_aux, # U,
 *     "VerbType_cop": VerbType_cop, # U,             # <<<<<<<<<<<<<<
 *     "VerbType_mod": VerbType_mod, # U,
 *     "VerbType_light": VerbType_light, # U,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbType_cop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbType_cop, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":393
 *     "VerbType_aux": VerbType_aux, # U,
 *     "VerbType_cop": VerbType_cop, # U,
 *     "VerbType_mod": VerbType_mod, # U,             # <<<<<<<<<<<<<<
 *     "VerbType_light": VerbType_light, # U,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbType_mod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbType_mod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":394
 *     "VerbType_cop": VerbType_cop, # U,
 *     "VerbType_mod": VerbType_mod, # U,
 *     "VerbType_light": VerbType_light, # U,             # <<<<<<<<<<<<<<
 * 
 *     "PERSON": PERSON,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_VerbType_light); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_VerbType_light, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":396
 *     "VerbType_light": VerbType_light, # U,
 * 
 *     "PERSON": PERSON,             # <<<<<<<<<<<<<<
 *     "NORP": NORP,
 *     "FACILITY": FACILITY,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PERSON); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PERSON, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":397
 * 
 *     "PERSON": PERSON,
 *     "NORP": NORP,             # <<<<<<<<<<<<<<
 *     "FACILITY": FACILITY,
 *     "ORG": ORG,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_NORP); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_NORP, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":398
 *     "PERSON": PERSON,
 *     "NORP": NORP,
 *     "FACILITY": FACILITY,             # <<<<<<<<<<<<<<
 *     "ORG": ORG,
 *     "GPE": GPE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_FACILITY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FACILITY, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":399
 *     "NORP": NORP,
 *     "FACILITY": FACILITY,
 *     "ORG": ORG,             # <<<<<<<<<<<<<<
 *     "GPE": GPE,
 *     "LOC": LOC,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ORG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ORG, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":400
 *     "FACILITY": FACILITY,
 *     "ORG": ORG,
 *     "GPE": GPE,             # <<<<<<<<<<<<<<
 *     "LOC": LOC,
 *     "PRODUCT": PRODUCT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_GPE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_GPE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":401
 *     "ORG": ORG,
 *     "GPE": GPE,
 *     "LOC": LOC,             # <<<<<<<<<<<<<<
 *     "PRODUCT": PRODUCT,
 *     "EVENT": EVENT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LOC); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LOC, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":402
 *     "GPE": GPE,
 *     "LOC": LOC,
 *     "PRODUCT": PRODUCT,             # <<<<<<<<<<<<<<
 *     "EVENT": EVENT,
 *     "WORK_OF_ART": WORK_OF_ART,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PRODUCT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PRODUCT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":403
 *     "LOC": LOC,
 *     "PRODUCT": PRODUCT,
 *     "EVENT": EVENT,             # <<<<<<<<<<<<<<
 *     "WORK_OF_ART": WORK_OF_ART,
 *     "LANGUAGE": LANGUAGE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_EVENT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_EVENT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":404
 *     "PRODUCT": PRODUCT,
 *     "EVENT": EVENT,
 *     "WORK_OF_ART": WORK_OF_ART,             # <<<<<<<<<<<<<<
 *     "LANGUAGE": LANGUAGE,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_WORK_OF_ART); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_WORK_OF_ART, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":405
 *     "EVENT": EVENT,
 *     "WORK_OF_ART": WORK_OF_ART,
 *     "LANGUAGE": LANGUAGE,             # <<<<<<<<<<<<<<
 * 
 *     "DATE": DATE,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LANGUAGE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LANGUAGE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":407
 *     "LANGUAGE": LANGUAGE,
 * 
 *     "DATE": DATE,             # <<<<<<<<<<<<<<
 *     "TIME": TIME,
 *     "PERCENT": PERCENT,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_DATE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_DATE, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":408
 * 
 *     "DATE": DATE,
 *     "TIME": TIME,             # <<<<<<<<<<<<<<
 *     "PERCENT": PERCENT,
 *     "MONEY": MONEY,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_TIME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_TIME, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":409
 *     "DATE": DATE,
 *     "TIME": TIME,
 *     "PERCENT": PERCENT,             # <<<<<<<<<<<<<<
 *     "MONEY": MONEY,
 *     "QUANTITY": QUANTITY,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_PERCENT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_PERCENT, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":410
 *     "TIME": TIME,
 *     "PERCENT": PERCENT,
 *     "MONEY": MONEY,             # <<<<<<<<<<<<<<
 *     "QUANTITY": QUANTITY,
 *     "ORDINAL": ORDINAL,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_MONEY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_MONEY, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":411
 *     "PERCENT": PERCENT,
 *     "MONEY": MONEY,
 *     "QUANTITY": QUANTITY,             # <<<<<<<<<<<<<<
 *     "ORDINAL": ORDINAL,
 *     "CARDINAL": CARDINAL,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_QUANTITY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_QUANTITY, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":412
 *     "MONEY": MONEY,
 *     "QUANTITY": QUANTITY,
 *     "ORDINAL": ORDINAL,             # <<<<<<<<<<<<<<
 *     "CARDINAL": CARDINAL,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ORDINAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ORDINAL, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":413
 *     "QUANTITY": QUANTITY,
 *     "ORDINAL": ORDINAL,
 *     "CARDINAL": CARDINAL,             # <<<<<<<<<<<<<<
 * 
 *     "acomp": acomp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_CARDINAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_CARDINAL, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":415
 *     "CARDINAL": CARDINAL,
 * 
 *     "acomp": acomp,             # <<<<<<<<<<<<<<
 *     "advcl": advcl,
 *     "advmod": advmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_acomp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_acomp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":416
 * 
 *     "acomp": acomp,
 *     "advcl": advcl,             # <<<<<<<<<<<<<<
 *     "advmod": advmod,
 *     "agent": agent,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_advcl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_advcl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":417
 *     "acomp": acomp,
 *     "advcl": advcl,
 *     "advmod": advmod,             # <<<<<<<<<<<<<<
 *     "agent": agent,
 *     "amod": amod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_advmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_advmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":418
 *     "advcl": advcl,
 *     "advmod": advmod,
 *     "agent": agent,             # <<<<<<<<<<<<<<
 *     "amod": amod,
 *     "appos": appos,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_agent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_agent, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":419
 *     "advmod": advmod,
 *     "agent": agent,
 *     "amod": amod,             # <<<<<<<<<<<<<<
 *     "appos": appos,
 *     "attr": attr,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_amod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_amod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":420
 *     "agent": agent,
 *     "amod": amod,
 *     "appos": appos,             # <<<<<<<<<<<<<<
 *     "attr": attr,
 *     "aux": aux,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_appos); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_appos, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":421
 *     "amod": amod,
 *     "appos": appos,
 *     "attr": attr,             # <<<<<<<<<<<<<<
 *     "aux": aux,
 *     "auxpass": auxpass,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_attr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_attr, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":422
 *     "appos": appos,
 *     "attr": attr,
 *     "aux": aux,             # <<<<<<<<<<<<<<
 *     "auxpass": auxpass,
 *     "cc": cc,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_aux); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_aux, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":423
 *     "attr": attr,
 *     "aux": aux,
 *     "auxpass": auxpass,             # <<<<<<<<<<<<<<
 *     "cc": cc,
 *     "ccomp": ccomp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_auxpass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_auxpass, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":424
 *     "aux": aux,
 *     "auxpass": auxpass,
 *     "cc": cc,             # <<<<<<<<<<<<<<
 *     "ccomp": ccomp,
 *     "complm": complm,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_cc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_cc, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":425
 *     "auxpass": auxpass,
 *     "cc": cc,
 *     "ccomp": ccomp,             # <<<<<<<<<<<<<<
 *     "complm": complm,
 *     "conj": conj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_ccomp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ccomp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":426
 *     "cc": cc,
 *     "ccomp": ccomp,
 *     "complm": complm,             # <<<<<<<<<<<<<<
 *     "conj": conj,
 *     "cop": cop, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_complm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 426, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_complm, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":427
 *     "ccomp": ccomp,
 *     "complm": complm,
 *     "conj": conj,             # <<<<<<<<<<<<<<
 *     "cop": cop, # U20
 *     "csubj": csubj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_conj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_conj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":428
 *     "complm": complm,
 *     "conj": conj,
 *     "cop": cop, # U20             # <<<<<<<<<<<<<<
 *     "csubj": csubj,
 *     "csubjpass": csubjpass,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_cop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_cop, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":429
 *     "conj": conj,
 *     "cop": cop, # U20
 *     "csubj": csubj,             # <<<<<<<<<<<<<<
 *     "csubjpass": csubjpass,
 *     "dep": dep,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_csubj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_csubj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":430
 *     "cop": cop, # U20
 *     "csubj": csubj,
 *     "csubjpass": csubjpass,             # <<<<<<<<<<<<<<
 *     "dep": dep,
 *     "det": det,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_csubjpass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_csubjpass, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":431
 *     "csubj": csubj,
 *     "csubjpass": csubjpass,
 *     "dep": dep,             # <<<<<<<<<<<<<<
 *     "det": det,
 *     "dobj": dobj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_dep); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_dep, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":432
 *     "csubjpass": csubjpass,
 *     "dep": dep,
 *     "det": det,             # <<<<<<<<<<<<<<
 *     "dobj": dobj,
 *     "expl": expl,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_det); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_det, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":433
 *     "dep": dep,
 *     "det": det,
 *     "dobj": dobj,             # <<<<<<<<<<<<<<
 *     "expl": expl,
 *     "hmod": hmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_dobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_dobj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":434
 *     "det": det,
 *     "dobj": dobj,
 *     "expl": expl,             # <<<<<<<<<<<<<<
 *     "hmod": hmod,
 *     "hyph": hyph,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_expl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_expl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":435
 *     "dobj": dobj,
 *     "expl": expl,
 *     "hmod": hmod,             # <<<<<<<<<<<<<<
 *     "hyph": hyph,
 *     "infmod": infmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_hmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_hmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":436
 *     "expl": expl,
 *     "hmod": hmod,
 *     "hyph": hyph,             # <<<<<<<<<<<<<<
 *     "infmod": infmod,
 *     "intj": intj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_hyph); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_hyph, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":437
 *     "hmod": hmod,
 *     "hyph": hyph,
 *     "infmod": infmod,             # <<<<<<<<<<<<<<
 *     "intj": intj,
 *     "iobj": iobj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_infmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_infmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":438
 *     "hyph": hyph,
 *     "infmod": infmod,
 *     "intj": intj,             # <<<<<<<<<<<<<<
 *     "iobj": iobj,
 *     "mark": mark,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_intj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_intj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":439
 *     "infmod": infmod,
 *     "intj": intj,
 *     "iobj": iobj,             # <<<<<<<<<<<<<<
 *     "mark": mark,
 *     "meta": meta,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_iobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_iobj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":440
 *     "intj": intj,
 *     "iobj": iobj,
 *     "mark": mark,             # <<<<<<<<<<<<<<
 *     "meta": meta,
 *     "neg": neg,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_mark); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_mark, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":441
 *     "iobj": iobj,
 *     "mark": mark,
 *     "meta": meta,             # <<<<<<<<<<<<<<
 *     "neg": neg,
 *     "nmod": nmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_meta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_meta, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":442
 *     "mark": mark,
 *     "meta": meta,
 *     "neg": neg,             # <<<<<<<<<<<<<<
 *     "nmod": nmod,
 *     "nn": nn,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_neg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_neg, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":443
 *     "meta": meta,
 *     "neg": neg,
 *     "nmod": nmod,             # <<<<<<<<<<<<<<
 *     "nn": nn,
 *     "npadvmod": npadvmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_nmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_nmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":444
 *     "neg": neg,
 *     "nmod": nmod,
 *     "nn": nn,             # <<<<<<<<<<<<<<
 *     "npadvmod": npadvmod,
 *     "nsubj": nsubj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_nn); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_nn, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":445
 *     "nmod": nmod,
 *     "nn": nn,
 *     "npadvmod": npadvmod,             # <<<<<<<<<<<<<<
 *     "nsubj": nsubj,
 *     "nsubjpass": nsubjpass,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_npadvmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_npadvmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":446
 *     "nn": nn,
 *     "npadvmod": npadvmod,
 *     "nsubj": nsubj,             # <<<<<<<<<<<<<<
 *     "nsubjpass": nsubjpass,
 *     "num": num,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_nsubj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_nsubj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":447
 *     "npadvmod": npadvmod,
 *     "nsubj": nsubj,
 *     "nsubjpass": nsubjpass,             # <<<<<<<<<<<<<<
 *     "num": num,
 *     "number": number,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_nsubjpass); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_nsubjpass, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":448
 *     "nsubj": nsubj,
 *     "nsubjpass": nsubjpass,
 *     "num": num,             # <<<<<<<<<<<<<<
 *     "number": number,
 *     "oprd": oprd,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_num); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_num, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":449
 *     "nsubjpass": nsubjpass,
 *     "num": num,
 *     "number": number,             # <<<<<<<<<<<<<<
 *     "oprd": oprd,
 *     "obj": obj, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_number); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_number, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":450
 *     "num": num,
 *     "number": number,
 *     "oprd": oprd,             # <<<<<<<<<<<<<<
 *     "obj": obj, # U20
 *     "obl": obl, # U20
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_oprd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_oprd, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":451
 *     "number": number,
 *     "oprd": oprd,
 *     "obj": obj, # U20             # <<<<<<<<<<<<<<
 *     "obl": obl, # U20
 *     "parataxis": parataxis,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_obj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_obj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":452
 *     "oprd": oprd,
 *     "obj": obj, # U20
 *     "obl": obl, # U20             # <<<<<<<<<<<<<<
 *     "parataxis": parataxis,
 *     "partmod": partmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_obl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_obl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":453
 *     "obj": obj, # U20
 *     "obl": obl, # U20
 *     "parataxis": parataxis,             # <<<<<<<<<<<<<<
 *     "partmod": partmod,
 *     "pcomp": pcomp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_parataxis); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_parataxis, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":454
 *     "obl": obl, # U20
 *     "parataxis": parataxis,
 *     "partmod": partmod,             # <<<<<<<<<<<<<<
 *     "pcomp": pcomp,
 *     "pobj": pobj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_partmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_partmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":455
 *     "parataxis": parataxis,
 *     "partmod": partmod,
 *     "pcomp": pcomp,             # <<<<<<<<<<<<<<
 *     "pobj": pobj,
 *     "poss": poss,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_pcomp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_pcomp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":456
 *     "partmod": partmod,
 *     "pcomp": pcomp,
 *     "pobj": pobj,             # <<<<<<<<<<<<<<
 *     "poss": poss,
 *     "possessive": possessive,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_pobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_pobj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":457
 *     "pcomp": pcomp,
 *     "pobj": pobj,
 *     "poss": poss,             # <<<<<<<<<<<<<<
 *     "possessive": possessive,
 *     "preconj": preconj,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_poss); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_poss, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":458
 *     "pobj": pobj,
 *     "poss": poss,
 *     "possessive": possessive,             # <<<<<<<<<<<<<<
 *     "preconj": preconj,
 *     "prep": prep,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_possessive); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_possessive, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":459
 *     "poss": poss,
 *     "possessive": possessive,
 *     "preconj": preconj,             # <<<<<<<<<<<<<<
 *     "prep": prep,
 *     "prt": prt,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_preconj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_preconj, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":460
 *     "possessive": possessive,
 *     "preconj": preconj,
 *     "prep": prep,             # <<<<<<<<<<<<<<
 *     "prt": prt,
 *     "punct": punct,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_prep); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_prep, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":461
 *     "preconj": preconj,
 *     "prep": prep,
 *     "prt": prt,             # <<<<<<<<<<<<<<
 *     "punct": punct,
 *     "quantmod": quantmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_prt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_prt, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":462
 *     "prep": prep,
 *     "prt": prt,
 *     "punct": punct,             # <<<<<<<<<<<<<<
 *     "quantmod": quantmod,
 *     "rcmod": rcmod,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_punct); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_punct, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":463
 *     "prt": prt,
 *     "punct": punct,
 *     "quantmod": quantmod,             # <<<<<<<<<<<<<<
 *     "rcmod": rcmod,
 *     "relcl": relcl,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_quantmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_quantmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":464
 *     "punct": punct,
 *     "quantmod": quantmod,
 *     "rcmod": rcmod,             # <<<<<<<<<<<<<<
 *     "relcl": relcl,
 *     "root": root,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_rcmod); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_rcmod, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":465
 *     "quantmod": quantmod,
 *     "rcmod": rcmod,
 *     "relcl": relcl,             # <<<<<<<<<<<<<<
 *     "root": root,
 *     "xcomp": xcomp,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_relcl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_relcl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":466
 *     "rcmod": rcmod,
 *     "relcl": relcl,
 *     "root": root,             # <<<<<<<<<<<<<<
 *     "xcomp": xcomp,
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_root); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_root, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":467
 *     "relcl": relcl,
 *     "root": root,
 *     "xcomp": xcomp,             # <<<<<<<<<<<<<<
 * 
 *     "acl": acl,
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_xcomp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_xcomp, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":469
 *     "xcomp": xcomp,
 * 
 *     "acl": acl,             # <<<<<<<<<<<<<<
 *     "LAW": LAW,
 * }
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_acl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_acl, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "spacy/symbols.pyx":470
 * 
 *     "acl": acl,
 *     "LAW": LAW,             # <<<<<<<<<<<<<<
 * }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(__pyx_e_5spacy_7symbols_LAW); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_LAW, __pyx_t_2) < 0) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IDS, __pyx_t_1) < 0) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "spacy/symbols.pyx":474
 * 
 * 
 * def sort_nums(x):             # <<<<<<<<<<<<<<
 *     return x[1]
 * 
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_5spacy_7symbols_1sort_nums, NULL, __pyx_n_s_spacy_symbols); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sort_nums, __pyx_t_1) < 0) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "spacy/symbols.pyx":478
 * 
 * 
 * PRON_LEMMA = "-PRON-"             # <<<<<<<<<<<<<<
 * NAMES = [it[0] for it in sorted(IDS.items(), key=sort_nums)]
 * # Unfortunate hack here, to work around problem with long cpdef enum
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PRON_LEMMA, __pyx_kp_u_PRON_2) < 0) __PYX_ERR(0, 478, __pyx_L1_error)

  /* "spacy/symbols.pyx":479
 * 
 * PRON_LEMMA = "-PRON-"
 * NAMES = [it[0] for it in sorted(IDS.items(), key=sort_nums)]             # <<<<<<<<<<<<<<
 * # Unfortunate hack here, to work around problem with long cpdef enum
 * # (which is generating an enormous amount of C++ in Cython 0.24+)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_IDS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_items); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_sort_nums); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_key, __pyx_t_4) < 0) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_sorted, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_2 = __pyx_t_4; __Pyx_INCREF(__pyx_t_2); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 479, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 479, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 479, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 479, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_2, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 479, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_2);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 479, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_it, __pyx_t_4) < 0) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_it); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NAMES, __pyx_t_1) < 0) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "spacy/symbols.pyx":483
 * # (which is generating an enormous amount of C++ in Cython 0.24+)
 * # We keep the enum cdef, and just make sure the names are available to Python
 * locals().update(IDS)             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_Globals(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_update); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_IDS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "spacy/symbols.pyx":1
 * # coding: utf8             # <<<<<<<<<<<<<<
 * #cython: optimize.unpack_method_calls=False
 * from __future__ import unicode_literals
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init spacy.symbols", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init spacy.symbols");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_5spacy_7symbols_symbol_t(enum __pyx_t_5spacy_7symbols_symbol_t value) {
    const enum __pyx_t_5spacy_7symbols_symbol_t neg_one = (enum __pyx_t_5spacy_7symbols_symbol_t) ((enum __pyx_t_5spacy_7symbols_symbol_t) 0 - (enum __pyx_t_5spacy_7symbols_symbol_t) 1), const_zero = (enum __pyx_t_5spacy_7symbols_symbol_t) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum __pyx_t_5spacy_7symbols_symbol_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum __pyx_t_5spacy_7symbols_symbol_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_5spacy_7symbols_symbol_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum __pyx_t_5spacy_7symbols_symbol_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_5spacy_7symbols_symbol_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum __pyx_t_5spacy_7symbols_symbol_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* Globals */
static PyObject* __Pyx_Globals(void) {
    Py_ssize_t i;
    PyObject *names;
    PyObject *globals = __pyx_d;
    Py_INCREF(globals);
    names = PyObject_Dir(__pyx_m);
    if (!names)
        goto bad;
    for (i = PyList_GET_SIZE(names)-1; i >= 0; i--) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject* name = PySequence_ITEM(names, i);
        if (!name)
            goto bad;
#else
        PyObject* name = PyList_GET_ITEM(names, i);
#endif
        if (!PyDict_Contains(globals, name)) {
            PyObject* value = __Pyx_GetAttr(__pyx_m, name);
            if (!value) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                goto bad;
            }
            if (PyDict_SetItem(globals, name, value) < 0) {
#if CYTHON_COMPILING_IN_PYPY
                Py_DECREF(name);
#endif
                Py_DECREF(value);
                goto bad;
            }
        }
#if CYTHON_COMPILING_IN_PYPY
        Py_DECREF(name);
#endif
    }
    Py_DECREF(names);
    return globals;
bad:
    Py_XDECREF(names);
    Py_XDECREF(globals);
    return NULL;
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
